@@ -6,17 +6,9 @@
 // Created:     19991127.mj10777
 // Copyright:   (c) Mark Johnson
 // Licence:     wxWindows license
-// RCS-ID:      $Id: browsedb.cpp,v 1.32 2005/01/31 18:09:45 ABX Exp $
-//----------------------------------------------------------------------------------------
-//-- 1)
-//----------------------------------------------------------------------------------------
-//-- all #ifdefs that the whole Project needs. -------------------------------------------
-//----------------------------------------------------------------------------------------
-#ifdef __GNUG__
-#pragma implementation
-#pragma interface
-#endif
+// RCS-ID:      $Id: browsedb.cpp,v 1.34 2005/09/23 12:48:14 MR Exp $
 //----------------------------------------------------------------------------------------
+
 // For compilers that support precompilation, includes "wx/wx.h".
 #include "wx/wxprec.h"
 //----------------------------------------------------------------------------------------
@@ -57,7 +49,7 @@ wxChar *GetExtendedDBErrorMsg(wxChar *ErrFile, int ErrLine)
     msg.Append (_T("\nODBC errors:\n"));
     // msg += _T("\n");
     /* Scan through each database connection displaying
-    * any ODBC errors that have occured. */
+    * any ODBC errors that have occurred. */
     wxDbList *pDbList;
     for (pDbList = PtrBegDbList; pDbList; pDbList = pDbList->PtrNext)
     {
