@@ -2,7 +2,7 @@
 // Name:        dcscreen.h
 // Purpose:
 // Author:      Vaclav Slavik
-// Id:          $Id: dcscreen.h,v 1.9 2004/05/23 20:51:18 JS Exp $
+// Id:          $Id: dcscreen.h,v 1.11 2006/09/05 20:46:07 VZ Exp $
 // Copyright:   (c) 2001-2002 SciTech Software, Inc. (www.scitechsoft.com)
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -10,10 +10,6 @@
 #ifndef __WX_DCSCREEN_H__
 #define __WX_DCSCREEN_H__
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-#pragma interface "dcscreen.h"
-#endif
-
 #include "wx/dcclient.h"
 
 //-----------------------------------------------------------------------------
@@ -30,7 +26,7 @@ class WXDLLEXPORT wxScreenDC: public wxDC
 {
 public:
     wxScreenDC();
-    ~wxScreenDC();
+    virtual ~wxScreenDC();
 
     static bool StartDrawingOnTop(wxWindow *WXUNUSED(window)) { return TRUE; }
     static bool StartDrawingOnTop(wxRect *WXUNUSED(rect) = NULL) { return TRUE; }
