@@ -1,21 +1,17 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        choice.h
+// Name:        wx/motif/choice.h
 // Purpose:     wxChoice class
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: choice.h,v 1.24.2.1 2006/01/08 01:28:48 SN Exp $
+// RCS-ID:      $Id: choice.h,v 1.30 2006/09/05 20:46:10 VZ Exp $
 // Copyright:   (c) Julian Smart
-// Licence:   	wxWindows licence
+// Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
 #ifndef _WX_CHOICE_H_
 #define _WX_CHOICE_H_
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA) && !defined(__EMX__)
-#pragma interface "choice.h"
-#endif
-
 #include "wx/clntdata.h"
 
 #ifndef wxWIDGET_ARRAY_DEFINED
@@ -32,8 +28,8 @@ class WXDLLEXPORT wxChoice: public wxChoiceBase
 
 public:
     wxChoice();
-    ~wxChoice();
-    
+    virtual ~wxChoice();
+
     wxChoice(wxWindow *parent, wxWindowID id,
         const wxPoint& pos = wxDefaultPosition,
         const wxSize& size = wxDefaultSize,
@@ -45,7 +41,7 @@ public:
         Init();
         Create(parent, id, pos, size, n, choices, style, validator, name);
     }
-    
+
     wxChoice(wxWindow *parent, wxWindowID id,
         const wxPoint& pos,
         const wxSize& size,
@@ -75,30 +71,29 @@ public:
         const wxString& name = wxChoiceNameStr);
 
     // implementation of wxControlWithItems
-    virtual int GetCount() const;
+    virtual unsigned int GetCount() const;
     virtual int DoAppend(const wxString& item);
-    virtual int DoInsert(const wxString& item, int pos);
-    virtual void DoSetItemClientData(int n, void* clientData);
-    virtual void* DoGetItemClientData(int n) const;
-    virtual void DoSetItemClientObject(int n, wxClientData* clientData);
-    virtual wxClientData* DoGetItemClientObject(int n) const;
+    virtual int DoInsert(const wxString& item, unsigned int pos);
+    virtual void DoSetItemClientData(unsigned int n, void* clientData);
+    virtual void* DoGetItemClientData(unsigned int n) const;
+    virtual void DoSetItemClientObject(unsigned int n, wxClientData* clientData);
+    virtual wxClientData* DoGetItemClientObject(unsigned int n) const;
     virtual int GetSelection() const;
-    virtual void Delete(int n);
-    virtual int FindString(const wxString& s) const;
+    virtual void Delete(unsigned int n);
     virtual void Clear();
-    virtual void SetString(int n, const wxString& s);
-    virtual wxString GetString(int n) const;
+    virtual void SetString(unsigned int n, const wxString& s);
+    virtual wxString GetString(unsigned int n) const;
 
     // implementation of wxChoiceBase
     virtual void SetSelection(int n);
     virtual void SetColumns(int n = 1 );
     virtual int GetColumns() const ;
-    
-    // Original API    
+
+    // Original API
     virtual void Command(wxCommandEvent& event);
-    
+
     void SetFocus();
-    
+
     // Implementation
     virtual void ChangeFont(bool keepOriginalSize = true);
     virtual void ChangeBackgroundColour();
@@ -117,14 +112,14 @@ protected:
     // common part of all contructors
     void Init();
 
-    size_t        m_noStrings;
+    unsigned int  m_noStrings;
     WXWidget      m_menuWidget;
     WXWidget      m_buttonWidget;
     wxWidgetArray m_widgetArray;
     WXWidget      m_formWidget;
     wxStringList  m_stringList;
     wxClientDataDictionary m_clientDataDict;
-     
+
     virtual void DoSetSize(int x, int y,
         int width, int height,
         int sizeFlags = wxSIZE_AUTO);
