@@ -1,10 +1,10 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        dcclient.h
+// Name:        wx/motif/dcclient.h
 // Purpose:     wxClientDC, wxPaintDC and wxWindowDC classes
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: dcclient.h,v 1.34 2005/09/18 01:19:13 VZ Exp $
+// RCS-ID:      $Id: dcclient.h,v 1.40 2006/10/05 19:34:18 MBN Exp $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -12,10 +12,6 @@
 #ifndef _WX_DCCLIENT_H_
 #define _WX_DCCLIENT_H_
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-#pragma interface "dcclient.h"
-#endif
-
 #include "wx/dc.h"
 
 // ----------------------------------------------------------------------------
@@ -35,21 +31,21 @@ class WXDLLEXPORT wxWindow;
 class WXDLLEXPORT wxWindowDC : public wxDC
 {
     DECLARE_DYNAMIC_CLASS(wxWindowDC)
-        
+
 public:
     wxWindowDC();
     wxWindowDC( wxWindow *win );
-    
-    ~wxWindowDC();
-    
+
+    virtual ~wxWindowDC();
+
     // TODO this function is Motif-only for now - should it go into base class?
     void Clear(const wxRect& rect);
-    
+
     // implement base class pure virtuals
     // ----------------------------------
-    
+
     virtual void Clear();
-    
+
     virtual void SetFont(const wxFont& font);
     virtual void SetPen(const wxPen& pen);
     virtual void SetBrush(const wxBrush& brush);
@@ -57,10 +53,10 @@ public:
     virtual void SetBackgroundMode(int mode);
     virtual void SetPalette(const wxPalette& palette);
     virtual void SetLogicalFunction( int function );
-    
+
     virtual void SetTextForeground(const wxColour& colour);
     virtual void SetTextBackground(const wxColour& colour);
-    
+
     virtual wxCoord GetCharHeight() const;
     virtual wxCoord GetCharWidth() const;
     virtual void DoGetTextExtent(const wxString& string,
@@ -68,27 +64,27 @@ public:
         wxCoord *descent = NULL,
         wxCoord *externalLeading = NULL,
         wxFont *theFont = NULL) const;
-    
+
     virtual bool CanDrawBitmap() const;
     virtual bool CanGetTextExtent() const;
-    
+
     virtual int GetDepth() const;
     virtual wxSize GetPPI() const;
-    
+
     virtual void DestroyClippingRegion();
-    
+
     // Helper function for setting clipping
     void SetDCClipping(WXRegion region);
-    
+
     // implementation from now on
     // --------------------------
-    
+
     WXGC GetGC() const { return m_gc; }
     WXGC GetBackingGC() const { return m_gcBacking; }
     WXDisplay* GetDisplay() const { return m_display; }
-    bool GetAutoSetting() const { return m_autoSetting; }
+    bool GetAutoSetting() const { return (m_autoSetting != 0); } // See comment in dcclient.cpp
     void SetAutoSetting(bool flag) { m_autoSetting = flag; }
-    
+
 protected:
     // note that this function will call colour.SetPixel,
     // and will do one of curCol = colour, curCol = wxWHITE, curCol = wxBLACK
@@ -96,45 +92,45 @@ protected:
     // if roundToWhite == true then the colour will be set to white unless
     // it is RGB 0x000000;if roundToWhite == true the colour wull be set to
     // black unless it id RGB 0xffffff
-    int CalculatePixel(wxColour& colour, wxColour& curCol,
-                       bool roundToWhite) const;
+    WXPixel CalculatePixel(wxColour& colour, wxColour& curCol,
+                           bool roundToWhite) const;
     // sets the foreground pixel taking into account the
     // currently selected logical operation
-    void SetForegroundPixelWithLogicalFunction(int pixel);
+    void SetForegroundPixelWithLogicalFunction(WXPixel pixel);
 
     virtual bool DoFloodFill(wxCoord x, wxCoord y, const wxColour& col,
         int style = wxFLOOD_SURFACE);
-    
+
     virtual bool DoGetPixel(wxCoord x, wxCoord y, wxColour *col) const;
-    
+
     virtual void DoDrawPoint(wxCoord x, wxCoord y);
     virtual void DoDrawLine(wxCoord x1, wxCoord y1, wxCoord x2, wxCoord y2);
-    
+
     virtual void DoDrawArc(wxCoord x1, wxCoord y1,
         wxCoord x2, wxCoord y2,
         wxCoord xc, wxCoord yc);
     virtual void DoDrawEllipticArc(wxCoord x, wxCoord y, wxCoord w, wxCoord h,
         double sa, double ea);
-    
+
     virtual void DoDrawRectangle(wxCoord x, wxCoord y, wxCoord width, wxCoord height);
     virtual void DoDrawRoundedRectangle(wxCoord x, wxCoord y,
         wxCoord width, wxCoord height,
         double radius);
     virtual void DoDrawEllipse(wxCoord x, wxCoord y, wxCoord width, wxCoord height);
-    
+
     virtual void DoCrossHair(wxCoord x, wxCoord y);
-    
+
     virtual void DoDrawText(const wxString& text, wxCoord x, wxCoord y);
     virtual void DoDrawRotatedText(const wxString &text, wxCoord x, wxCoord y, double angle);
-    
+
     virtual bool DoBlit(wxCoord xdest, wxCoord ydest, wxCoord width, wxCoord height,
         wxDC *source, wxCoord xsrc, wxCoord ysrc,
         int rop = wxCOPY, bool useMask = false, wxCoord xsrcMask = -1, wxCoord ysrcMask = -1);
-    
+
     virtual void DoSetClippingRegionAsRegion(const wxRegion& region);
     virtual void DoSetClippingRegion(wxCoord x, wxCoord y,
         wxCoord width, wxCoord height);
-    
+
     virtual void DoDrawLines(int n, wxPoint points[],
         wxCoord xoffset, wxCoord yoffset);
     virtual void DoDrawPolygon(int n, wxPoint points[],
@@ -157,7 +153,7 @@ protected:
     WXRegion     m_clipRegion;
 
     // Not sure if we'll need all of these
-    int          m_backgroundPixel;
+    WXPixel      m_backgroundPixel;
     wxColour     m_currentColour;
     int          m_currentPenWidth ;
     int          m_currentPenJoin ;
@@ -168,34 +164,26 @@ protected:
     int          m_currentStyle ;
     int          m_currentFill ;
     int          m_autoSetting ; // See comment in dcclient.cpp
-
-    // this is useless and should be removed, kept for now just for backwards
-    // compatibility
-#if wxCHECK_VERSION(2, 7, 0)
-    #error "Remove wxClientDC::m_oldFont"
-#endif
-    WXFont       m_oldFont;
 };
 
 class WXDLLEXPORT wxPaintDC: public wxWindowDC
 {
     DECLARE_DYNAMIC_CLASS(wxPaintDC)
-        
+
 public:
     wxPaintDC() { }
     wxPaintDC(wxWindow* win);
-    
-    ~wxPaintDC();
+
+    virtual ~wxPaintDC();
 };
 
 class WXDLLEXPORT wxClientDC: public wxWindowDC
 {
     DECLARE_DYNAMIC_CLASS(wxClientDC)
-        
+
 public:
     wxClientDC() { }
     wxClientDC(wxWindow* win) : wxWindowDC(win) { }
 };
 
-#endif
-// _WX_DCCLIENT_H_
+#endif // _WX_DCCLIENT_H_
