@@ -1,10 +1,10 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        dcmemory.h
+// Name:        wx/motif/dcmemory.h
 // Purpose:     wxMemoryDC class
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: dcmemory.h,v 1.10 2004/05/23 20:51:22 JS Exp $
+// RCS-ID:      $Id: dcmemory.h,v 1.16 2006/10/30 19:41:06 VZ Exp $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -12,30 +12,30 @@
 #ifndef _WX_DCMEMORY_H_
 #define _WX_DCMEMORY_H_
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-#pragma interface "dcmemory.h"
-#endif
-
 #include "wx/dcclient.h"
 
-class wxMemoryDC : public wxWindowDC
+class WXDLLIMPEXP_CORE wxMemoryDC : public wxWindowDC, public wxMemoryDCBase
 {
     DECLARE_DYNAMIC_CLASS(wxMemoryDC)
-        
+
 public:
-    wxMemoryDC();
+    wxMemoryDC() { Init(); }
+    wxMemoryDC(wxBitmap& bitmap) { Init(); SelectObject(bitmap); }
     wxMemoryDC( wxDC *dc ); // Create compatible DC
-    ~wxMemoryDC();
-    
-    virtual void SelectObject( const wxBitmap& bitmap );
-    
+    virtual ~wxMemoryDC();
+
     void DoGetSize( int *width, int *height ) const;
-    
+
     wxBitmap& GetBitmap() const { return (wxBitmap&) m_bitmap; }
-    
+
+protected:
+    virtual void DoSelect(const wxBitmap& bitmap);
+
 private:
     friend class wxPaintDC;
-    
+
+    void Init();
+
     wxBitmap  m_bitmap;
 };
 
