@@ -1,21 +1,17 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        icon.h
+// Name:        wx/motif/icon.h
 // Purpose:     wxIcon class
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: icon.h,v 1.23 2005/09/13 16:04:10 VZ Exp $
+// RCS-ID:      $Id: icon.h,v 1.28 2006/10/30 19:26:00 VZ Exp $
 // Copyright:   (c) Julian Smart
-// Licence:   	wxWindows licence
+// Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
 #ifndef _WX_ICON_H_
 #define _WX_ICON_H_
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-#pragma interface "icon.h"
-#endif
-
 #include "wx/bitmap.h"
 
 // Icon
@@ -24,9 +20,6 @@ class WXDLLEXPORT wxIcon : public wxBitmap
 public:
     wxIcon();
 
-    // Copy constructors
-    inline wxIcon(const wxIcon& icon) { Ref(icon); }
-
     // Initialize with XBM data
     wxIcon(const char bits[], int width, int height);
 
@@ -45,7 +38,7 @@ public:
         LoadFile(loc.GetFileName(), wxBITMAP_TYPE_ANY);
     }
 
-    ~wxIcon();
+    virtual ~wxIcon();
 
     bool LoadFile(const wxString& name, wxBitmapType type,
                   int desiredWidth, int desiredHeight = -1);
@@ -62,13 +55,6 @@ public:
     // ctors, assignment operators...), but it's ok to have such function
     void CopyFromBitmap(const wxBitmap& bmp);
 
-    wxIcon& operator = (const wxIcon& icon)
-        { if (this != &icon) Ref(icon); return *this; }
-    bool operator == (const wxIcon& icon) const
-        { return m_refData == icon.m_refData; }
-    bool operator != (const wxIcon& icon) const
-        { return !(*this == icon); }
-
 
     DECLARE_DYNAMIC_CLASS(wxIcon)
 };
