@@ -1,29 +1,25 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        minifram.h
+// Name:        wx/motif/minifram.h
 // Purpose:     wxMiniFrame class. A small frame for e.g. floating toolbars.
 //              If there is no equivalent on your platform, just make it a
 //              normal frame.
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: minifram.h,v 1.6 2004/05/23 20:51:22 JS Exp $
+// RCS-ID:      $Id: minifram.h,v 1.9 2006/09/05 20:46:13 VZ Exp $
 // Copyright:   (c) Julian Smart
-// Licence:   	wxWindows licence
+// Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
 #ifndef _WX_MINIFRAM_H_
 #define _WX_MINIFRAM_H_
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-#pragma interface "minifram.h"
-#endif
-
 #include "wx/frame.h"
 
 class WXDLLEXPORT wxMiniFrame: public wxFrame {
-    
+
     DECLARE_DYNAMIC_CLASS(wxMiniFrame)
-        
+
 public:
     inline wxMiniFrame() {}
     inline wxMiniFrame(wxWindow *parent,
@@ -37,8 +33,8 @@ public:
         // Use wxFrame constructor in absence of more specific code.
         Create(parent, id, title, pos, size, style, name);
     }
-    
-    ~wxMiniFrame() {}
+
+    virtual ~wxMiniFrame() {}
 protected:
 };
 
