@@ -4,7 +4,7 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     12/10/2002
-// RCS-ID:      $Id: toplevel.h,v 1.13 2005/09/19 10:36:18 VZ Exp $
+// RCS-ID:      $Id: toplevel.h,v 1.15 2005/09/25 20:29:56 VZ Exp $
 // Copyright:   (c) Mattia Barbon
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -12,10 +12,6 @@
 #ifndef __MOTIFTOPLEVELH__
 #define __MOTIFTOPLEVELH__
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-    #pragma interface "toplevel.h"
-#endif
-
 class WXDLLIMPEXP_CORE wxTopLevelWindowMotif : public wxTopLevelWindowBase
 {
 public:
@@ -72,14 +68,8 @@ protected:
     virtual void DoGetPosition(int* x, int* y) const;
 
 private:
-#if wxCHECK_VERSION(2,7,0)
-    // DoDestroy() is not used anywhere else, DoCreate() should also be renamed
-    // in src/motif/dialog.cpp, frame.cpp and toplevel.cp
-    #error "Remove DoDestroy() and rename DoCreate() to XmDoCreateTLW(), they were only kept for binary backwards compatibility"
-#endif
-
     // really create the Motif widget for TLW
-    virtual bool DoCreate(wxWindow* parent,
+    virtual bool XmDoCreateTLW(wxWindow* parent,
                                wxWindowID id,
                                const wxString& title,
                                const wxPoint& pos,
@@ -87,7 +77,6 @@ private:
                                long style,
                                const wxString& name) = 0;
 
-    virtual void DoDestroy() { }
 
     wxString m_title;
 };
