@@ -1,10 +1,10 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        window.h
+// Name:        wx/motif/window.h
 // Purpose:     wxWindow class
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: window.h,v 1.60 2005/08/03 00:53:09 MW Exp $
+// RCS-ID:      $Id: window.h,v 1.62 2005/11/03 20:58:01 ABX Exp $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -12,10 +12,6 @@
 #ifndef _WX_WINDOW_H_
 #define _WX_WINDOW_H_
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-#pragma interface "window.h"
-#endif
-
 #include "wx/region.h"
 
 // ----------------------------------------------------------------------------
@@ -26,53 +22,53 @@ class WXDLLIMPEXP_CORE wxWindow : public wxWindowBase
 {
     friend class WXDLLEXPORT wxDC;
     friend class WXDLLEXPORT wxWindowDC;
-    
+
 public:
     wxWindow() { Init(); }
-    
+
     wxWindow(wxWindow *parent,
-        wxWindowID id,
-        const wxPoint& pos = wxDefaultPosition,
-        const wxSize& size = wxDefaultSize,
-        long style = 0,
-        const wxString& name = wxPanelNameStr)
+             wxWindowID id,
+             const wxPoint& pos = wxDefaultPosition,
+             const wxSize& size = wxDefaultSize,
+             long style = 0,
+             const wxString& name = wxPanelNameStr)
     {
         Init();
         Create(parent, id, pos, size, style, name);
     }
-    
+
     virtual ~wxWindow();
-    
+
     bool Create(wxWindow *parent,
-        wxWindowID id,
-        const wxPoint& pos = wxDefaultPosition,
-        const wxSize& size = wxDefaultSize,
-        long style = 0,
-        const wxString& name = wxPanelNameStr);
-    
+                wxWindowID id,
+                const wxPoint& pos = wxDefaultPosition,
+                const wxSize& size = wxDefaultSize,
+                long style = 0,
+                const wxString& name = wxPanelNameStr);
+
     // implement base class pure virtuals
-    virtual void SetTitle( const wxString& title);
-    virtual wxString GetTitle() const;
-    
+    virtual void SetLabel(const wxString& label);
+    virtual wxString GetLabel() const;
+
     virtual void Raise();
     virtual void Lower();
-    
+
     virtual bool Show( bool show = true );
     virtual bool Enable( bool enable = true );
-    
+
     virtual void SetFocus();
-    
+
     virtual void WarpPointer(int x, int y);
-    
+
     virtual void Refresh( bool eraseBackground = true,
         const wxRect *rect = (const wxRect *) NULL );
-    
+
     virtual bool SetBackgroundColour( const wxColour &colour );
     virtual bool SetForegroundColour( const wxColour &colour );
-    
+
     virtual bool SetCursor( const wxCursor &cursor );
     virtual bool SetFont( const wxFont &font );
-    
+
     virtual int GetCharHeight() const;
     virtual int GetCharWidth() const;
     virtual void GetTextExtent(const wxString& string,
@@ -81,7 +77,7 @@ public:
         int *externalLeading = (int *) NULL,
         const wxFont *theFont = (const wxFont *) NULL)
         const;
-    
+
     virtual void SetScrollbar( int orient, int pos, int thumbVisible,
         int range, bool refresh = true );
     virtual void SetScrollPos( int orient, int pos, bool refresh = true );
@@ -90,23 +86,23 @@ public:
     virtual int GetScrollRange( int orient ) const;
     virtual void ScrollWindow( int dx, int dy,
         const wxRect* rect = (wxRect *) NULL );
-    
+
 #if wxUSE_DRAG_AND_DROP
     virtual void SetDropTarget( wxDropTarget *dropTarget );
 #endif // wxUSE_DRAG_AND_DROP
-    
+
     // Accept files for dragging
     virtual void DragAcceptFiles(bool accept);
 
     // Get the unique identifier of a window
     virtual WXWidget GetHandle() const { return GetMainWidget(); }
-    
+
     // implementation from now on
     // --------------------------
-    
+
     // accessors
     // ---------
-    
+
     // Get main widget for this window, e.g. a text widget
     virtual WXWidget GetMainWidget() const;
     // Get the widget that corresponds to the label (for font setting,
@@ -119,46 +115,46 @@ public:
     // multi-line text widget. Top means, top in the window hierarchy that
     // implements this window.
     virtual WXWidget GetTopWidget() const;
-    
+
     // Get the underlying X window and display
     WXWindow GetClientXWindow() const;
     WXWindow GetXWindow() const;
     WXDisplay *GetXDisplay() const;
-    
+
     void SetLastClick(int button, long timestamp)
     { m_lastButton = button; m_lastTS = timestamp; }
-    
+
     int GetLastClickedButton() const { return m_lastButton; }
     long GetLastClickTime() const { return m_lastTS; }
-    
+
     // Gives window a chance to do something in response to a size message,
     // e.g. arrange status bar, toolbar etc.
     virtual bool PreResize();
-    
+
     // Generates a paint event
     virtual void DoPaint();
-    
+
     // update rectangle/region manipulation
     // (for wxWindowDC and Motif callbacks only)
     // -----------------------------------------
-    
+
     // Adds a recangle to the updates list
     void AddUpdateRect(int x, int y, int w, int h);
-    
+
     void ClearUpdateRegion() { m_updateRegion.Clear(); }
     void SetUpdateRegion(const wxRegion& region) { m_updateRegion = region; }
-    
+
     // Process idle (send update events)
     void OnInternalIdle();
-    
+
 protected:
     // Responds to colour changes: passes event on to children.
     void OnSysColourChanged(wxSysColourChangedEvent& event);
-    
+
     // Motif-specific
-    
+
     void SetMainWidget(WXWidget w) { m_mainWidget = w; }
-    
+
     // See src/motif/window.cpp, near the top, for an explanation
     // why this is necessary
     void CanvasSetSizeIntr(int x, int y, int width, int height,
@@ -189,23 +185,23 @@ public:
     int GetPixmapHeight() const { return m_pixmapHeight; }
     void SetPixmapWidth(int w) { m_pixmapWidth = w; }
     void SetPixmapHeight(int h) { m_pixmapHeight = h; }
-    
+
     // Change properties
     // Change to the current font (often overridden)
     virtual void ChangeFont(bool keepOriginalSize = true);
-    
+
     // Change background and foreground colour using current background colour
     // setting (Motif generates foreground based on background)
     virtual void ChangeBackgroundColour();
     // Change foreground colour using current foreground colour setting
     virtual void ChangeForegroundColour();
-    
+
 protected:
     // Adds the widget to the hash table and adds event handlers.
     bool AttachWidget(wxWindow* parent, WXWidget mainWidget,
         WXWidget formWidget, int x, int y, int width, int height);
     bool DetachWidget(WXWidget widget);
-    
+
     // How to implement accelerators. If we find a key event, translate to
     // wxWidgets wxKeyEvent form. Find a widget for the window. Now find a
     // wxWindow for the widget. If there isn't one, go up the widget hierarchy
@@ -220,26 +216,26 @@ protected:
     // event and send it.
 public:
     virtual bool ProcessAccelerator(wxKeyEvent& event);
-    
+
 protected:
     // unmanage and destroy an X widget f it's !NULL (passing NULL is ok)
     void UnmanageAndDestroy(WXWidget widget);
-    
+
     // map or unmap an X widget (passing NULL is ok),
     // returns true if widget was mapped/unmapped
     bool MapOrUnmap(WXWidget widget, bool map);
-    
+
     // scrolling stuff
     // ---------------
-    
+
     // create/destroy window scrollbars
     void CreateScrollbar(wxOrientation orientation);
     void DestroyScrollbar(wxOrientation orientation);
-    
+
     // get either hor or vert scrollbar widget
     WXWidget GetScrollbar(wxOrientation orient) const
     { return orient == wxHORIZONTAL ? m_hScrollBar : m_vScrollBar; }
-    
+
     // set the scroll pos
     void SetInternalScrollPos(wxOrientation orient, int pos)
     {
@@ -248,16 +244,16 @@ protected:
         else
             m_scrollPosY = pos;
     }
-    
+
     // Motif-specific flags
     // --------------------
-    
+
     bool m_needsRefresh:1;          // repaint backing store?
-    
+
     // For double-click detection
     long                  m_lastTS;           // last timestamp
     unsigned              m_lastButton:2;     // last pressed button
-    
+
 protected:
     WXWidget              m_mainWidget;
     WXWidget              m_hScrollBar;
@@ -271,12 +267,12 @@ protected:
     int                   m_pixmapHeight;
     int                   m_pixmapOffsetX;
     int                   m_pixmapOffsetY;
-    
+
     // Store the last scroll pos, since in wxWin the pos isn't set
     // automatically by system
     int                   m_scrollPosX;
     int                   m_scrollPosY;
-    
+
     // implement the base class pure virtuals
     virtual void DoClientToScreen( int *x, int *y ) const;
     virtual void DoScreenToClient( int *x, int *y ) const;
@@ -295,11 +291,11 @@ protected:
 #if wxUSE_TOOLTIPS
     virtual void DoSetToolTip( wxToolTip *tip );
 #endif // wxUSE_TOOLTIPS
-    
+
 private:
     // common part of all ctors
     void Init();
-    
+
     DECLARE_DYNAMIC_CLASS(wxWindow)
     DECLARE_NO_COPY_CLASS(wxWindow)
     DECLARE_EVENT_TABLE()
@@ -322,12 +318,11 @@ class WXDLLEXPORT wxNoOptimize
 public:
     wxNoOptimize() { ms_count++; }
     ~wxNoOptimize() { ms_count--; }
-    
+
     static bool CanOptimize() { return ms_count == 0; }
-    
+
 protected:
     static int ms_count;
 };
 
-#endif
-// _WX_WINDOW_H_
+#endif // _WX_WINDOW_H_
