@@ -4,7 +4,7 @@
 // Author:      Stefan Neis
 // Modified by:
 // Created:     22.09.2003
-// RCS-ID:      $Id: apptrait.h,v 1.3 2004/05/23 20:51:37 JS Exp $
+// RCS-ID:      $Id: apptrait.h,v 1.5 2006/10/29 19:19:58 SN Exp $
 // Copyright:   (c) 2003 Stefan Neis <Stefan.Neis@t-online.de>
 // Licence:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
@@ -19,7 +19,6 @@
 class WXDLLIMPEXP_BASE wxConsoleAppTraits : public wxConsoleAppTraitsBase
 {
 public:
-    virtual wxToolkitInfo& GetToolkitInfo();
 };
 
 #if wxUSE_GUI
@@ -27,7 +26,7 @@ public:
 class WXDLLIMPEXP_CORE wxGUIAppTraits : public wxGUIAppTraitsBase
 {
 public:
-    virtual wxToolkitInfo& GetToolkitInfo();
+    virtual wxPortId GetToolkitVersion(int *majVer, int *minVer) const;
 
     // wxThread helpers
     // ----------------
@@ -37,6 +36,9 @@ public:
 
     // Clean up message queue.
     virtual void TerminateGui(unsigned long ulHab);
+#ifdef __WXGTK__
+    virtual wxString GetDesktopEnvironment() const;
+#endif
 };
 
 #endif // wxUSE_GUI
