@@ -1,18 +1,14 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        pnghand.h
+// Name:        wx/os2/pnghand.h
 // Purpose:     PNG bitmap handler
 // Author:      Julian Smart
 // Modified by:
 // Created:     04/01/98
-// RCS-ID:      $Id: pnghand.h,v 1.5 2004/05/23 20:51:39 JS Exp $
+// RCS-ID:      $Id: pnghand.h,v 1.7 2006/10/17 14:44:44 ABX Exp $
 // Copyright:   (c) Microsoft, Julian Smart
-// Licence:   	wxWindows licence
+// Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
-#ifdef __GNUG__
-#pragma interface "pnghand.h"
-#endif
-
 #ifndef _WX_PNGHAND_H_
 #define _WX_PNGHAND_H_
 
@@ -42,5 +38,4 @@ public:
 };
 
 #endif
-  // _WX_PNGHAND_H_
-
+    // _WX_PNGHAND_H_
