@@ -4,7 +4,7 @@
 // Author:      David Webster
 // Modified by:
 // Created:     01/23/03
-// RCS-ID:      $Id: treectrl.h,v 1.12 2005/05/23 10:28:26 ABX Exp $
+// RCS-ID:      $Id: treectrl.h,v 1.16 2006/03/28 13:11:18 ABX Exp $
 // Copyright:   (c) David Webster
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -16,10 +16,6 @@
 // headers
 // ----------------------------------------------------------------------------
 
-#ifdef __GNUG__
-    #pragma interface "treectrl.h"
-#endif
-
 #if wxUSE_TREECTRL
 
 #include "wx/textctrl.h"
@@ -40,9 +36,11 @@ struct WXDLLEXPORT wxTreeViewItem;
 // they're equivalent
 class wxTreeItemData;
 
-// flags for deprecated InsertItem() variant
-#define wxTREE_INSERT_FIRST 0xFFFF0001
-#define wxTREE_INSERT_LAST  0xFFFF0002
+#if WXWIN_COMPATIBILITY_2_6
+    // flags for deprecated InsertItem() variant
+    #define wxTREE_INSERT_FIRST 0xFFFF0001
+    #define wxTREE_INSERT_LAST  0xFFFF0002
+#endif
 
 // hash storing attributes for our items
 WX_DECLARE_EXPORTED_VOIDPTR_HASH_MAP(wxTreeItemAttr *, wxMapTreeAttr);
@@ -94,7 +92,7 @@ public:
     //
     // Get the total number of items in the control
     //
-    size_t GetCount(void) const;
+    virtual unsigned int GetCount(void) const;
 
     //
     // Indent is the number of pixels the children are indented relative to
@@ -277,14 +275,6 @@ public:
     //
     wxTreeItemId GetItemParent(const wxTreeItemId& rItem) const;
 
-#if WXWIN_COMPATIBILITY_2_2
-        // deprecated:  Use GetItemParent instead.
-    wxDEPRECATED( wxTreeItemId GetParent(const wxTreeItemId& item) const);
-
-        // Expose the base class method hidden by the one above. Not deprecatable.
-    wxWindow *GetParent() const { return wxControl::GetParent(); }
-#endif  // WXWIN_COMPATIBILITY_2_2
-
         // for this enumeration function you must pass in a "cookie" parameter
         // which is opaque for the application but is necessary for the library
         // to make these functions reentrant (i.e. allow more than one
