@@ -1,10 +1,10 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        window.h
+// Name:        wx/os2/window.h
 // Purpose:     wxWindow class
 // Author:      David Webster
 // Modified by:
 // Created:     10/12/99
-// RCS-ID:      $Id: window.h,v 1.55 2005/04/27 01:12:00 DW Exp $
+// RCS-ID:      $Id: window.h,v 1.58 2006/08/24 15:37:25 ABX Exp $
 // Copyright:   (c) David Webster
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -90,8 +90,8 @@ public:
                );
 
     // implement base class pure virtuals
-    virtual void     SetTitle(const wxString& rTitle);
-    virtual wxString GetTitle(void) const;
+    virtual void     SetLabel(const wxString& label);
+    virtual wxString GetLabel(void) const;
     virtual void     Raise(void);
     virtual void     Lower(void);
     virtual bool     Show(bool bShow = true);
@@ -178,7 +178,7 @@ public:
     virtual WXWidget GetHandle(void) const { return GetHWND(); }
     bool             GetUseCtl3D(void) const { return m_bUseCtl3D; }
     bool             GetTransparentBackground(void) const { return m_bBackgroundTransparent; }
-    void             SetTransparent(bool bT = true) { m_bBackgroundTransparent = bT; }
+    void             SetTransparentBackground(bool bT = true) { m_bBackgroundTransparent = bT; }
 
     // event handlers
     // --------------
@@ -571,7 +571,7 @@ public:
 // kbd code translation
 WXDLLEXPORT int wxCharCodeOS2ToWX(int nKeySym);
 WXDLLEXPORT int wxCharCodeWXToOS2( int   nId
-                                  ,bool* pbIsVirtual
+                                  ,bool* pbIsVirtual = NULL
                                  );
 
 // ----------------------------------------------------------------------------
@@ -587,5 +587,4 @@ WX_DECLARE_HASH(wxWindowOS2, wxWindowList, wxWinHashTable);
 
 extern wxWinHashTable *wxWinHandleHash;
 
-#endif
-    // _WX_WINDOW_H_
+#endif // _WX_WINDOW_H_
