@@ -2,7 +2,7 @@
 // Name:        wx/motif/dataobj.h
 // Purpose:     declaration of the wxDataObject class for Motif
 // Author:      Julian Smart
-// RCS-ID:      $Id: dataobj.h,v 1.6 2004/05/23 20:51:52 JS Exp $
+// RCS-ID:      $Id: dataobj.h,v 1.9 2006/09/05 20:46:53 VZ Exp $
 // Copyright:   (c) 1998 Robert Roebling
 // Licence:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
@@ -10,21 +10,17 @@
 #ifndef _WX_X11_DATAOBJ_H_
 #define _WX_X11_DATAOBJ_H_
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-#pragma interface "dataobj.h"
-#endif
-
 // ----------------------------------------------------------------------------
 // wxDataObject is the same as wxDataObjectBase under wxMotif
 // ----------------------------------------------------------------------------
 
-class wxDataObject : public wxDataObjectBase
+class WXDLLIMPEXP_CORE wxDataObject : public wxDataObjectBase
 {
 public:
     wxDataObject();
     
 #ifdef __DARWIN__
-    ~wxDataObject() { }
+    virtual ~wxDataObject() { }
 #endif
 
     virtual bool IsSupportedFormat( const wxDataFormat& format, Direction dir = Get ) const;
