@@ -4,7 +4,7 @@
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: dcclient.h,v 1.12 2005/08/02 18:16:49 MW Exp $
+// RCS-ID:      $Id: dcclient.h,v 1.16 2006/10/31 00:59:04 VZ Exp $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -12,10 +12,6 @@
 #ifndef _WX_DCCLIENT_H_
 #define _WX_DCCLIENT_H_
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-#pragma interface "dcclient.h"
-#endif
-
 #include "wx/dc.h"
 #include "wx/region.h"
 
@@ -36,10 +32,10 @@ class WXDLLIMPEXP_CORE wxClientDC;
 class WXDLLIMPEXP_CORE wxWindowDC : public wxDC
 {
 public:
-    wxWindowDC();
+    wxWindowDC() { Init(); }
     wxWindowDC( wxWindow *win );
 
-    ~wxWindowDC();
+    virtual ~wxWindowDC();
 
     virtual bool CanDrawBitmap() const { return true; }
     virtual bool CanGetTextExtent() const { return true; }
@@ -104,11 +100,6 @@ public:
 
     virtual wxCoord GetCharHeight() const;
     virtual wxCoord GetCharWidth() const;
-    virtual void DoGetTextExtent(const wxString& string,
-        wxCoord *x, wxCoord *y,
-        wxCoord *descent = NULL,
-        wxCoord *externalLeading = NULL,
-        wxFont *theFont = NULL) const;
 
     virtual int GetDepth() const;
     virtual wxSize GetPPI() const;
@@ -116,9 +107,18 @@ public:
     virtual void DestroyClippingRegion();
     WXWindow GetWindow() const { return m_window; }
 
+    virtual void ComputeScaleAndOrigin();
+
 protected:
     // implementation
     // --------------
+    virtual void DoGetTextExtent(const wxString& string,
+        wxCoord *x, wxCoord *y,
+        wxCoord *descent = NULL,
+        wxCoord *externalLeading = NULL,
+        wxFont *theFont = NULL) const;
+
+    void Init();
 
     WXDisplay    *m_display;
     WXWindow      m_window;
@@ -140,7 +140,6 @@ protected:
 
     void SetUpDC();
     void Destroy();
-    virtual void ComputeScaleAndOrigin();
 
 private:
     DECLARE_DYNAMIC_CLASS(wxWindowDC)
