@@ -1,34 +1,29 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        dcprint.h
+// Name:        wx/x11/dcprint.h
 // Purpose:     wxPrinterDC class
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: dcprint.h,v 1.5 2004/05/23 20:51:52 JS Exp $
+// RCS-ID:      $Id: dcprint.h,v 1.8 2006/10/17 14:44:51 ABX Exp $
 // Copyright:   (c) Julian Smart
-// Licence:   	wxWindows licence
+// Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
 #ifndef _WX_DCPRINT_H_
 #define _WX_DCPRINT_H_
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-#pragma interface "dcprint.h"
-#endif
-
 #include "wx/dc.h"
 
 class WXDLLEXPORT wxPrinterDC: public wxDC
 {
 public:
     DECLARE_CLASS(wxPrinterDC)
-        
+
     // Create a printer DC
     wxPrinterDC(const wxString& driver, const wxString& device, const wxString& output, bool interactive = TRUE, int orientation = wxPORTRAIT);
-    
-    ~wxPrinterDC();
+
+    virtual ~wxPrinterDC();
 };
 
 #endif
-// _WX_DCPRINT_H_
-
+    // _WX_DCPRINT_H_
