@@ -1,21 +1,17 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        dcscreen.h
+// Name:        wx/x11/dcscreen.h
 // Purpose:     wxScreenDC class
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: dcscreen.h,v 1.7 2005/08/02 18:16:49 MW Exp $
+// RCS-ID:      $Id: dcscreen.h,v 1.9 2006/10/17 14:44:51 ABX Exp $
 // Copyright:   (c) Julian Smart
-// Licence:   	wxWindows licence
+// Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
 #ifndef _WX_DCSCREEN_H_
 #define _WX_DCSCREEN_H_
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-#pragma interface "dcscreen.h"
-#endif
-
 #include "wx/dcclient.h"
 
 //-----------------------------------------------------------------------------
@@ -47,5 +43,4 @@ private:
 
 
 #endif
-// _WX_DCSCREEN_H_
-
+    // _WX_DCSCREEN_H_
