@@ -3,7 +3,7 @@
 // Purpose:
 // Author:      Robert Roebling
 // Created:
-// Id:          $Id: popupwin.h,v 1.8 2004/05/25 20:41:54 JS Exp $
+// Id:          $Id: popupwin.h,v 1.10 2005/09/23 12:51:01 MR Exp $
 // Copyright:   (c) 2001 Robert Roebling
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -11,10 +11,6 @@
 #ifndef __GTKPOPUPWINH__
 #define __GTKPOPUPWINH__
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-    #pragma interface "popupwin.h"
-#endif
-
 #include "wx/defs.h"
 #include "wx/panel.h"
 #include "wx/icon.h"
@@ -23,7 +19,7 @@
 // wxPopUpWindow
 //-----------------------------------------------------------------------------
 
-class wxPopupWindow: public wxPopupWindowBase
+class WXDLLIMPEXP_CORE wxPopupWindow: public wxPopupWindowBase
 {
 public:
     wxPopupWindow() { }
