@@ -1,21 +1,17 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        print.h
+// Name:        wx/x11/print.h
 // Purpose:     wxPrinter, wxPrintPreview classes
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: print.h,v 1.5 2004/05/23 20:51:52 JS Exp $
+// RCS-ID:      $Id: print.h,v 1.8 2006/10/17 14:44:52 ABX Exp $
 // Copyright:   (c) Julian Smart
-// Licence:   	wxWindows licence
+// Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
 #ifndef _WX_PRINT_H_
 #define _WX_PRINT_H_
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-#pragma interface "print.h"
-#endif
-
 #include "wx/prntbase.h"
 
 /*
@@ -25,11 +21,11 @@
 class WXDLLEXPORT wxPrinter: public wxPrinterBase
 {
     DECLARE_DYNAMIC_CLASS(wxPrinter)
-        
+
 public:
     wxPrinter(wxPrintData *data = NULL);
-    ~wxPrinter();
-    
+    virtual ~wxPrinter();
+
     virtual bool Print(wxWindow *parent, wxPrintout *printout, bool prompt = TRUE);
     virtual bool PrintDialog(wxWindow *parent);
     virtual bool Setup(wxWindow *parent);
@@ -43,14 +39,14 @@ public:
 class WXDLLEXPORT wxPrintPreview: public wxPrintPreviewBase
 {
     DECLARE_CLASS(wxPrintPreview)
-        
+
 public:
     wxPrintPreview(wxPrintout *printout, wxPrintout *printoutForPrinting = NULL, wxPrintData *data = NULL);
-    ~wxPrintPreview();
-    
+    virtual ~wxPrintPreview();
+
     virtual bool Print(bool interactive);
     virtual void DetermineScaling();
 };
 
 #endif
-// _WX_PRINT_H_
+    // _WX_PRINT_H_
