@@ -4,7 +4,7 @@
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: private.h,v 1.16 2005/08/02 18:16:50 MW Exp $
+// RCS-ID:      $Id: private.h,v 1.17 2006/05/28 23:51:22 VZ Exp $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -80,5 +80,9 @@ extern Window wxGetWindowParent(Window window);
 bool wxSetWMDecorations(Window w, long style);
 bool wxMWMIsRunning(Window w);
 
+// Checks if any of our children are finished.
+// implemented in src/x11/utils.cpp
+void wxCheckForFinishedChildren();
+
 #endif
 // _WX_PRIVATE_H_
