@@ -3,7 +3,7 @@
 // Purpose:
 // Author:      Robert Roebling
 // Created:     01/02/97
-// Id:          $Id: textctrl.h,v 1.15 2005/08/02 18:16:51 MW Exp $
+// Id:          $Id: textctrl.h,v 1.18 2006/10/08 22:39:51 VZ Exp $
 // Copyright:   (c) 1998 Robert Roebling
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -19,10 +19,6 @@
 #include "wx/univ/textctrl.h"
 #else
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-    #pragma interface "textctrl.h"
-#endif
-
 #include "wx/scrolwin.h"
 #include "wx/arrstr.h"
 #include "wx/datetime.h"
@@ -120,8 +116,7 @@ public:
     // implement base class pure virtuals
     // ----------------------------------
 
-    virtual wxString GetValue() const;
-    virtual void SetValue(const wxString& value);
+    virtual void ChangeValue(const wxString &value);
 
     virtual int GetLineLength(long lineNo) const;
     virtual wxString GetLineText(long lineNo) const;
@@ -133,10 +128,6 @@ public:
     // more readable flag testing methods
     // ----------------------------------
 
-#if 0
-    // it seems now in wxTextCtrlBase
-    bool IsSingleLine() const { return !(GetWindowStyle() & wxTE_MULTILINE); }
-#endif
     bool IsPassword() const { return (GetWindowStyle() & wxTE_PASSWORD) != 0; }
     bool WrapLines() const { return false; }
 
@@ -275,6 +266,8 @@ protected:
 
     virtual wxSize DoGetBestSize() const;
 
+    virtual void DoSetValue(const wxString& value, int flags = 0);
+
     friend class wxSourceUndoStep;
 
     wxSourceLineArray  m_lines;
