@@ -4,7 +4,7 @@
 // Author:      Vadim Zeitlin
 // Modified by:
 // Created:     01.11.99
-// RCS-ID:      $Id: menu.cpp,v 1.49 2005/05/18 20:39:34 MW Exp $
+// RCS-ID:      $Id: menu.cpp,v 1.59 2007/01/14 20:45:30 VZ Exp $
 // Copyright:   (c) 1999 Vadim Zeitlin
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -55,7 +55,7 @@
     #define USE_LOG_WINDOW 0
 #endif
 
-#if wxUSE_OWNER_DRAWN
+#if wxUSE_OWNER_DRAWN || defined(__WXGTK__)
 #include "copy.xpm"
 #endif
 
@@ -84,7 +84,8 @@ protected:
     void OnQuit(wxCommandEvent& event);
 #if USE_LOG_WINDOW
     void OnClearLog(wxCommandEvent& event);
-#endif
+    void OnClearLogUpdateUI(wxUpdateUIEvent& event);
+#endif // USE_LOG_WINDOW
 
     void OnAbout(wxCommandEvent& event);
 
@@ -200,7 +201,7 @@ enum
 {
     Menu_File_Quit = wxID_EXIT,
 #if USE_LOG_WINDOW
-    Menu_File_ClearLog,
+    Menu_File_ClearLog = 100,
 #endif
 
     Menu_MenuBar_Toggle = 200,
@@ -266,6 +267,7 @@ BEGIN_EVENT_TABLE(MyFrame, wxFrame)
     EVT_MENU(Menu_File_Quit,     MyFrame::OnQuit)
 #if USE_LOG_WINDOW
     EVT_MENU(Menu_File_ClearLog, MyFrame::OnClearLog)
+    EVT_UPDATE_UI(Menu_File_ClearLog, MyFrame::OnClearLogUpdateUI)
 #endif
 
     EVT_MENU(Menu_Help_About, MyFrame::OnAbout)
@@ -378,15 +380,69 @@ MyFrame::MyFrame()
     // create the menubar
     wxMenu *fileMenu = new wxMenu;
 
+    wxMenu *stockSubMenu = new wxMenu;
+    stockSubMenu->Append(wxID_ADD);
+    stockSubMenu->Append(wxID_APPLY);
+    stockSubMenu->Append(wxID_BOLD);
+    stockSubMenu->Append(wxID_CANCEL);
+    stockSubMenu->Append(wxID_CLEAR);
+    stockSubMenu->Append(wxID_CLOSE);
+    stockSubMenu->Append(wxID_COPY);
+    stockSubMenu->Append(wxID_CUT);
+    stockSubMenu->Append(wxID_DELETE);
+    stockSubMenu->Append(wxID_FIND);
+    stockSubMenu->Append(wxID_REPLACE);
+    stockSubMenu->Append(wxID_BACKWARD);
+    stockSubMenu->Append(wxID_DOWN);
+    stockSubMenu->Append(wxID_FORWARD);
+    stockSubMenu->Append(wxID_UP);
+    stockSubMenu->Append(wxID_HELP);
+    stockSubMenu->Append(wxID_HOME);
+    stockSubMenu->Append(wxID_INDENT);
+    stockSubMenu->Append(wxID_INDEX);
+    stockSubMenu->Append(wxID_ITALIC);
+    stockSubMenu->Append(wxID_JUSTIFY_CENTER);
+    stockSubMenu->Append(wxID_JUSTIFY_FILL);
+    stockSubMenu->Append(wxID_JUSTIFY_LEFT);
+    stockSubMenu->Append(wxID_JUSTIFY_RIGHT);
+    stockSubMenu->Append(wxID_NEW);
+    stockSubMenu->Append(wxID_NO);
+    stockSubMenu->Append(wxID_OK);
+    stockSubMenu->Append(wxID_OPEN);
+    stockSubMenu->Append(wxID_PASTE);
+    stockSubMenu->Append(wxID_PREFERENCES);
+    stockSubMenu->Append(wxID_PRINT);
+    stockSubMenu->Append(wxID_PREVIEW);
+    stockSubMenu->Append(wxID_PROPERTIES);
+    stockSubMenu->Append(wxID_EXIT);
+    stockSubMenu->Append(wxID_REDO);
+    stockSubMenu->Append(wxID_REFRESH);
+    stockSubMenu->Append(wxID_REMOVE);
+    stockSubMenu->Append(wxID_REVERT_TO_SAVED);
+    stockSubMenu->Append(wxID_SAVE);
+    stockSubMenu->Append(wxID_SAVEAS);
+    stockSubMenu->Append(wxID_STOP);
+    stockSubMenu->Append(wxID_UNDELETE);
+    stockSubMenu->Append(wxID_UNDERLINE);
+    stockSubMenu->Append(wxID_UNDO);
+    stockSubMenu->Append(wxID_UNINDENT);
+    stockSubMenu->Append(wxID_YES);
+    stockSubMenu->Append(wxID_ZOOM_100);
+    stockSubMenu->Append(wxID_ZOOM_FIT);
+    stockSubMenu->Append(wxID_ZOOM_IN);
+    stockSubMenu->Append(wxID_ZOOM_OUT);
+    fileMenu->AppendSubMenu(stockSubMenu, _T("&Standard items demo"));
+
 #if USE_LOG_WINDOW
     wxMenuItem *item = new wxMenuItem(fileMenu, Menu_File_ClearLog,
                                       _T("Clear &log\tCtrl-L"));
-#if wxUSE_OWNER_DRAWN
+#if wxUSE_OWNER_DRAWN || defined(__WXGTK__)
     item->SetBitmap(copy_xpm);
 #endif
     fileMenu->Append(item);
     fileMenu->AppendSeparator();
-#endif
+#endif // USE_LOG_WINDOW
+
     fileMenu->Append(Menu_File_Quit, _T("E&xit\tAlt-X"), _T("Quit menu sample"));
 
     wxMenu *menubarMenu = new wxMenu;
@@ -414,7 +470,7 @@ MyFrame::MyFrame()
 
     wxMenu* subMenu = new wxMenu;
     subMenu->Append(Menu_SubMenu_Normal, _T("&Normal submenu item"), _T("Disabled submenu item"));
-    subMenu->AppendCheckItem(Menu_SubMenu_Check, _T("&Unchecked submenu item"), _T("Unchecked submenu item"));
+    subMenu->AppendCheckItem(Menu_SubMenu_Check, _T("&Check submenu item"), _T("Check submenu item"));
     subMenu->AppendRadioItem(Menu_SubMenu_Radio1, _T("Radio item &1"), _T("Radio item"));
     subMenu->AppendRadioItem(Menu_SubMenu_Radio2, _T("Radio item &2"), _T("Radio item"));
     subMenu->AppendRadioItem(Menu_SubMenu_Radio3, _T("Radio item &3"), _T("Radio item"));
@@ -438,8 +494,10 @@ MyFrame::MyFrame()
     menuMenu->AppendSeparator();
     menuMenu->Append(Menu_Menu_GetInfo, _T("Get menu item in&fo\tAlt-F"),
                      _T("Show the state of the last menu item"));
+#if wxUSE_TEXTDLG
     menuMenu->Append(Menu_Menu_SetLabel, _T("Set menu item label\tAlt-L"),
                      _T("Set the label of a menu item"));
+#endif
 #if wxUSE_TEXTDLG
     menuMenu->AppendSeparator();
     menuMenu->Append(Menu_Menu_FindItem, _T("Find menu item from label"),
@@ -480,7 +538,7 @@ MyFrame::MyFrame()
 
 #if USE_LOG_WINDOW
     // create the log text window
-    m_textctrl = new wxTextCtrl(this, wxID_ANY, _T(""),
+    m_textctrl = new wxTextCtrl(this, wxID_ANY, wxEmptyString,
                                 wxDefaultPosition, wxDefaultSize,
                                 wxTE_MULTILINE);
     m_textctrl->SetEditable(false);
@@ -494,6 +552,9 @@ MyFrame::MyFrame()
                  _T("menubar itself.\n\n")
                  _T("Right click the band below to test popup menus.\n"));
 #endif
+#ifdef __POCKETPC__
+    EnableContextMenu();
+#endif
 }
 
 MyFrame::~MyFrame()
@@ -545,11 +606,13 @@ wxMenuItem *MyFrame::GetLastMenuItem() const
 void MyFrame::LogMenuEvent(const wxCommandEvent& event)
 {
     int id = event.GetId();
-    if ( !GetMenuBar()->FindItem(id) )
-        return;
 
     wxString msg = wxString::Format(_T("Menu command %d"), id);
-    if ( GetMenuBar()->FindItem(id)->IsCheckable() )
+
+    // catch all checkable menubar items and also the check item from the popup
+    // menu
+    wxMenuItem *item = GetMenuBar()->FindItem(id);
+    if ( (item && item->IsCheckable()) || id == Menu_Popup_ToBeChecked )
     {
         msg += wxString::Format(_T(" (the item is currently %schecked)"),
                                 event.IsChecked() ? _T("") : _T("not "));
@@ -568,11 +631,21 @@ void MyFrame::OnQuit(wxCommandEvent& WXUNUSED(event))
 }
 
 #if USE_LOG_WINDOW
+
 void MyFrame::OnClearLog(wxCommandEvent& WXUNUSED(event))
 {
     m_textctrl->Clear();
 }
-#endif
+
+void MyFrame::OnClearLogUpdateUI(wxUpdateUIEvent& event)
+{
+    // if we only enable this item when the log window is empty, we never see
+    // it in the disable state as a message is logged whenever the menu is
+    // opened, so we disable it if there is not "much" text in the window
+    event.Enable( m_textctrl->GetNumberOfLines() > 5 );
+}
+
+#endif // USE_LOG_WINDOW
 
 void MyFrame::OnAbout(wxCommandEvent& WXUNUSED(event))
 {
@@ -679,7 +752,7 @@ void MyFrame::OnFindMenu(wxCommandEvent& WXUNUSED(event))
                      (
                         _T("Enter label to search for: "),
                         _T("Find menu"),
-                        _T(""),
+                        wxEmptyString,
                         this
                      );
 
@@ -747,7 +820,7 @@ void MyFrame::OnInsertMenuItem(wxCommandEvent& WXUNUSED(event))
 
     menu->Insert(0, wxMenuItem::New(menu, Menu_Dummy_Fourth,
                                     _T("Fourth dummy item\tCtrl-F4")));
-    menu->Insert(1, wxMenuItem::New(menu, wxID_SEPARATOR, _T("")));
+    menu->Insert(1, wxMenuItem::New(menu, wxID_SEPARATOR));
 }
 
 void MyFrame::OnEnableMenuItem(wxCommandEvent& WXUNUSED(event))
@@ -898,7 +971,7 @@ void MyFrame::OnFindMenuItem(wxCommandEvent& WXUNUSED(event))
                      (
                         _T("Enter label to search for: "),
                         _T("Find menu item"),
-                        _T(""),
+                        wxEmptyString,
                         this
                      );
 
@@ -926,7 +999,7 @@ void MyFrame::OnFindMenuItem(wxCommandEvent& WXUNUSED(event))
 
 void MyFrame::ShowContextMenu(const wxPoint& pos)
 {
-    wxMenu menu(_T("Test popup"));
+    wxMenu menu;
 
     menu.Append(Menu_Help_About, _T("&About"));
     menu.Append(Menu_Popup_Submenu, _T("&Submenu"), CreateDummyMenu(NULL));
@@ -990,7 +1063,6 @@ void MyFrame::OnUpdateSubMenuNormal(wxUpdateUIEvent& event)
 void MyFrame::OnUpdateSubMenuCheck(wxUpdateUIEvent& event)
 {
     event.Enable(true);
-    event.Check(true);
 }
 
 void MyFrame::OnUpdateSubMenuRadio(wxUpdateUIEvent& event)
