@@ -4,7 +4,7 @@
 // Author:      Guillermo Rodriguez Garcia <guille@iies.es>
 // Modified by:
 // Created:     1999/09/19
-// RCS-ID:      $Id: client.cpp,v 1.29 2005/03/30 19:10:46 ABX Exp $
+// RCS-ID:      $Id: client.cpp,v 1.33 2005/09/23 12:52:25 MR Exp $
 // Copyright:   (c) 1999 Guillermo Rodriguez Garcia
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -17,11 +17,6 @@
 // headers
 // --------------------------------------------------------------------------
 
-#if defined(__GNUG__) && !defined(__APPLE__)
-    #pragma implementation
-    #pragma interface
-#endif
-
 // For compilers that support precompilation, includes "wx/wx.h".
 #include "wx/wxprec.h"
 
@@ -112,9 +107,9 @@ private:
 enum
 {
   // menu items
-  CLIENT_QUIT = 1000,
-  CLIENT_ABOUT,
-  CLIENT_OPEN,
+  CLIENT_QUIT = wxID_EXIT,
+  CLIENT_ABOUT = wxID_ABOUT,
+  CLIENT_OPEN = 100,
   CLIENT_TEST1,
   CLIENT_TEST2,
   CLIENT_TEST3,
@@ -290,7 +285,7 @@ void MyFrame::OnOpenConnection(wxCommandEvent& WXUNUSED(event))
   //
   // Connect(addr, false) will issue a nonblocking connection request
   // and return immediately. If the return value is true, then the
-  // connection has been already succesfully established. If it is
+  // connection has been already successfully established. If it is
   // false, you must wait for the request to complete, either with
   // WaitOnConnect() or by watching wxSOCKET_CONNECTION / LOST
   // events (please read the documentation).
@@ -585,7 +580,7 @@ void MyFrame::OnTestURL(wxCommandEvent& WXUNUSED(event))
   wxYield();
 
   // Get the data
-  wxFile fileTest(wxT("test.url"));
+  wxFile fileTest(wxT("test.url"), wxFile::write);
   wxFileOutputStream sout(fileTest);
   if (!sout.Ok())
   {
