@@ -1,38 +1,43 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        font.cpp
+// Name:        src/mac/carbon/font.cpp
 // Purpose:     wxFont class
 // Author:      Stefan Csomor
 // Modified by:
 // Created:     1998-01-01
-// RCS-ID:      $Id: font.cpp,v 1.36 2005/07/28 22:08:10 VZ Exp $
+// RCS-ID:      $Id: font.cpp,v 1.53.4.5 2007/03/15 09:40:24 JS Exp $
 // Copyright:   (c) Stefan Csomor
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-#pragma implementation "font.h"
-#endif
-
 #include "wx/wxprec.h"
 
-#include "wx/string.h"
 #include "wx/font.h"
-#include "wx/fontutil.h"
-#include "wx/gdicmn.h"
-#include "wx/utils.h"
+
+#ifndef WX_PRECOMP
+    #include "wx/string.h"
+    #include "wx/utils.h"
+    #include "wx/intl.h"
+    #include "wx/gdicmn.h"
+#endif
 
 #include "wx/fontutil.h"
+#include "wx/graphics.h"
+#include "wx/log.h"
 
 #include "wx/mac/private.h"
+
 #ifndef __DARWIN__
 #include <ATSUnicode.h>
 #endif
 
+
 IMPLEMENT_DYNAMIC_CLASS(wxFont, wxGDIObject)
 
+
 class WXDLLEXPORT wxFontRefData: public wxGDIRefData
 {
     friend class WXDLLEXPORT wxFont;
+
 public:
     wxFontRefData()
         : m_fontId(0)
@@ -40,10 +45,10 @@ public:
         , m_family(wxDEFAULT)
         , m_style(wxNORMAL)
         , m_weight(wxNORMAL)
-        , m_underlined(FALSE)
+        , m_underlined(false)
         , m_faceName(wxT("applicationfont"))
         , m_encoding(wxFONTENCODING_DEFAULT)
-        , m_macFontNum(0)
+        , m_macFontFamily(0)
         , m_macFontSize(0)
         , m_macFontStyle(0)
         , m_macATSUStyle(0)
@@ -63,7 +68,7 @@ public:
         , m_underlined(data.m_underlined)
         , m_faceName(data.m_faceName)
         , m_encoding(data.m_encoding)
-        , m_macFontNum(data.m_macFontNum)
+        , m_macFontFamily(data.m_macFontFamily)
         , m_macFontSize(data.m_macFontSize)
         , m_macFontStyle(data.m_macFontStyle)
         , m_macATSUStyle(0)
@@ -88,7 +93,7 @@ public:
         , m_underlined(underlined)
         , m_faceName(faceName)
         , m_encoding(encoding)
-        , m_macFontNum(0)
+        , m_macFontFamily(0)
         , m_macFontSize(0)
         , m_macFontStyle(0)
         , m_macATSUStyle(0)
@@ -98,9 +103,15 @@ public:
     }
 
     virtual ~wxFontRefData();
-    void SetNoAntiAliasing( bool no = TRUE ) { m_noAA = no; }
-    bool GetNoAntiAliasing() const { return m_noAA; }
-    
+
+    void SetNoAntiAliasing( bool no = true )
+    { m_noAA = no; }
+
+    bool GetNoAntiAliasing() const
+    { return m_noAA; }
+
+    void MacFindFont();
+
 protected:
     // common part of all ctors
     void Init(int size,
@@ -121,31 +132,32 @@ protected:
     wxString        m_faceName;
     wxFontEncoding  m_encoding;
     bool            m_noAA;      // No anti-aliasing
-    
+
 public:
-    short           m_macFontNum;
-    short           m_macFontSize;
-    Style           m_macFontStyle;
-    
+    FMFontFamily    m_macFontFamily;
+    FMFontSize      m_macFontSize;
+    FMFontStyle     m_macFontStyle;
+
     // ATSU Font Information
-    
+
     // this is split into an ATSU font id that may
     // contain some styles (special bold fonts etc) and
     // these are the additional qd styles that are not
     // included in the ATSU font id
     ATSUStyle       m_macATSUStyle ;
     ATSUFontID      m_macATSUFontID;
-    Style           m_macATSUAdditionalQDStyles ;
-    
+    FMFontStyle     m_macATSUAdditionalQDStyles ;
+
     // for true themeing support we must store the correct font
     // information here, as this speeds up and optimizes rendering
     ThemeFontID     m_macThemeFontID ;
-   
-    wxNativeFontInfo  m_info;
 
-public:
-    void        MacFindFont() ;
+    wxNativeFontInfo  m_info;
 };
+
+#define M_FONTDATA ((wxFontRefData*)m_refData)
+
+
 // ============================================================================
 // implementation
 // ============================================================================
@@ -155,12 +167,12 @@ public:
 // ----------------------------------------------------------------------------
 
 void wxFontRefData::Init(int pointSize,
-                         int family,
-                         int style,
-                         int weight,
-                         bool underlined,
-                         const wxString& faceName,
-                         wxFontEncoding encoding)
+    int family,
+    int style,
+    int weight,
+    bool underlined,
+    const wxString& faceName,
+    wxFontEncoding encoding)
 {
     m_style = style;
     m_pointSize = pointSize;
@@ -171,15 +183,15 @@ void wxFontRefData::Init(int pointSize,
     m_faceName = faceName;
     m_encoding = encoding;
 
-    m_macFontNum = 0 ;
+    m_macFontFamily = 0 ;
     m_macFontSize = 0;
     m_macFontStyle = 0;
     m_macATSUFontID = 0;
     m_macATSUAdditionalQDStyles = 0 ;
     m_macATSUStyle = NULL ;
-    
+
     m_macThemeFontID = kThemeCurrentPortFont ;
-    m_noAA = FALSE;
+    m_noAA = false;
 }
 
 wxFontRefData::~wxFontRefData()
@@ -193,11 +205,15 @@ wxFontRefData::~wxFontRefData()
 
 void wxFontRefData::MacFindFont()
 {
-    if ( m_macThemeFontID != kThemeCurrentPortFont ) 
+    OSStatus status ;
+
+    Str255 qdFontName ;
+    if ( m_macThemeFontID != kThemeCurrentPortFont )
     {
-        Str255 fontName ;
-    	GetThemeFont(m_macThemeFontID , GetApplicationScript() , fontName , &m_macFontSize , &m_macFontStyle ) ;
-        m_faceName = wxMacMakeStringFromPascal( fontName ) ;
+        Style style ;
+        GetThemeFont( m_macThemeFontID, GetApplicationScript(), qdFontName, &m_macFontSize, &style );
+        m_macFontStyle = style ;
+        m_faceName = wxMacMakeStringFromPascal( qdFontName );
         if ( m_macFontStyle & bold )
             m_weight = wxBOLD ;
         else
@@ -206,140 +222,143 @@ void wxFontRefData::MacFindFont()
             m_style = wxITALIC ;
         if ( m_macFontStyle & underline )
             m_underlined = true ;
-        ::GetFNum( fontName, &m_macFontNum);
         m_pointSize = m_macFontSize ;
+#ifndef __LP64__
+        m_macFontFamily = FMGetFontFamilyFromName( qdFontName );
+#endif
     }
     else
     {
-        if( m_faceName.Length() == 0 )
+        if ( m_faceName.empty() )
         {
-            switch( m_family )
+            if ( m_family == wxDEFAULT )
             {
-                case wxDEFAULT :
-                    m_macFontNum = ::GetAppFont() ;
-                    break ;
-                case wxSCRIPT :
-                case wxROMAN :
-                case wxDECORATIVE :
-#ifdef __WXMAC_OSX__
-                    ::GetFNum( "\pTimes" , &m_macFontNum) ;
-#else
-                    ::GetFNum( "\pTimes" , &m_macFontNum) ;
+#ifndef __LP64__
+                m_macFontFamily = GetAppFont();
+                FMGetFontFamilyName(m_macFontFamily,qdFontName);
+                m_faceName = wxMacMakeStringFromPascal( qdFontName );
+#endif
+            }
+            else
+            {
+                switch ( m_family )
+                {
+                    case wxSCRIPT :
+                    case wxROMAN :
+                    case wxDECORATIVE :
+                        m_faceName = wxT("Times");
+                        break ;
+
+                    case wxSWISS :
+                        m_faceName =  wxT("Lucida Grande");
+                        break ;
+
+                    case wxMODERN :
+                    case wxTELETYPE:
+                        m_faceName =  wxT("Monaco");
+                        break ;
+
+                    default:
+                        m_faceName =  wxT("Times");
+                        break ;
+                }
+#ifndef __LP64__
+                wxMacStringToPascal( m_faceName , qdFontName );
+                m_macFontFamily = FMGetFontFamilyFromName( qdFontName );
+                if ( m_macFontFamily == kInvalidFontFamily )
+                {
+                    wxLogDebug( wxT("ATSFontFamilyFindFromName failed for %s"), m_faceName );
+                    m_macFontFamily = GetAppFont();
+                }
 #endif
-                    break ;
-                case wxSWISS :
-#ifdef __WXMAC_OSX__
-                    ::GetFNum( "\pLucida Grande" , &m_macFontNum) ;
-#else
-                    ::GetFNum( "\pGeneva" , &m_macFontNum) ;
-#endif
-                    break ;
-                case wxMODERN :
-#ifdef __WXMAC_OSX__
-                    ::GetFNum( "\pMonaco" , &m_macFontNum) ;
-#else
-                    ::GetFNum( "\pMonaco" , &m_macFontNum) ;
-#endif
-                    break ;
             }
-            Str255 name ;
-            ::GetFontName( m_macFontNum , name ) ;
-            m_faceName = wxMacMakeStringFromPascal( name ) ;
         }
         else
         {
+#ifndef __LP64__
             if ( m_faceName == wxT("systemfont") )
-                m_macFontNum = ::GetSysFont() ;
+                m_macFontFamily = GetSysFont();
             else if ( m_faceName == wxT("applicationfont") )
-                m_macFontNum = ::GetAppFont() ;
+                m_macFontFamily = GetAppFont();
             else
+#else
+            if ( m_faceName == wxT("systemfont") )
+                m_faceName =  wxT("Lucida Grande");
+            else if ( m_faceName == wxT("applicationfont") )
+                m_faceName =  wxT("Lucida Grande");
+#endif
             {
-                Str255 fontname ;
-                wxMacStringToPascal( m_faceName , fontname ) ;
-                ::GetFNum( fontname, &m_macFontNum);
+                wxMacCFStringHolder cf( m_faceName, wxLocale::GetSystemEncoding() );
+                ATSFontFamilyRef atsfamily = ATSFontFamilyFindFromName( cf , kATSOptionFlagsDefault );
+                if ( atsfamily == (ATSFontFamilyRef) -1 )
+                {
+                    wxLogDebug( wxT("ATSFontFamilyFindFromName failed for %s"), m_faceName );
+                    m_macFontFamily = GetAppFont();
+                }
+                else
+                    m_macFontFamily = FMGetFontFamilyFromATSFontFamilyRef( atsfamily );
             }
         }
 
         m_macFontStyle = 0;
         if (m_weight == wxBOLD)
              m_macFontStyle |= bold;
-        if (m_style == wxITALIC || m_style == wxSLANT) 
+        if (m_style == wxITALIC || m_style == wxSLANT)
             m_macFontStyle |= italic;
-        if (m_underlined) 
+        if (m_underlined)
             m_macFontStyle |= underline;
         m_macFontSize = m_pointSize ;
     }
 
     // we try to get as much styles as possible into ATSU
 
-    Fixed atsuSize = IntToFixed( m_macFontSize ) ;
 
-    Style atsuStyle = normal ;
-    verify_noerr(::ATSUFONDtoFontID(m_macFontNum, atsuStyle , (UInt32*)&m_macATSUFontID) ); 
-    if ( m_macFontStyle & bold )
-    {
-        ATSUFontID test ;
-        if ( ::ATSUFONDtoFontID(m_macFontNum, atsuStyle | bold , &test) == noErr )
-        {
-            atsuStyle |= bold ;
-            m_macATSUFontID = test ;
-        }
-    }
-    if ( m_macFontStyle & italic )
-    {
-        ATSUFontID test ;
-        if ( ::ATSUFONDtoFontID(m_macFontNum, atsuStyle | italic , &test) == noErr )
-        {
-            atsuStyle |= italic ;
-            m_macATSUFontID = test ;
-        }
-    }
-    if ( m_macFontStyle & underline )
-    {
-        ATSUFontID test ;
-        if ( ::ATSUFONDtoFontID(m_macFontNum, atsuStyle | underline , &test) == noErr )
-        {
-            atsuStyle |= underline ;
-            m_macATSUFontID = test ;
-        }
-    }
-    
-    m_macATSUAdditionalQDStyles = m_macFontStyle & (~atsuStyle ) ;
+    // ATSUFontID and FMFont are equivalent
+    FMFontStyle intrinsicStyle = 0 ;
+#ifndef __LP64__
+    status = FMGetFontFromFontFamilyInstance( m_macFontFamily , m_macFontStyle , &m_macATSUFontID , &intrinsicStyle);
+    wxASSERT_MSG( status == noErr , wxT("couldn't get an ATSUFont from font family") );
+#endif
+    m_macATSUAdditionalQDStyles = m_macFontStyle & (~intrinsicStyle );
 
     if ( m_macATSUStyle )
     {
         ::ATSUDisposeStyle((ATSUStyle)m_macATSUStyle);
         m_macATSUStyle = NULL ;
     }
-    OSStatus status = ::ATSUCreateStyle((ATSUStyle *)&m_macATSUStyle) ;
-    wxASSERT_MSG( status == noErr , wxT("couldn't create ATSU style") ) ;
+
+    status = ::ATSUCreateStyle((ATSUStyle *)&m_macATSUStyle);
+    wxASSERT_MSG( status == noErr , wxT("couldn't create ATSU style") );
+
     ATSUAttributeTag atsuTags[] =
     {
-            kATSUFontTag ,
-            kATSUSizeTag ,
-            kATSUVerticalCharacterTag,
-            kATSUQDBoldfaceTag ,
-            kATSUQDItalicTag ,
-            kATSUQDUnderlineTag ,
-            kATSUQDCondensedTag ,
-            kATSUQDExtendedTag ,
-    } ;
-    ByteCount atsuSizes[sizeof(atsuTags)/sizeof(ATSUAttributeTag)] =
+        kATSUFontTag ,
+        kATSUSizeTag ,
+        kATSUVerticalCharacterTag,
+        kATSUQDBoldfaceTag ,
+        kATSUQDItalicTag ,
+        kATSUQDUnderlineTag ,
+        kATSUQDCondensedTag ,
+        kATSUQDExtendedTag ,
+    };
+    ByteCount atsuSizes[sizeof(atsuTags) / sizeof(ATSUAttributeTag)] =
     {
-            sizeof( ATSUFontID ) ,
-            sizeof( Fixed ) ,
-            sizeof( ATSUVerticalCharacterType),
-            sizeof( Boolean ) ,
-            sizeof( Boolean ) ,
-            sizeof( Boolean ) ,
-            sizeof( Boolean ) ,
-            sizeof( Boolean ) ,
-    } ;
+        sizeof( ATSUFontID ) ,
+        sizeof( Fixed ) ,
+        sizeof( ATSUVerticalCharacterType),
+        sizeof( Boolean ) ,
+        sizeof( Boolean ) ,
+        sizeof( Boolean ) ,
+        sizeof( Boolean ) ,
+        sizeof( Boolean ) ,
+    };
+
     Boolean kTrue = true ;
     Boolean kFalse = false ;
 
+    Fixed atsuSize = IntToFixed( m_macFontSize );
     ATSUVerticalCharacterType kHorizontal = kATSUStronglyHorizontal;
-    ATSUAttributeValuePtr    atsuValues[sizeof(atsuTags)/sizeof(ATSUAttributeTag)] =
+    ATSUAttributeValuePtr    atsuValues[sizeof(atsuTags) / sizeof(ATSUAttributeTag)] =
     {
             &m_macATSUFontID ,
             &atsuSize ,
@@ -349,25 +368,25 @@ void wxFontRefData::MacFindFont()
             (m_macATSUAdditionalQDStyles & underline) ? &kTrue : &kFalse ,
             (m_macATSUAdditionalQDStyles & condense) ? &kTrue : &kFalse ,
             (m_macATSUAdditionalQDStyles & extend) ? &kTrue : &kFalse ,
-    } ;
-    status = ::ATSUSetAttributes((ATSUStyle)m_macATSUStyle, sizeof(atsuTags)/sizeof(ATSUAttributeTag) ,
+    };
+
+    status = ::ATSUSetAttributes(
+        (ATSUStyle)m_macATSUStyle,
+        sizeof(atsuTags) / sizeof(ATSUAttributeTag) ,
         atsuTags, atsuSizes, atsuValues);
 
-    wxASSERT_MSG( status == noErr , wxT("couldn't Modify ATSU style") ) ;
+    wxASSERT_MSG( status == noErr , wxT("couldn't modify ATSU style") );
 }
 
 // ----------------------------------------------------------------------------
 // wxFont
 // ----------------------------------------------------------------------------
 
-void wxFont::Init()
-{
-}
-
 bool wxFont::Create(const wxNativeFontInfo& info)
 {
-    return Create(info.pointSize, info.family, info.style, info.weight,
-                  info.underlined, info.faceName, info.encoding);
+    return Create(
+        info.pointSize, info.family, info.style, info.weight,
+        info.underlined, info.faceName, info.encoding );
 }
 
 wxFont::wxFont(const wxString& fontdesc)
@@ -378,30 +397,36 @@ wxFont::wxFont(const wxString& fontdesc)
 }
 
 bool wxFont::Create(int pointSize,
-                    int family,
-                    int style,
-                    int weight,
-                    bool underlined,
-                    const wxString& faceName,
-                    wxFontEncoding encoding)
+    int family,
+    int style,
+    int weight,
+    bool underlined,
+    const wxString& faceName,
+    wxFontEncoding encoding)
 {
     UnRef();
-    m_refData = new wxFontRefData(pointSize, family, style, weight,
-                                  underlined, faceName, encoding);
+
+    m_refData = new wxFontRefData(
+        pointSize, family, style, weight,
+        underlined, faceName, encoding);
 
     RealizeResource();
 
-    return TRUE;
+    return true;
 }
 
-bool wxFont::MacCreateThemeFont(wxUint16 themeFontID )
+bool wxFont::MacCreateThemeFont(wxUint16 themeFontID)
 {
     UnRef();
-    m_refData = new wxFontRefData(12, wxDEFAULT , wxFONTSTYLE_NORMAL , wxFONTWEIGHT_NORMAL ,false, wxEmptyString, wxFONTENCODING_DEFAULT);
+
+    m_refData = new wxFontRefData(
+        12, wxDEFAULT, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_NORMAL,
+        false, wxEmptyString, wxFONTENCODING_DEFAULT );
+
     M_FONTDATA->m_macThemeFontID = themeFontID ;
     RealizeResource();
 
-    return TRUE;
+    return true;
 }
 
 wxFont::~wxFont()
@@ -410,8 +435,9 @@ wxFont::~wxFont()
 
 bool wxFont::RealizeResource()
 {
-    M_FONTDATA->MacFindFont() ;
-    return TRUE;
+    M_FONTDATA->MacFindFont();
+
+    return true;
 }
 
 void wxFont::SetEncoding(wxFontEncoding encoding)
@@ -474,13 +500,15 @@ void wxFont::SetWeight(int weight)
     RealizeResource();
 }
 
-void wxFont::SetFaceName(const wxString& faceName)
+bool wxFont::SetFaceName(const wxString& faceName)
 {
     Unshare();
 
     M_FONTDATA->m_faceName = faceName;
 
     RealizeResource();
+
+    return wxFontBase::SetFaceName(faceName);
 }
 
 void wxFont::SetUnderlined(bool underlined)
@@ -510,95 +538,123 @@ void wxFont::SetNoAntiAliasing( bool no )
 int wxFont::GetPointSize() const
 {
     wxCHECK_MSG( M_FONTDATA != NULL , 0, wxT("invalid font") );
+
     return M_FONTDATA->m_pointSize;
 }
 
+wxSize wxFont::GetPixelSize() const
+{
+#if wxUSE_GRAPHICS_CONTEXT
+    // TODO: consider caching the value
+    wxGraphicsContext* dc = wxGraphicsContext::CreateFromNative((CGContextRef) NULL);
+    dc->SetFont(*(wxFont *)this,*wxBLACK);
+    wxDouble width, height = 0;
+    dc->GetTextExtent( wxT("g"), &width, &height, NULL, NULL);
+    return wxSize((int)width, (int)height);
+#else
+    wxFontBase::GetPixelSize();
+#endif
+}
+
 int wxFont::GetFamily() const
 {
     wxCHECK_MSG( M_FONTDATA != NULL , 0, wxT("invalid font") );
+
     return M_FONTDATA->m_family;
 }
 
 int wxFont::GetStyle() const
 {
     wxCHECK_MSG( M_FONTDATA != NULL , 0, wxT("invalid font") );
+
     return M_FONTDATA->m_style;
 }
 
 int wxFont::GetWeight() const
 {
     wxCHECK_MSG( M_FONTDATA != NULL , 0, wxT("invalid font") );
+
     return M_FONTDATA->m_weight;
 }
 
 bool wxFont::GetUnderlined() const
 {
     wxCHECK_MSG( M_FONTDATA != NULL , false, wxT("invalid font") );
+
     return M_FONTDATA->m_underlined;
 }
 
 wxString wxFont::GetFaceName() const
 {
     wxCHECK_MSG( M_FONTDATA != NULL , wxEmptyString , wxT("invalid font") );
+
     return M_FONTDATA->m_faceName;
 }
 
 wxFontEncoding wxFont::GetEncoding() const
 {
     wxCHECK_MSG( M_FONTDATA != NULL , wxFONTENCODING_DEFAULT , wxT("invalid font") );
+
     return M_FONTDATA->m_encoding;
 }
 
 bool wxFont::GetNoAntiAliasing() const
 {
     wxCHECK_MSG( M_FONTDATA != NULL , false, wxT("invalid font") );
+
     return M_FONTDATA->m_noAA;
 }
 
 short wxFont::MacGetFontNum() const
 {
     wxCHECK_MSG( M_FONTDATA != NULL , 0, wxT("invalid font") );
-    return M_FONTDATA->m_macFontNum;
+
+    return M_FONTDATA->m_macFontFamily;
 }
 
 short wxFont::MacGetFontSize() const
 {
     wxCHECK_MSG( M_FONTDATA != NULL , 0, wxT("invalid font") );
+
     return M_FONTDATA->m_macFontSize;
 }
 
 wxByte wxFont::MacGetFontStyle() const
 {
     wxCHECK_MSG( M_FONTDATA != NULL , 0, wxT("invalid font") );
+
     return M_FONTDATA->m_macFontStyle;
 }
 
 wxUint32 wxFont::MacGetATSUFontID() const
 {
     wxCHECK_MSG( M_FONTDATA != NULL , 0, wxT("invalid font") );
+
     return M_FONTDATA->m_macATSUFontID;
 }
 
-void* wxFont::MacGetATSUStyle() const
+void * wxFont::MacGetATSUStyle() const
 {
     wxCHECK_MSG( M_FONTDATA != NULL , NULL, wxT("invalid font") );
+
     return M_FONTDATA->m_macATSUStyle;
 }
 
 wxUint32 wxFont::MacGetATSUAdditionalQDStyles() const
 {
     wxCHECK_MSG( M_FONTDATA != NULL , 0, wxT("invalid font") );
+
     return M_FONTDATA->m_macATSUAdditionalQDStyles;
 }
 
-wxUint16 wxFont::MacGetThemeFontID() const 
+wxUint16 wxFont::MacGetThemeFontID() const
 {
     wxCHECK_MSG( M_FONTDATA != NULL , 0, wxT("invalid font") );
+
     return M_FONTDATA->m_macThemeFontID;
 }
 
-
-const wxNativeFontInfo *wxFont::GetNativeFontInfo() const
+const wxNativeFontInfo * wxFont::GetNativeFontInfo() const
 {
     wxCHECK_MSG( M_FONTDATA != NULL , NULL, wxT("invalid font") );
     wxCHECK_MSG( Ok(), NULL, wxT("invalid font") );
@@ -607,4 +663,3 @@ const wxNativeFontInfo *wxFont::GetNativeFontInfo() const
 
     return &(M_FONTDATA->m_info);
 }
-
