@@ -1,22 +1,26 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        button.cpp
+// Name:        src/mac/classic/button.cpp
 // Purpose:     wxButton
 // Author:      Stefan Csomor
 // Modified by:
 // Created:     1998-01-01
-// RCS-ID:      $Id: button.cpp,v 1.6 2005/07/28 22:08:20 VZ Exp $
+// RCS-ID:      $Id: button.cpp,v 1.10 2006/07/25 01:31:07 VZ Exp $
 // Copyright:   (c) Stefan Csomor
-// Licence:       wxWindows licence
+// Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
-#ifdef __GNUG__
-#pragma implementation "button.h"
+#include "wx/wxprec.h"
+
+#ifdef __BORLANDC__
+    #pragma hdrstop
 #endif
 
-#include "wx/defs.h"
-
 #include "wx/button.h"
-#include "wx/panel.h"
+
+#ifndef WX_PRECOMP
+    #include "wx/panel.h"
+#endif
+
 #include "wx/stockitem.h"
 
 IMPLEMENT_DYNAMIC_CLASS(wxButton, wxControl)
@@ -36,7 +40,7 @@ bool wxButton::Create(wxWindow *parent, wxWindowID id, const wxString& lbl,
     wxString label(lbl);
     if (label.empty() && wxIsStockID(id))
         label = wxGetStockLabel(id);
-    
+
     if ( !wxButtonBase::Create(parent, id, pos, size, style, validator, name) )
         return false;
 
@@ -48,27 +52,26 @@ bool wxButton::Create(wxWindow *parent, wxWindowID id, const wxString& lbl,
         m_macHorizontalBorder = kMacOSXHorizontalBorder;
         m_macVerticalBorder = kMacOSXVerticalBorder;
     }
-    
+
     MacPreControlCreate( parent , id ,  label , pos , size ,style, validator , name , &bounds , title ) ;
 
-    m_macControl = (WXWidget) ::NewControl( MAC_WXHWND(parent->MacGetRootWindow()) , &bounds , title , false , 0 , 0 , 1, 
+    m_macControl = (WXWidget) ::NewControl( MAC_WXHWND(parent->MacGetRootWindow()) , &bounds , title , false , 0 , 0 , 1,
           kControlPushButtonProc , (long) this ) ;
     wxASSERT_MSG( (ControlHandle) m_macControl != NULL , wxT("No valid mac control") ) ;
-    
+
     MacPostControlCreate() ;
-    
-  return TRUE;
+
+    return true;
 }
 
 void wxButton::SetDefault()
 {
-    wxWindow *parent = GetParent();
+    wxTopLevelWindow *tlw = wxDynamicCast(wxGetTopLevelParent(this), wxTopLevelWindow);
     wxButton *btnOldDefault = NULL;
-    if ( parent )
+    if ( tlw )
     {
-        btnOldDefault = wxDynamicCast(parent->GetDefaultItem(),
-           wxButton);
-        parent->SetDefaultItem(this);
+        btnOldDefault = wxDynamicCast(tlw->GetDefaultItem(), wxButton);
+        tlw->SetDefaultItem(this);
     }
 
     Boolean inData;
@@ -88,18 +91,18 @@ void wxButton::SetDefault()
 
 wxSize wxButton::DoGetBestSize() const
 {
-  wxSize sz = GetDefaultSize() ;
-  
-  int wBtn = m_label.Length() * 8 + 12 + 2 * kMacOSXHorizontalBorder ;
-    
-  if (wBtn > sz.x) sz.x = wBtn;
-  
-  return sz ;
+    wxSize sz = GetDefaultSize() ;
+
+    int wBtn = m_label.length() * 8 + 12 + 2 * kMacOSXHorizontalBorder ;
+
+    if (wBtn > sz.x) sz.x = wBtn;
+
+    return sz ;
 }
 
 wxSize wxButton::GetDefaultSize()
 {
-    int wBtn = 70 ; 
+    int wBtn = 70 ;
     int hBtn = 20 ;
 
     if ( UMAHasAquaLayout() )
@@ -123,7 +126,7 @@ void wxButton::Command (wxCommandEvent & event)
     ProcessCommand (event);
 }
 
-void wxButton::MacHandleControlClick( WXWidget WXUNUSED(control) , wxInt16 controlpart , bool WXUNUSED(mouseStillDown) ) 
+void wxButton::MacHandleControlClick( WXWidget WXUNUSED(control) , wxInt16 controlpart , bool WXUNUSED(mouseStillDown) )
 {
     if ( controlpart != kControlNoPart )
     {
@@ -132,4 +135,3 @@ void wxButton::MacHandleControlClick( WXWidget WXUNUSED(control) , wxInt16 contr
         ProcessCommand(event);
     }
 }
-
