@@ -5,15 +5,11 @@
 // Author:      Stefan Csomor
 // Modified by:
 // Created:     1998-01-01
-// RCS-ID:      $Id: colordlg.cpp,v 1.4 2005/07/28 22:08:20 VZ Exp $
+// RCS-ID:      $Id: colordlg.cpp,v 1.5 2005/09/23 12:54:20 MR Exp $
 // Copyright:   (c) Stefan Csomor
 // Licence:       wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
-#ifdef __GNUG__
-#pragma implementation "colordlg.h"
-#endif
-
 #include "wx/mac/colordlg.h"
 
 IMPLEMENT_DYNAMIC_CLASS(wxColourDialog, wxDialog)
