@@ -1,19 +1,19 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        statbox.cpp
+// Name:        src/mac/classic/statbox.cpp
 // Purpose:     wxStaticBox
 // Author:      Stefan Csomor
 // Modified by:
 // Created:     1998-01-01
-// RCS-ID:      $Id: statbox.cpp,v 1.5 2005/07/28 22:08:24 VZ Exp $
+// RCS-ID:      $Id: statbox.cpp,v 1.7 2006/04/18 09:05:00 ABX Exp $
 // Copyright:   (c) Stefan Csomor
-// Licence:       wxWindows licence
+// Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
-#ifdef __GNUG__
-#pragma implementation "statbox.h"
-#endif
+#include "wx/wxprec.h"
 
-#include "wx/defs.h"
+#ifdef __BORLANDC__
+    #pragma hdrstop
+#endif
 
 #include "wx/statbox.h"
 #include "wx/mac/uma.h"
@@ -27,7 +27,7 @@ END_EVENT_TABLE()
 /*
  * Static box
  */
- 
+
 bool wxStaticBox::Create(wxWindow *parent, wxWindowID id,
            const wxString& label,
            const wxPoint& pos,
@@ -41,13 +41,13 @@ bool wxStaticBox::Create(wxWindow *parent, wxWindowID id,
 
     Rect bounds ;
     Str255 title ;
-    
+
     MacPreControlCreate( parent , id ,  label , pos , size ,style, wxDefaultValidator , name , &bounds , title ) ;
-    
-    m_macControl = (WXWidget) ::NewControl( MAC_WXHWND(parent->MacGetRootWindow()) , &bounds , title , false , 0 , 0 , 1, 
+
+    m_macControl = (WXWidget) ::NewControl( MAC_WXHWND(parent->MacGetRootWindow()) , &bounds , title , false , 0 , 0 , 1,
         kControlGroupBoxTextTitleProc , (long) this ) ;
-    
+
     MacPostControlCreate() ;
-    
-    return TRUE;
+
+    return true;
 }
