@@ -1,16 +1,16 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        dcclient.cpp
+// Name:        src/motif/dcclient.cpp
 // Purpose:     wxClientDC class
 // Author:      Julian Smart
 // Modified by:
 // Created:     01/02/97
-// RCS-ID:      $Id: dcclient.cpp,v 1.67 2005/09/18 01:19:27 VZ Exp $
+// RCS-ID:      $Id: dcclient.cpp,v 1.80 2006/10/30 22:58:02 VZ Exp $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
 /*
-  About pens, brushes, and the autoSetting flag:
+  About pens, brushes, and the m_autoSetting flag:
 
   Under X, pens and brushes control some of the same X drawing
   parameters.  Therefore, it is impossible to independently maintain
@@ -18,9 +18,9 @@
   the current logical function. The m_currentFill, etc. instance
   variables remember state across the brush and pen.
 
-  Since pens are used more than brushes, the autoSetting flag is used to
+  Since pens are used more than brushes, the m_autoSetting flag is used to
   indicate that a brush was recently used, and SetPen must be called to
-  reinstall the current pen's parameters. If autoSetting includes 0x2, then the
+  reinstall the current pen's parameters. If m_autoSetting includes 0x2, then the
   pens color may need to be set based on XOR.
 
   There is, unfortunately, some confusion between setting the current pen/brush
@@ -36,20 +36,19 @@
 // headers
 // ----------------------------------------------------------------------------
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-    #pragma implementation "dcclient.h"
-#endif
-
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
 #include "wx/dcclient.h"
-#include "wx/dcmemory.h"
-#include "wx/window.h"
-#include "wx/app.h"
-#include "wx/image.h"
-#include "wx/log.h"
-#include "wx/math.h"
+
+#ifndef WX_PRECOMP
+    #include "wx/log.h"
+    #include "wx/app.h"
+    #include "wx/window.h"
+    #include "wx/dcmemory.h"
+    #include "wx/math.h"
+    #include "wx/image.h"
+#endif
 
 #ifdef __VMS__
 #pragma message disable nosimpint
@@ -153,7 +152,6 @@ void wxWindowDC::Init()
     m_display = (WXDisplay*) NULL;
     m_pixmap = (WXPixmap) 0;
     m_autoSetting = 0;
-    m_oldFont = (WXFont) 0;
     m_ok = false;
     m_clipRegion = (WXRegion) 0;
 }
@@ -197,7 +195,7 @@ wxWindowDC::wxWindowDC( wxWindow *window )
             &gcvalues);
     }
 
-    m_backgroundPixel = (int) gcvalues.background;
+    m_backgroundPixel = gcvalues.background;
 
     SetBackground(wxBrush(m_window->GetBackgroundColour(), wxSOLID));
 }
@@ -448,8 +446,8 @@ void wxWindowDC::DoDrawLines( int n, wxPoint points[], wxCoord xoffset, wxCoord
 
         for (i = 0; i < n; i++)
         {
-            xpoints[i].x = XLOG2DEV (points[i].x + xoffset);
-            xpoints[i].y = YLOG2DEV (points[i].y + yoffset);
+            xpoints[i].x = (short)XLOG2DEV (points[i].x + xoffset);
+            xpoints[i].y = (short)YLOG2DEV (points[i].y + yoffset);
         }
         XDrawLines ((Display*) m_display, (Pixmap) m_pixmap, (GC) m_gc, xpoints, n, 0);
 
@@ -457,8 +455,8 @@ void wxWindowDC::DoDrawLines( int n, wxPoint points[], wxCoord xoffset, wxCoord
         {
             for (i = 0; i < n; i++)
             {
-                xpoints[i].x = XLOG2DEV_2 (points[i].x + xoffset);
-                xpoints[i].y = YLOG2DEV_2 (points[i].y + yoffset);
+                xpoints[i].x = (short)XLOG2DEV_2 (points[i].x + xoffset);
+                xpoints[i].y = (short)YLOG2DEV_2 (points[i].y + yoffset);
             }
             XDrawLines ((Display*) m_display, (Pixmap) m_window->GetBackingPixmap(),(GC) m_gcBacking, xpoints, n, 0);
         }
@@ -476,10 +474,10 @@ void wxWindowDC::DoDrawPolygon( int n, wxPoint points[],
     int i;
     for (i = 0; i < n; i++)
     {
-        xpoints1[i].x = XLOG2DEV (points[i].x + xoffset);
-        xpoints1[i].y = YLOG2DEV (points[i].y + yoffset);
-        xpoints2[i].x = XLOG2DEV_2 (points[i].x + xoffset);
-        xpoints2[i].y = YLOG2DEV_2 (points[i].y + yoffset);
+        xpoints1[i].x = (short)XLOG2DEV (points[i].x + xoffset);
+        xpoints1[i].y = (short)YLOG2DEV (points[i].y + yoffset);
+        xpoints2[i].x = (short)XLOG2DEV_2 (points[i].x + xoffset);
+        xpoints2[i].y = (short)YLOG2DEV_2 (points[i].y + yoffset);
         CalcBoundingBox (points[i].x + xoffset, points[i].y + yoffset);
     }
 
@@ -799,13 +797,13 @@ bool wxWindowDC::DoBlit( wxCoord xdest, wxCoord ydest,
     // foreground colour. [m_textForegroundColour] Background pixels (0)
     // will be painted with backgound colour (m_textBackgroundColour)
     // Using ::SetPen is horribly slow, so avoid doing it
-    int oldBackgroundPixel = -1;
-    int oldForegroundPixel = -1;
+    WXPixel oldBackgroundPixel = -1;
+    WXPixel oldForegroundPixel = -1;
 
     if (m_textBackgroundColour.Ok())
     {
         oldBackgroundPixel = m_backgroundPixel;
-        int pixel = m_textBackgroundColour.AllocColour(m_display);
+        WXPixel pixel = m_textBackgroundColour.AllocColour(m_display);
 
         XSetBackground ((Display*) m_display, (GC) m_gc, pixel);
         if (m_window && m_window->GetBackingPixmap())
@@ -820,7 +818,7 @@ bool wxWindowDC::DoBlit( wxCoord xdest, wxCoord ydest,
             CalculatePixel( m_textForegroundColour,
                             m_textForegroundColour, true);
 
-        int pixel = m_textForegroundColour.GetPixel();
+        WXPixel pixel = m_textForegroundColour.GetPixel();
         if (pixel > -1)
             SetForegroundPixelWithLogicalFunction(pixel);
     }
@@ -1058,7 +1056,7 @@ void wxWindowDC::DoDrawText( const wxString &text, wxCoord x, wxCoord y )
 
         if (!sameColour || !GET_OPTIMIZATION)
         {
-            int pixel = m_textBackgroundColour.AllocColour(m_display);
+            WXPixel pixel = m_textBackgroundColour.AllocColour(m_display);
             m_currentColour = m_textBackgroundColour;
 
             // Set the GC to the required colour
@@ -1091,8 +1089,8 @@ void wxWindowDC::DoDrawText( const wxString &text, wxCoord x, wxCoord y )
 
         if (!sameColour || !GET_OPTIMIZATION)
         {
-            int pixel = CalculatePixel(m_textForegroundColour,
-                                       m_currentColour, false);
+            WXPixel pixel = CalculatePixel(m_textForegroundColour,
+                                           m_currentColour, false);
 
             // Set the GC to the required colour
             if (pixel > -1)
@@ -1163,10 +1161,10 @@ void wxWindowDC::DoDrawRotatedText( const wxString &text, wxCoord x, wxCoord y,
 
     wxCHECK_RET( Ok(), "invalid dc" );
 
-    int oldBackgroundPixel = -1;
-    int oldForegroundPixel = -1;
-    int foregroundPixel = -1;
-    int backgroundPixel = -1;
+    WXPixel oldBackgroundPixel = -1;
+    WXPixel oldForegroundPixel = -1;
+    WXPixel foregroundPixel = -1;
+    WXPixel backgroundPixel = -1;
 
     if (m_textBackgroundColour.Ok())
     {
@@ -1324,7 +1322,7 @@ wxCoord wxWindowDC::GetCharWidth() const
 {
     wxCHECK_MSG( Ok(), 0, "invalid dc" );
     wxCHECK_MSG( m_font.Ok(), 0, "invalid font" );
-    
+
     int width;
 
     wxGetTextExtent (m_display, m_font, m_userScaleY * m_logicalScaleY,
@@ -1416,7 +1414,7 @@ void wxWindowDC::SetFont( const wxFont &font )
 #endif
 }
 
-void wxWindowDC::SetForegroundPixelWithLogicalFunction(int pixel)
+void wxWindowDC::SetForegroundPixelWithLogicalFunction(WXPixel pixel)
 {
     if (m_logicalFunction == wxXOR)
     {
@@ -1436,12 +1434,12 @@ void wxWindowDC::SetForegroundPixelWithLogicalFunction(int pixel)
     }
 }
 
-int wxWindowDC::CalculatePixel(wxColour& colour, wxColour& curCol,
+WXPixel wxWindowDC::CalculatePixel(wxColour& colour, wxColour& curCol,
                                bool roundToWhite) const
 {
     const unsigned char wp = (unsigned char)255;
 
-    int pixel = -1;
+    WXPixel pixel = -1;
     if(!m_colour) // Mono display
     {
         unsigned char red = colour.Red ();
@@ -1453,16 +1451,16 @@ int wxWindowDC::CalculatePixel(wxColour& colour, wxColour& curCol,
            ((red != 0 || blue != 0 || green != 0) && roundToWhite))
         {
             curCol = *wxWHITE;
-            pixel = (int)WhitePixel((Display*) m_display,
-                                    DefaultScreen((Display*) m_display));
+            pixel = WhitePixel((Display*) m_display,
+                               DefaultScreen((Display*) m_display));
             curCol.SetPixel(pixel);
             colour.SetPixel(pixel);
         }
         else
         {
             curCol = *wxBLACK;
-            pixel = (int)BlackPixel((Display*) m_display,
-                                    DefaultScreen((Display*) m_display));
+            pixel = BlackPixel((Display*) m_display,
+                               DefaultScreen((Display*) m_display));
             curCol.SetPixel(pixel);
             colour.SetPixel(pixel);
         }
@@ -1583,7 +1581,7 @@ void wxWindowDC::SetPen( const wxPen &pen )
             {
                 int factor = scaled_width == 0 ? 1 : scaled_width;
                 for (int i = 0; i < req_nb_dash; i++)
-                    real_req_dash[i] = req_dash[i] * factor;
+                    real_req_dash[i] = (wxX11Dash)(req_dash[i] * factor);
                 XSetDashes ((Display*) m_display, (GC) m_gc, 0, real_req_dash, req_nb_dash);
 
                 if (m_window && m_window->GetBackingPixmap())
@@ -1692,7 +1690,7 @@ void wxWindowDC::SetPen( const wxPen &pen )
             XSetStipple ((Display*) m_display,(GC) m_gcBacking, myStipple);
     }
     else if (m_currentStipple.Ok()
-        && ((m_currentStipple != oldStipple) || !GET_OPTIMIZATION))
+        && ((!m_currentStipple.IsSameAs(oldStipple)) || !GET_OPTIMIZATION))
     {
         XSetStipple ((Display*) m_display, (GC) m_gc, (Pixmap) m_currentStipple.GetDrawable());
 
@@ -1719,7 +1717,7 @@ void wxWindowDC::SetPen( const wxPen &pen )
     if (!sameColour || !GET_OPTIMIZATION
         || ((m_logicalFunction == wxXOR) || (m_autoSetting & 0x2)))
     {
-        int pixel = -1;
+        WXPixel pixel = -1;
         if (m_pen.GetStyle () == wxTRANSPARENT)
             pixel = m_backgroundPixel;
         else
@@ -1886,7 +1884,7 @@ void wxWindowDC::SetBrush( const wxBrush &brush )
     // must test m_logicalFunction, because it involves background!
     if (!sameColour || !GET_OPTIMIZATION || m_logicalFunction == wxXOR)
     {
-        int pixel = CalculatePixel(m_brush.GetColour(), m_currentColour, true);
+        WXPixel pixel = CalculatePixel(m_brush.GetColour(), m_currentColour, true);
 
         if (pixel > -1)
             SetForegroundPixelWithLogicalFunction(pixel);
@@ -2068,7 +2066,8 @@ void wxWindowDC::DoSetClippingRegion( wxCoord x, wxCoord y,
 {
     wxDC::DoSetClippingRegion( x, y, width, height );
 
-    wxRegion temp(x, y, width, height);
+    wxRegion temp(XLOG2DEV(x), YLOG2DEV(y),
+                  XLOG2DEVREL(width), YLOG2DEVREL(height));
 
     SetDCClipping(temp.GetX11Region());
 
@@ -2077,10 +2076,10 @@ void wxWindowDC::DoSetClippingRegion( wxCoord x, wxCoord y,
     if (m_window && m_window->GetBackingPixmap())
     {
         XRectangle rects[1];
-        rects[0].x = XLOG2DEV_2(x);
-        rects[0].y = YLOG2DEV_2(y);
-        rects[0].width = XLOG2DEVREL(width);
-        rects[0].height = YLOG2DEVREL(height);
+        rects[0].x = (short)XLOG2DEV_2(x);
+        rects[0].y = (short)YLOG2DEV_2(y);
+        rects[0].width = (unsigned short)XLOG2DEVREL(width);
+        rects[0].height = (unsigned short)YLOG2DEVREL(height);
         XSetClipRectangles((Display*) m_display, (GC) m_gcBacking,
                            0, 0, rects, 1, Unsorted);
     }
@@ -2088,21 +2087,19 @@ void wxWindowDC::DoSetClippingRegion( wxCoord x, wxCoord y,
 
 void wxWindowDC::DoSetClippingRegionAsRegion( const wxRegion& region )
 {
-    wxRect box = region.GetBox();
-
-    wxDC::DoSetClippingRegion( box.x, box.y, box.width, box.height );
-
     SetDCClipping(region.GetX11Region());
 
     // Needs to work differently for Pixmap: without this,
     // there's a nasty (Display*) m_display bug. 8/12/94
     if (m_window && m_window->GetBackingPixmap())
     {
+        wxRect box = region.GetBox();
+
         XRectangle rects[1];
-        rects[0].x = XLOG2DEV_2(box.x);
-        rects[0].y = YLOG2DEV_2(box.y);
-        rects[0].width = XLOG2DEVREL(box.width);
-        rects[0].height = YLOG2DEVREL(box.height);
+        rects[0].x = (short)XLOG2DEV_2(box.x);
+        rects[0].y = (short)YLOG2DEV_2(box.y);
+        rects[0].width = (unsigned short)XLOG2DEVREL(box.width);
+        rects[0].height = (unsigned short)YLOG2DEVREL(box.height);
         XSetClipRectangles((Display*) m_display, (GC) m_gcBacking,
                            0, 0, rects, 1, Unsorted);
     }
@@ -2174,7 +2171,7 @@ static void XCopyRemote(Display *src_display, Display *dest_display,
     static const int CACHE_SIZE = 256;
 
     unsigned int i, j;
-    unsigned long cachesrc[CACHE_SIZE], cachedest[CACHE_SIZE];
+    Pixel cachesrc[CACHE_SIZE], cachedest[CACHE_SIZE];
     int k, cache_pos, all_cache;
 
     if (!cache || !*cache)
@@ -2192,7 +2189,7 @@ static void XCopyRemote(Display *src_display, Display *dest_display,
 
     for (i = 0; i < w; i++)
         for (j = 0; j < h; j++) {
-            unsigned long pixel;
+            Pixel pixel;
             XColor xcol;
 
             pixel = XGetPixel(image, i, j);
