@@ -1,18 +1,14 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        dialog.cpp
+// Name:        src/motif/dialog.cpp
 // Purpose:     wxDialog class
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: dialog.cpp,v 1.56 2005/09/20 10:05:46 JS Exp $
+// RCS-ID:      $Id: dialog.cpp,v 1.69 2006/08/19 22:56:07 VZ Exp $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-#pragma implementation "dialog.h"
-#endif
-
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
@@ -24,9 +20,13 @@
 #endif
 
 #include "wx/dialog.h"
-#include "wx/utils.h"
-#include "wx/app.h"
-#include "wx/settings.h"
+
+#ifndef WX_PRECOMP
+    #include "wx/app.h"
+    #include "wx/utils.h"
+    #include "wx/settings.h"
+#endif
+
 #include "wx/evtloop.h"
 
 #ifdef __VMS__
@@ -66,22 +66,11 @@
 // for modal dialogs
 wxList wxModalDialogs;
 extern wxList wxModelessWindows;  // Frames and modeless dialogs
-extern wxList wxPendingDelete;
 
 #define wxUSE_INVISIBLE_RESIZE 1
 
 IMPLEMENT_DYNAMIC_CLASS(wxDialog, wxTopLevelWindow)
 
-BEGIN_EVENT_TABLE(wxDialog, wxTopLevelWindow)
-  EVT_BUTTON(wxID_OK, wxDialog::OnOK)
-  EVT_BUTTON(wxID_APPLY, wxDialog::OnApply)
-  EVT_BUTTON(wxID_CANCEL, wxDialog::OnCancel)
-  EVT_CHAR_HOOK(wxDialog::OnCharHook)
-  EVT_SYS_COLOUR_CHANGED(wxDialog::OnSysColourChanged)
-  EVT_CLOSE(wxDialog::OnCloseWindow)
-END_EVENT_TABLE()
-
-
 wxDialog::wxDialog()
 {
     m_modalShowing = false;
@@ -109,7 +98,6 @@ bool wxDialog::Create(wxWindow *parent, wxWindowID id,
     m_foregroundColour = *wxBLACK;
 
     Widget dialogShell = (Widget) m_mainWidget;
-    Widget shell = XtParent(dialogShell) ;
 
     SetTitle( title );
 
@@ -117,32 +105,33 @@ bool wxDialog::Create(wxWindow *parent, wxWindowID id,
     ChangeFont(false);
 
     // Can't remember what this was about... but I think it's necessary.
-    if (wxUSE_INVISIBLE_RESIZE)
-    {
-        if (pos.x > -1)
-            XtVaSetValues(dialogShell, XmNx, pos.x,
-            NULL);
-        if (pos.y > -1)
-            XtVaSetValues(dialogShell, XmNy, pos.y,
-            NULL);
+#if wxUSE_INVISIBLE_RESIZE
+    if (pos.x > -1)
+        XtVaSetValues(dialogShell, XmNx, pos.x,
+        NULL);
+    if (pos.y > -1)
+        XtVaSetValues(dialogShell, XmNy, pos.y,
+        NULL);
 
-        if (size.x > -1)
-            XtVaSetValues(dialogShell, XmNwidth, size.x, NULL);
-        if (size.y > -1)
-            XtVaSetValues(dialogShell, XmNheight, size.y, NULL);
-    }
+    if (size.x > -1)
+        XtVaSetValues(dialogShell, XmNwidth, size.x, NULL);
+    if (size.y > -1)
+        XtVaSetValues(dialogShell, XmNheight, size.y, NULL);
+#endif
 
     // Positioning of the dialog doesn't work properly unless the dialog
     // is managed, so we manage without mapping to the screen.
     // To show, we map the shell (actually it's parent).
-    if (!wxUSE_INVISIBLE_RESIZE)
-        XtVaSetValues(shell, XmNmappedWhenManaged, False, NULL);
+#if !wxUSE_INVISIBLE_RESIZE
+    Widget shell = XtParent(dialogShell) ;
+    XtVaSetValues(shell, XmNmappedWhenManaged, False, NULL);
+#endif
+
+#if !wxUSE_INVISIBLE_RESIZE
+    XtManageChild(dialogShell);
+    SetSize(pos.x, pos.y, size.x, size.y);
+#endif
 
-    if (!wxUSE_INVISIBLE_RESIZE)
-    {
-        XtManageChild(dialogShell);
-        SetSize(pos.x, pos.y, size.x, size.y);
-    }
     XtAddEventHandler(dialogShell,ExposureMask,False,
         wxUniversalRepaintProc, (XtPointer) this);
 
@@ -151,12 +140,12 @@ bool wxDialog::Create(wxWindow *parent, wxWindowID id,
     return true;
 }
 
-bool wxDialog::DoCreate(wxWindow* parent,
-                             wxWindowID id,
-                             const wxString& title,
-                             const wxPoint& pos,
-                             const wxSize& size,
-                             long style,
+bool wxDialog::XmDoCreateTLW(wxWindow* parent,
+                             wxWindowID WXUNUSED(id),
+                             const wxString& WXUNUSED(title),
+                             const wxPoint& WXUNUSED(pos),
+                             const wxSize& WXUNUSED(size),
+                             long WXUNUSED(style),
                              const wxString& name)
 {
     Widget parentWidget = (Widget) 0;
@@ -198,21 +187,10 @@ bool wxDialog::DoCreate(wxWindow* parent,
 
 void wxDialog::SetModal(bool flag)
 {
-#ifdef __VMS
-#pragma message disable codcauunr
-#endif
    if ( flag )
-        m_windowStyle |= wxDIALOG_MODAL ;
-    else
-        if ( m_windowStyle & wxDIALOG_MODAL )
-            m_windowStyle -= wxDIALOG_MODAL ;
-
-        wxModelessWindows.DeleteObject(this);
-        if (!flag)
-            wxModelessWindows.Append(this);
-#ifdef __VMS
-#pragma message enable codcauunr
-#endif
+       wxModelessWindows.DeleteObject(this);
+   else
+       wxModelessWindows.Append(this);
 }
 
 wxDialog::~wxDialog()
@@ -228,10 +206,13 @@ wxDialog::~wxDialog()
     }
 
     m_modalShowing = false;
-    if (!wxUSE_INVISIBLE_RESIZE && m_mainWidget)
+
+#if !wxUSE_INVISIBLE_RESIZE
+    if (m_mainWidget)
     {
         XtUnmapWidget((Widget) m_mainWidget);
     }
+#endif
 
     PreDestroy();
 
@@ -242,23 +223,6 @@ wxDialog::~wxDialog()
     }
 }
 
-// By default, pressing escape cancels the dialog
-void wxDialog::OnCharHook(wxKeyEvent& event)
-{
-    if (event.m_keyCode == WXK_ESCAPE)
-    {
-        // Behaviour changed in 2.0: we'll send a Cancel message
-        // to the dialog instead of Close.
-        wxCommandEvent cancelEvent(wxEVT_COMMAND_BUTTON_CLICKED, wxID_CANCEL);
-        cancelEvent.SetEventObject( this );
-        GetEventHandler()->ProcessEvent(cancelEvent);
-
-        return;
-    }
-    // We didn't process this event.
-    event.Skip();
-}
-
 void wxDialog::DoSetSize(int x, int y, int width, int height, int sizeFlags)
 {
     XtVaSetValues((Widget) m_mainWidget, XmNresizePolicy, XmRESIZE_ANY, NULL);
@@ -303,21 +267,23 @@ bool wxDialog::Show( bool show )
 
     if (show)
     {
-        if (!wxUSE_INVISIBLE_RESIZE)
-            XtMapWidget(XtParent((Widget) m_mainWidget));
-        else
-            XtManageChild((Widget)m_mainWidget) ;
+#if !wxUSE_INVISIBLE_RESIZE
+        XtMapWidget(XtParent((Widget) m_mainWidget));
+#else
+        XtManageChild((Widget)m_mainWidget) ;
+#endif
 
-        XRaiseWindow( XtDisplay( (Widget)m_mainWidget ), 
+        XRaiseWindow( XtDisplay( (Widget)m_mainWidget ),
                       XtWindow( (Widget)m_mainWidget) );
 
     }
     else
     {
-        if (!wxUSE_INVISIBLE_RESIZE)
-            XtUnmapWidget(XtParent((Widget) m_mainWidget));
-        else
-            XtUnmanageChild((Widget)m_mainWidget) ;
+#if !wxUSE_INVISIBLE_RESIZE
+        XtUnmapWidget(XtParent((Widget) m_mainWidget));
+#else
+        XtUnmanageChild((Widget)m_mainWidget) ;
+#endif
 
         XFlush(XtDisplay((Widget)m_mainWidget));
         XSync(XtDisplay((Widget)m_mainWidget), False);
@@ -329,8 +295,6 @@ bool wxDialog::Show( bool show )
 // Shows a dialog modally, returning a return code
 int wxDialog::ShowModal()
 {
-    m_windowStyle |= wxDIALOG_MODAL;
-
     Show(true);
 
     // after the event loop ran, the widget might already have been destroyed
@@ -374,69 +338,6 @@ void wxDialog::EndModal(int retCode)
     SetModal(false);
 }
 
-// Standard buttons
-void wxDialog::OnOK(wxCommandEvent& WXUNUSED(event))
-{
-    if ( Validate() && TransferDataFromWindow() )
-    {
-        if ( IsModal() )
-            EndModal(wxID_OK);
-        else
-        {
-            SetReturnCode(wxID_OK);
-            this->Show(false);
-        }
-    }
-}
-
-void wxDialog::OnApply(wxCommandEvent& WXUNUSED(event))
-{
-    if (Validate())
-        TransferDataFromWindow();
-    // TODO probably need to disable the Apply button until things change again
-}
-
-void wxDialog::OnCancel(wxCommandEvent& WXUNUSED(event))
-{
-    if ( IsModal() )
-        EndModal(wxID_CANCEL);
-    else
-    {
-        SetReturnCode(wxID_CANCEL);
-        this->Show(false);
-    }
-}
-
-void wxDialog::OnCloseWindow(wxCloseEvent& WXUNUSED(event))
-{
-    // We'll send a Cancel message by default,
-    // which may close the dialog.
-    // Check for looping if the Cancel event handler calls Close().
-
-    // Note that if a cancel button and handler aren't present in the dialog,
-    // nothing will happen when you close the dialog via the window manager, or
-    // via Close().
-    // We wouldn't want to destroy the dialog by default, since the dialog may have been
-    // created on the stack.
-    // However, this does mean that calling dialog->Close() won't delete the dialog
-    // unless the handler for wxID_CANCEL does so. So use Destroy() if you want to be
-    // sure to destroy the dialog.
-    // The default OnCancel (above) simply ends a modal dialog, and hides a modeless dialog.
-
-    static wxList closing;
-
-    if ( closing.Member(this) )
-        return;
-
-    closing.Append(this);
-
-    wxCommandEvent cancelEvent(wxEVT_COMMAND_BUTTON_CLICKED, wxID_CANCEL);
-    cancelEvent.SetEventObject( this );
-    GetEventHandler()->ProcessEvent(cancelEvent); // This may close the dialog
-
-    closing.DeleteObject(this);
-}
-
 // Destroy the window (delayed, if a managed window)
 bool wxDialog::Destroy()
 {
@@ -445,12 +346,6 @@ bool wxDialog::Destroy()
     return true;
 }
 
-void wxDialog::OnSysColourChanged(wxSysColourChangedEvent& WXUNUSED(event))
-{
-    SetBackgroundColour(wxSystemSettings::GetColour(wxSYS_COLOUR_3DFACE));
-    Refresh();
-}
-
 void wxDialog::ChangeFont(bool keepOriginalSize)
 {
     wxWindow::ChangeFont(keepOriginalSize);
