@@ -1,10 +1,10 @@
 ///////////////////////////////////////////////////////////////////////////////
-// Name:        motif/evtloop.cpp
+// Name:        src/motif/evtloop.cpp
 // Purpose:     implements wxEventLoop for Motif
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     01.11.02
-// RCS-ID:      $Id: evtloop.cpp,v 1.18 2005/09/17 21:01:39 VZ Exp $
+// RCS-ID:      $Id: evtloop.cpp,v 1.30 2006/12/06 23:28:42 VZ Exp $
 // Copyright:   (c) 2002 Mattia Barbon
 // License:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
@@ -17,10 +17,6 @@
 // headers
 // ----------------------------------------------------------------------------
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-    #pragma implementation "evtloop.h"
-#endif
-
 #ifdef __VMS
 #define XtParent XTPARENT
 #define XtDisplay XTDISPLAY
@@ -30,24 +26,30 @@
 #include "wx/wxprec.h"
 
 #ifndef WX_PRECOMP
+    #include "wx/event.h"
+    #include "wx/app.h"
+    #include "wx/window.h"
+    #include "wx/module.h"
 #endif //WX_PRECOMP
 
 #include "wx/evtloop.h"
-#include "wx/event.h"
-#include "wx/app.h"
-#include "wx/window.h"
 
 #ifdef __VMS__
-#pragma message disable nosimpint
+    #pragma message disable nosimpint
 #endif
 #include <Xm/Xm.h>
 #include <X11/Xlib.h>
 #ifdef __VMS__
-#pragma message enable nosimpint
+    #pragma message enable nosimpint
 #endif
 
+#include "wx/unix/private.h"
 #include "wx/motif/private.h"
 
+#ifdef HAVE_SYS_SELECT_H
+#   include <sys/select.h>
+#endif
+
 static bool CheckForKeyUp(XEvent* event);
 static bool CheckForKeyDown(XEvent* event);
 static bool CheckForAccelerator(XEvent* event);
@@ -99,8 +101,6 @@ bool wxEventLoopImpl::SendIdleMessage()
 // wxEventLoop running and exiting
 // ----------------------------------------------------------------------------
 
-wxEventLoop *wxEventLoopBase::ms_activeLoop = NULL;
-
 wxEventLoop::~wxEventLoop()
 {
     wxASSERT_MSG( !m_impl, _T("should have been deleted in Run()") );
@@ -111,8 +111,7 @@ int wxEventLoop::Run()
     // event loops are not recursive, you need to create another loop!
     wxCHECK_MSG( !IsRunning(), -1, _T("can't reenter a message loop") );
 
-    wxEventLoop *oldLoop = ms_activeLoop;
-    ms_activeLoop = this;
+    wxEventLoopActivator activate(this);
 
     m_impl = new wxEventLoopImpl;
     m_impl->SetKeepGoing( true );
@@ -123,12 +122,12 @@ int wxEventLoop::Run()
             break;
     }
 
+    OnExit();
+
     int exitcode = m_impl->GetExitCode();
     delete m_impl;
     m_impl = NULL;
 
-    ms_activeLoop = oldLoop;
-
     return exitcode;
 }
 
@@ -260,7 +259,7 @@ bool CheckForAccelerator(XEvent* event)
         wxWindow* win = NULL;
 
         // Find the first wxWindow that corresponds to this event window
-        while (widget && !(win = wxGetWindowFromTable(widget)))
+        while (widget && ((win = wxGetWindowFromTable(widget))!=NULL))
             widget = XtParent(widget);
 
         if (!widget || !win)
@@ -294,7 +293,7 @@ bool CheckForKeyDown(XEvent* event)
         wxWindow* win = NULL;
 
         // Find the first wxWindow that corresponds to this event window
-        while (widget && !(win = wxGetWindowFromTable(widget)))
+        while (widget && ((win = wxGetWindowFromTable(widget))!=NULL))
             widget = XtParent(widget);
 
         if (!widget || !win)
@@ -320,7 +319,7 @@ bool CheckForKeyUp(XEvent* event)
         wxWindow* win = NULL;
 
         // Find the first wxWindow that corresponds to this event window
-        while (widget && !(win = wxGetWindowFromTable(widget)))
+        while (widget && ((win = wxGetWindowFromTable(widget))!=NULL))
                 widget = XtParent(widget);
 
         if (!widget || !win)
@@ -381,8 +380,6 @@ bool wxDoEventLoopIteration( wxEventLoop& evtLoop )
 // also wxEventLoop::Exit is implemented that way, so that exiting an
 // event loop won't require an event being in the queue
 
-#include "wx/module.h"
-
 #include <sys/types.h>
 #include <sys/time.h>
 #include <unistd.h>
@@ -413,7 +410,7 @@ private:
     DECLARE_DYNAMIC_CLASS(wxIdlePipeModule)
 };
 
-IMPLEMENT_DYNAMIC_CLASS(wxIdlePipeModule, wxModule);
+IMPLEMENT_DYNAMIC_CLASS(wxIdlePipeModule, wxModule)
 
 static void wxInputCallback( XtPointer, int* fd, XtInputId* )
 {
@@ -428,8 +425,8 @@ static void wxInputCallback( XtPointer, int* fd, XtInputId* )
         timeout.tv_sec = 0;
         timeout.tv_usec = 0;
 
-        FD_ZERO( &in );
-        FD_SET( *fd, &in );
+        wxFD_ZERO( &in );
+        wxFD_SET( *fd, &in );
 
         if( select( *fd + 1, &in, NULL, NULL, &timeout ) <= 0 )
             break;
@@ -449,8 +446,8 @@ static void wxBreakDispatch()
     timeout.tv_sec = 0;
     timeout.tv_usec = 0;
 
-    FD_ZERO( &in );
-    FD_SET( idleFds[0], &in );
+    wxFD_ZERO( &in );
+    wxFD_SET( idleFds[0], &in );
 
     if( select( idleFds[0] + 1, &in, NULL, NULL, &timeout ) > 0 )
         return;
@@ -475,7 +472,7 @@ bool wxAddIdleCallback()
 {
     if (!wxInitIdleFds())
         return false;
-    
+
     // install input handler for wxWakeUpIdle
     XtAppAddInput((XtAppContext) wxTheApp->GetAppContext(),
                   idleFds[0],
@@ -485,4 +482,3 @@ bool wxAddIdleCallback()
 
     return true;
 }
-
