@@ -4,7 +4,7 @@
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: font.cpp,v 1.35 2005/07/31 09:42:13 MBN Exp $
+// RCS-ID:      $Id: font.cpp,v 1.47 2006/11/20 16:20:45 VS Exp $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -17,15 +17,9 @@
 // headers
 // ----------------------------------------------------------------------------
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-    #pragma implementation "font.h"
-#endif
-
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
-#include "wx/defs.h"
-
 #ifdef __VMS
 #pragma message disable nosimpint
 #include "wx/vms_x_fix.h"
@@ -35,23 +29,21 @@
 #pragma message enable nosimpint
 #endif
 
-#include "wx/string.h"
 #include "wx/font.h"
-#include "wx/gdicmn.h"
-#include "wx/utils.h"       // for wxGetDisplay()
+
+#ifndef WX_PRECOMP
+    #include "wx/string.h"
+    #include "wx/utils.h"       // for wxGetDisplay()
+    #include "wx/settings.h"
+    #include "wx/gdicmn.h"
+#endif
+
 #include "wx/fontutil.h"    // for wxNativeFontInfo
 #include "wx/tokenzr.h"
-#include "wx/settings.h"
 #include "wx/motif/private.h"
 
 IMPLEMENT_DYNAMIC_CLASS(wxFont, wxGDIObject)
 
-#if wxCHECK_MOTIF_VERSION( 2, 0 ) && !wxCHECK_LESSTIF()
-    #define wxUSE_RENDER_TABLE 1
-#else
-    #define wxUSE_RENDER_TABLE 0
-#endif
-
 // ----------------------------------------------------------------------------
 // private classes
 // ----------------------------------------------------------------------------
@@ -62,12 +54,12 @@ class wxXFont : public wxObject
 {
 public:
     wxXFont();
-    ~wxXFont();
+    virtual ~wxXFont();
 
 #if !wxMOTIF_NEW_FONT_HANDLING
     WXFontStructPtr     m_fontStruct;   // XFontStruct
 #endif
-#if !wxUSE_RENDER_TABLE && !wxMOTIF_NEW_FONT_HANDLING
+#if !wxMOTIF_USE_RENDER_TABLE && !wxMOTIF_NEW_FONT_HANDLING
     WXFontList          m_fontList;     // Motif XmFontList
 #else // if wxUSE_RENDER_TABLE
     WXRenderTable       m_renderTable;  // Motif XmRenderTable
@@ -99,7 +91,7 @@ public:
              data.m_underlined, data.m_faceName, data.m_encoding);
     }
 
-    ~wxFontRefData();
+    virtual ~wxFontRefData();
 
 protected:
     // common part of all ctors
@@ -139,9 +131,9 @@ wxXFont::wxXFont()
 #if !wxMOTIF_NEW_FONT_HANDLING
     m_fontStruct = (WXFontStructPtr) 0;
 #endif
-#if !wxUSE_RENDER_TABLE && !wxMOTIF_NEW_FONT_HANDLING
+#if !wxMOTIF_USE_RENDER_TABLE && !wxMOTIF_NEW_FONT_HANDLING
     m_fontList = (WXFontList) 0;
-#else // if wxUSE_RENDER_TABLE
+#else // if wxMOTIF_USE_RENDER_TABLE
     m_renderTable = (WXRenderTable) 0;
     m_rendition   = (WXRendition) 0;
 #endif
@@ -151,7 +143,7 @@ wxXFont::wxXFont()
 
 wxXFont::~wxXFont()
 {
-#if !wxUSE_RENDER_TABLE
+#if !wxMOTIF_USE_RENDER_TABLE
     if (m_fontList)
         XmFontListFree ((XmFontList) m_fontList);
     m_fontList = NULL;
@@ -219,21 +211,17 @@ wxFontRefData::~wxFontRefData()
     m_fonts.Clear();
 }
 
+#define M_FONTDATA ((wxFontRefData*)m_refData)
+
 // ----------------------------------------------------------------------------
 // wxFont
 // ----------------------------------------------------------------------------
 
 wxFont::wxFont(const wxNativeFontInfo& info)
 {
-    Init();
-
     (void)Create(info.GetXFontName());
 }
 
-void wxFont::Init()
-{
-}
-
 bool wxFont::Create(int pointSize,
                     int family,
                     int style,
@@ -246,8 +234,6 @@ bool wxFont::Create(int pointSize,
     m_refData = new wxFontRefData(pointSize, family, style, weight,
                                   underlined, faceName, encoding);
 
-    RealizeResource();
-
     return true;
 }
 
@@ -383,8 +369,6 @@ void wxFont::SetPointSize(int pointSize)
 
     M_FONTDATA->m_pointSize = pointSize;
     M_FONTDATA->m_nativeFontInfo.GetXFontName().Clear(); // invalid now
-
-    RealizeResource();
 }
 
 void wxFont::SetFamily(int family)
@@ -393,8 +377,6 @@ void wxFont::SetFamily(int family)
 
     M_FONTDATA->m_family = family;
     M_FONTDATA->m_nativeFontInfo.GetXFontName().Clear(); // invalid now
-
-    RealizeResource();
 }
 
 void wxFont::SetStyle(int style)
@@ -403,8 +385,6 @@ void wxFont::SetStyle(int style)
 
     M_FONTDATA->m_style = style;
     M_FONTDATA->m_nativeFontInfo.GetXFontName().Clear(); // invalid now
-
-    RealizeResource();
 }
 
 void wxFont::SetWeight(int weight)
@@ -413,18 +393,16 @@ void wxFont::SetWeight(int weight)
 
     M_FONTDATA->m_weight = weight;
     M_FONTDATA->m_nativeFontInfo.GetXFontName().Clear(); // invalid now
-
-    RealizeResource();
 }
 
-void wxFont::SetFaceName(const wxString& faceName)
+bool wxFont::SetFaceName(const wxString& faceName)
 {
     Unshare();
 
     M_FONTDATA->m_faceName = faceName;
     M_FONTDATA->m_nativeFontInfo.GetXFontName().Clear(); // invalid now
 
-    RealizeResource();
+    return wxFontBase::SetFaceName(faceName);
 }
 
 void wxFont::SetUnderlined(bool underlined)
@@ -432,8 +410,6 @@ void wxFont::SetUnderlined(bool underlined)
     Unshare();
 
     M_FONTDATA->m_underlined = underlined;
-
-    RealizeResource();
 }
 
 void wxFont::SetEncoding(wxFontEncoding encoding)
@@ -442,8 +418,6 @@ void wxFont::SetEncoding(wxFontEncoding encoding)
 
     M_FONTDATA->m_encoding = encoding;
     M_FONTDATA->m_nativeFontInfo.GetXFontName().Clear(); // invalid now
-
-    RealizeResource();
 }
 
 void wxFont::DoSetNativeFontInfo(const wxNativeFontInfo& info)
@@ -466,7 +440,7 @@ int wxFont::GetPointSize() const
 
 wxString wxFont::GetFaceName() const
 {
-    wxCHECK_MSG( Ok(), wxT(""), wxT("invalid font") );
+    wxCHECK_MSG( Ok(), wxEmptyString, wxT("invalid font") );
 
     return M_FONTDATA->m_faceName ;
 }
@@ -510,7 +484,7 @@ const wxNativeFontInfo *wxFont::GetNativeFontInfo() const
 {
     wxCHECK_MSG( Ok(), (wxNativeFontInfo *)NULL, wxT("invalid font") );
 
-    if(M_FONTDATA->m_nativeFontInfo.GetXFontName().IsEmpty())
+    if(M_FONTDATA->m_nativeFontInfo.GetXFontName().empty())
         GetInternalFont();
 
     return &(M_FONTDATA->m_nativeFontInfo);
@@ -568,8 +542,8 @@ wxXFont* wxFont::GetInternalFont(double scale, WXDisplay* display) const
 #endif
     f->m_display = ( display ? display : wxGetDisplay() );
     f->m_scale = intScale;
-    
-#if wxUSE_RENDER_TABLE
+
+#if wxMOTIF_USE_RENDER_TABLE
     XmRendition rendition;
     XmRenderTable renderTable;
     Arg args[5];
@@ -593,7 +567,7 @@ wxXFont* wxFont::GetInternalFont(double scale, WXDisplay* display) const
     f->m_renderTable = (WXRenderTable)renderTable;
     f->m_rendition = (WXRendition)rendition;
     wxASSERT( f->m_renderTable != NULL );
-#else // if !wxUSE_RENDER_TABLE
+#else // if !wxMOTIF_USE_RENDER_TABLE
     f->m_fontList = XmFontListCreate ((XFontStruct*) font, XmSTRING_DEFAULT_CHARSET);
     wxASSERT( f->m_fontList != NULL );
 #endif
@@ -612,38 +586,31 @@ WXFontStructPtr wxFont::GetFontStruct(double scale, WXDisplay* display) const
     return (f ? f->m_fontStruct : (WXFontStructPtr) 0);
 }
 
+#endif
+
+#if !wxMOTIF_USE_RENDER_TABLE
+
 WXFontList wxFont::GetFontList(double scale, WXDisplay* display) const
 {
-#if !wxUSE_RENDER_TABLE
     wxXFont* f = GetInternalFont(scale, display);
 
     return (f ? f->m_fontList : (WXFontList) 0);
-#else
-    return NULL;
-#endif
 }
 
-#endif // !wxMOTIF_NEW_FONT_HANDLING
-
- // declared in the header, can't use wxUSE_RENDER_TABLE
-#if wxCHECK_MOTIF_VERSION( 2, 0 )
+#else // if wxMOTIF_USE_RENDER_TABLE
 
 WXRenderTable wxFont::GetRenderTable(WXDisplay* display) const
 {
-#if wxUSE_RENDER_TABLE
     wxXFont* f = GetInternalFont(1.0, display);
 
-    return (f ? f->m_renderTable : (WXFontList) 0);
-#else
-    return NULL;
-#endif
+    return (f ? f->m_renderTable : (WXRenderTable) 0);
 }
 
-#endif // wxCHECK_MOTIF_VERSION( 2, 0 )
+#endif // wxMOTIF_USE_RENDER_TABLE
 
 WXFontType wxFont::GetFontType(WXDisplay* display) const
 {
-#if wxUSE_RENDER_TABLE
+#if wxMOTIF_USE_RENDER_TABLE
     return Ok() ? GetRenderTable(display) : NULL;
 #else
     return Ok() ? GetFontList(1.0, display) : NULL;
@@ -652,7 +619,7 @@ WXFontType wxFont::GetFontType(WXDisplay* display) const
 
 WXFontType wxFont::GetFontTypeC(WXDisplay* display) const
 {
-#if wxUSE_RENDER_TABLE
+#if wxMOTIF_USE_RENDER_TABLE
     return Ok() ? GetRenderTable(display) : NULL;
 #else
     return Ok() ? XmFontListCopy( (XmFontList)GetFontList(1.0, display) ) : NULL;
@@ -661,7 +628,7 @@ WXFontType wxFont::GetFontTypeC(WXDisplay* display) const
 
 /*static*/ WXString wxFont::GetFontTag()
 {
-#if wxUSE_RENDER_TABLE
+#if wxMOTIF_USE_RENDER_TABLE
     return (WXString)XmNrenderTable;
 #else
     return (WXString)XmNfontList;
@@ -691,13 +658,13 @@ void wxGetTextExtent(WXDisplay* display, const wxFont& font, double scale,
 {
     XRectangle ink, logical;
     WXFontSet fset = font.GetFontSet(scale, display);
-    
+
     XmbTextExtents( (XFontSet)fset, str.c_str(), str.length(), &ink, &logical);
 
     if( width ) *width = logical.width;
     if( height ) *height = logical.height;
-    if( ascent ) *ascent = -logical.y;    
-    if( descent ) *descent = logical.height + logical.y;    
+    if( ascent ) *ascent = -logical.y;
+    if( descent ) *descent = logical.height + logical.y;
 }
 
 #else // if !wxMOTIF_NEW_FONT_HANDLING
@@ -710,7 +677,7 @@ void wxGetTextExtent(WXDisplay* display, const wxFont& font,
 
     int direction, ascent2, descent2;
     XCharStruct overall;
-    int slen = str.Len();
+    int slen = str.length();
 
     XTextExtents((XFontStruct*) pFontStruct, (char*) str.c_str(), slen,
                  &direction, &ascent2, &descent2, &overall);
