@@ -1,33 +1,34 @@
 ///////////////////////////////////////////////////////////////////////////////
-// Name:        listbox.cpp
+// Name:        src/motif/listbox.cpp
 // Purpose:     wxListBox
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: listbox.cpp,v 1.44 2005/06/19 19:11:20 MBN Exp $
+// RCS-ID:      $Id: listbox.cpp,v 1.55 2006/10/03 14:55:49 VZ Exp $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-    #pragma implementation "listbox.h"
-#endif
-
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
+#if wxUSE_LISTBOX
+
+#include "wx/listbox.h"
+
+#ifndef WX_PRECOMP
+    #include "wx/dynarray.h"
+    #include "wx/log.h"
+    #include "wx/utils.h"
+    #include "wx/settings.h"
+    #include "wx/arrstr.h"
+#endif
+
 #ifdef __VMS
 #define XtParent XTPARENT
 #define XtDisplay XTDISPLAY
 #endif
 
-# include "wx/listbox.h"
-#include "wx/settings.h"
-#include "wx/dynarray.h"
-#include "wx/log.h"
-#include "wx/utils.h"
-#include "wx/arrstr.h"
-
 #ifdef __VMS__
 #pragma message disable nosimpint
 #endif
@@ -91,7 +92,7 @@ bool wxListBox::Create(wxWindow *parent, wxWindowID id,
                                    validator, name ) )
         return false;
 
-    m_noItems = n;
+    m_noItems = (unsigned int)n;
     m_backgroundColour = * wxWHITE;
 
     Widget parentWidget = (Widget) parent->GetClientWidget();
@@ -194,8 +195,9 @@ void wxListBox::DoSetFirstItem( int N )
 {
     int count, length;
 
-    if (N < 0)
+    if (!IsValid(N))
         return;
+
     XtVaGetValues ((Widget) m_mainWidget,
                     XmNvisibleItemCount, &count,
                     XmNitemCount, &length,
@@ -205,35 +207,20 @@ void wxListBox::DoSetFirstItem( int N )
     XmListSetPos ((Widget) m_mainWidget, N + 1);
 }
 
-void wxListBox::Delete(int N)
+void wxListBox::Delete(unsigned int n)
 {
-    wxSizeKeeper sk( this );
     Widget listBox = (Widget) m_mainWidget;
 
-    bool managed = XtIsManaged(listBox);
+    XmListDeletePos (listBox, n + 1);
 
-    if (managed)
-        XtUnmanageChild (listBox);
-
-    XmListDeletePos (listBox, N + 1);
-
-    if (managed)
-        XtManageChild (listBox);
-
-    sk.Restore();
-    m_clientDataDict.Delete(N, HasClientObjectData());
+    m_clientDataDict.Delete(n, HasClientObjectData());
     m_noItems --;
 }
 
 int wxListBox::DoAppend(const wxString& item)
 {
-    wxSizeKeeper sk( this );
     Widget listBox = (Widget) m_mainWidget;
 
-    bool managed = XtIsManaged(listBox);
-
-    if (managed)
-        XtUnmanageChild (listBox);
     int n;
     XtVaGetValues (listBox, XmNitemCount, &n, NULL);
     wxXmString text( item );
@@ -244,10 +231,6 @@ int wxListBox::DoAppend(const wxString& item)
     // selection policy!!
     SetSelectionPolicy();
 
-    if (managed)
-        XtManageChild (listBox);
-
-    sk.Restore();
     m_noItems ++;
 
     return GetCount() - 1;
@@ -255,18 +238,13 @@ int wxListBox::DoAppend(const wxString& item)
 
 void wxListBox::DoSetItems(const wxArrayString& items, void** clientData)
 {
-    wxSizeKeeper sk( this );
     Widget listBox = (Widget) m_mainWidget;
 
     if( HasClientObjectData() )
         m_clientDataDict.DestroyData();
 
-    bool managed = XtIsManaged(listBox);
-
-    if (managed)
-        XtUnmanageChild (listBox);
     XmString *text = new XmString[items.GetCount()];
-    size_t i;
+    unsigned int i;
     for (i = 0; i < items.GetCount(); ++i)
         text[i] = wxStringToXmString (items[i]);
 
@@ -283,11 +261,6 @@ void wxListBox::DoSetItems(const wxArrayString& items, void** clientData)
     // selection policy!!
     SetSelectionPolicy();
 
-    if (managed)
-        XtManageChild (listBox);
-
-    sk.Restore();
-
     m_noItems = items.GetCount();
 }
 
@@ -310,8 +283,10 @@ int wxDoFindStringInList(Widget w, const wxString& s)
         return -1;
 }
 
-int wxListBox::FindString(const wxString& s) const
+int wxListBox::FindString(const wxString& s, bool WXUNUSED(bCase)) const
 {
+    // FIXME: back to base class for not supported value of bCase
+
     return wxDoFindStringInList( (Widget)m_mainWidget, s );
 }
 
@@ -389,24 +364,24 @@ bool wxListBox::IsSelected(int N) const
     return false;
 }
 
-void wxListBox::DoSetItemClientObject(int n, wxClientData* clientData)
+void wxListBox::DoSetItemClientObject(unsigned int n, wxClientData* clientData)
 {
     m_clientDataDict.Set(n, clientData, false);
 }
 
-wxClientData* wxListBox::DoGetItemClientObject(int n) const
+wxClientData* wxListBox::DoGetItemClientObject(unsigned int n) const
 {
     return m_clientDataDict.Get(n);
 }
 
-void *wxListBox::DoGetItemClientData(int N) const
+void *wxListBox::DoGetItemClientData(unsigned int n) const
 {
-    return (void*)m_clientDataDict.Get(N);
+    return (void*)m_clientDataDict.Get(n);
 }
 
-void wxListBox::DoSetItemClientData(int N, void *Client_data)
+void wxListBox::DoSetItemClientData(unsigned int n, void *Client_data)
 {
-    m_clientDataDict.Set(N, (wxClientData*)Client_data, false);
+    m_clientDataDict.Set(n, (wxClientData*)Client_data, false);
 }
 
 // Return number of selections and an array of selected integers
@@ -476,23 +451,17 @@ wxString wxDoGetStringInList( Widget listBox, int n )
         return wxEmptyString;
 }
 
-wxString wxListBox::GetString( int n ) const
+wxString wxListBox::GetString(unsigned int n) const
 {
     return wxDoGetStringInList( (Widget)m_mainWidget, n );
 }
 
-void wxListBox::DoInsertItems(const wxArrayString& items, int pos)
+void wxListBox::DoInsertItems(const wxArrayString& items, unsigned int pos)
 {
-    wxSizeKeeper sk( this );
     Widget listBox = (Widget) m_mainWidget;
 
-    bool managed = XtIsManaged(listBox);
-
-    if (managed)
-        XtUnmanageChild(listBox);
-
     XmString *text = new XmString[items.GetCount()];
-    size_t i;
+    unsigned int i;
     // Steve Hammes: Motif 1.1 compatibility
     // #if XmVersion > 1100
     // Corrected by Sergey Krasnov from Steve Hammes' code
@@ -516,15 +485,10 @@ void wxListBox::DoInsertItems(const wxArrayString& items, int pos)
     // selection policy!!
     SetSelectionPolicy();
 
-    if (managed)
-        XtManageChild(listBox);
-
-    sk.Restore();
-
     m_noItems += items.GetCount();
 }
 
-void wxListBox::SetString(int N, const wxString& s)
+void wxListBox::SetString(unsigned int n, const wxString& s)
 {
     wxSizeKeeper sk( this );
     Widget listBox = (Widget) m_mainWidget;
@@ -533,8 +497,8 @@ void wxListBox::SetString(int N, const wxString& s)
 
     // delete the item and add it again.
     // FIXME isn't there a way to change it in place?
-    XmListDeletePos (listBox, N+1);
-    XmListAddItem (listBox, text(), N+1);
+    XmListDeletePos (listBox, n+1);
+    XmListAddItem (listBox, text(), n+1);
 
     sk.Restore();
 }
@@ -665,7 +629,7 @@ void wxListBox::ChangeForegroundColour()
     */
 }
 
-int wxListBox::GetCount() const
+unsigned int wxListBox::GetCount() const
 {
     return m_noItems;
 }
@@ -717,3 +681,4 @@ wxSize wxListBox::DoGetBestSize() const
     return wxDoGetListBoxBestSize( (Widget)m_mainWidget, this );
 }
 
+#endif // wxUSE_LISTBOX
