@@ -1,18 +1,14 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        mdi.cpp
+// Name:        src/motif/mdi.cpp
 // Purpose:     MDI classes
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: mdi.cpp,v 1.37 2005/03/21 12:27:45 VZ Exp $
+// RCS-ID:      $Id: mdi.cpp,v 1.41 2006/05/24 07:16:14 ABX Exp $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-#pragma implementation "mdi.h"
-#endif
-
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
@@ -22,9 +18,12 @@
 #endif
 
 #include "wx/mdi.h"
-#include "wx/menu.h"
-#include "wx/settings.h"
-#include "wx/icon.h"
+
+#ifndef WX_PRECOMP
+    #include "wx/menu.h"
+    #include "wx/icon.h"
+    #include "wx/settings.h"
+#endif
 
 #ifdef __VMS__
 #pragma message disable nosimpint
@@ -303,7 +302,7 @@ void wxMDIParentFrame::OnMenuHighlight(wxMenuEvent& event)
     if (GetStatusBar())
     {
         if (event.GetMenuId() == -1)
-            SetStatusText("");
+            SetStatusText(wxEmptyString);
         else
         {
             wxMenuBar *menuBar = (wxMenuBar*) NULL;
@@ -314,7 +313,7 @@ void wxMDIParentFrame::OnMenuHighlight(wxMenuEvent& event)
             if (menuBar)
             {
                 wxString helpString(menuBar->GetHelpString(event.GetMenuId()));
-                if (helpString != "")
+                if (!helpString.empty())
                     SetStatusText(helpString);
             }
         }
