@@ -1,23 +1,18 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        menu.cpp
+// Name:        src/motif/menu.cpp
 // Purpose:     wxMenu, wxMenuBar, wxMenuItem
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: menu.cpp,v 1.54 2005/09/13 16:49:06 VZ Exp $
+// RCS-ID:      $Id: menu.cpp,v 1.65 2006/08/19 23:21:18 VZ Exp $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
-
 // ============================================================================
 // declarations
 // ============================================================================
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-    #pragma implementation "menu.h"
-#endif
-
 // ----------------------------------------------------------------------------
 // headers
 // ----------------------------------------------------------------------------
@@ -25,15 +20,16 @@
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
-#include "wx/defs.h"
-
 #include "wx/menu.h"
-#include "wx/menuitem.h"
-#include "wx/log.h"
-#include "wx/utils.h"
-#include "wx/app.h"
-#include "wx/frame.h"
-#include "wx/settings.h"
+
+#ifndef WX_PRECOMP
+    #include "wx/log.h"
+    #include "wx/app.h"
+    #include "wx/utils.h"
+    #include "wx/frame.h"
+    #include "wx/settings.h"
+    #include "wx/menuitem.h"
+#endif
 
 #ifdef __VMS__
 #pragma message disable nosimpint
@@ -119,18 +115,7 @@ void wxMenu::Break()
 // function appends a new item or submenu to the menu
 wxMenuItem* wxMenu::DoAppend(wxMenuItem *pItem)
 {
-    if (m_menuWidget)
-    {
-        // this is a dynamic Append
-        pItem->CreateItem(m_menuWidget, GetMenuBar(), m_topLevelMenu);
-    }
-
-    if ( pItem->IsSubMenu() )
-    {
-        pItem->GetSubMenu()->m_topLevelMenu = m_topLevelMenu;
-    }
-
-    return wxMenuBase::DoAppend(pItem);
+    return DoInsert(GetMenuItemCount(), pItem);
 }
 
 wxMenuItem *wxMenu::DoRemove(wxMenuItem *item)
@@ -142,12 +127,22 @@ wxMenuItem *wxMenu::DoRemove(wxMenuItem *item)
 
 wxMenuItem* wxMenu::DoInsert(size_t pos, wxMenuItem *item)
 {
-    if ( wxMenuBase::DoInsert(pos, item) )
-        return item;
+    if (m_menuWidget)
+    {
+        // this is a dynamic Append
+#ifndef XmNpositionIndex
+    wxCHECK_MSG( pos == GetMenuItemCount(), -1, wxT("insert not implemented"));
+#endif
+        item->CreateItem(m_menuWidget, GetMenuBar(), m_topLevelMenu, pos);
+    }
 
-    wxFAIL_MSG(wxT("DoInsert not implemented; or error in wxMenuBase::DoInsert"));
+    if ( item->IsSubMenu() )
+    {
+        item->GetSubMenu()->m_topLevelMenu = m_topLevelMenu;
+    }
 
-    return NULL;
+    return pos == GetMenuItemCount() ? wxMenuBase::DoAppend(item) :
+                                       wxMenuBase::DoInsert(pos, item);
 }
 
 void wxMenu::SetTitle(const wxString& label)
@@ -272,30 +267,27 @@ wxString wxMenuBar::GetLabelTop(size_t pos) const
 
 bool wxMenuBar::Append(wxMenu * menu, const wxString& title)
 {
+    return Insert(GetMenuCount(), menu, title);
+}
+
+bool wxMenuBar::Insert(size_t pos, wxMenu *menu, const wxString& title)
+{
+    wxCHECK_MSG( pos <= GetMenuCount(), false, wxT("invalid position") );
     wxCHECK_MSG( menu, false, wxT("invalid menu") );
     wxCHECK_MSG( !menu->GetParent() && !menu->GetButtonWidget(), false,
                  wxT("menu already appended") );
 
     if ( m_menuBarFrame )
     {
-        WXWidget w = menu->CreateMenu(this, GetMainWidget(), menu, title, true);
+        WXWidget w = menu->CreateMenu(this, GetMainWidget(), menu,
+                                      pos, title, true);
         wxCHECK_MSG( w, false, wxT("failed to create menu") );
         menu->SetButtonWidget(w);
     }
 
-    m_titles.Add(title);
+    m_titles.Insert(title, pos);
 
-    return wxMenuBarBase::Append(menu, title);
-}
-
-bool wxMenuBar::Insert(size_t pos, wxMenu *menu, const wxString& title)
-{
-    if ( !wxMenuBarBase::Insert(pos, menu, title) )
-        return false;
-
-    wxFAIL_MSG(wxT("TODO"));
-
-    return false;
+    return wxMenuBarBase::Insert(pos, menu, title);
 }
 
 wxMenu *wxMenuBar::Replace(size_t pos, wxMenu *menu, const wxString& title)
@@ -326,20 +318,17 @@ wxMenu *wxMenuBar::Remove(size_t pos)
 
 // Find the menu menuString, item itemString, and return the item id.
 // Returns -1 if none found.
-int wxMenuBar::FindMenuItem (const wxString& menuString, const wxString& itemString) const
+int wxMenuBar::FindMenuItem(const wxString& menuString, const wxString& itemString) const
 {
-    char buf1[200];
-    char buf2[200];
-    wxStripMenuCodes (wxConstCast(menuString.c_str(), char), buf1);
+    const wxString stripped = wxStripMenuCodes(menuString);
 
     size_t menuCount = GetMenuCount();
     for (size_t i = 0; i < menuCount; i++)
     {
-        wxStripMenuCodes (wxConstCast(m_titles[i].c_str(), char), buf2);
-        if (strcmp (buf1, buf2) == 0)
+        if ( wxStripMenuCodes(m_titles[i]) == stripped )
             return m_menus.Item(i)->GetData()->FindItem (itemString);
     }
-    return -1;
+    return wxNOT_FOUND;
 }
 
 wxMenuItem *wxMenuBar::FindItem(int id, wxMenu ** itemMenu) const
@@ -347,12 +336,14 @@ wxMenuItem *wxMenuBar::FindItem(int id, wxMenu ** itemMenu) const
     if (itemMenu)
         *itemMenu = NULL;
 
-    wxMenuItem *item = NULL;
     size_t menuCount = GetMenuCount();
     for (size_t i = 0; i < menuCount; i++)
-        if ((item = m_menus.Item(i)->GetData()->FindItem(id, itemMenu)))
-            return item;
-        return NULL;
+    {
+        wxMenuItem *item = m_menus.Item(i)->GetData()->FindItem(id, itemMenu);
+        if (item) return item;
+    }
+
+    return NULL;
 }
 
 // Create menubar
@@ -378,7 +369,7 @@ bool wxMenuBar::CreateMenuBar(wxFrame* parent)
     {
         wxMenu *menu = GetMenu(i);
         wxString title(m_titles[i]);
-        menu->SetButtonWidget(menu->CreateMenu (this, menuBarW, menu, title, true));
+        menu->SetButtonWidget(menu->CreateMenu (this, menuBarW, menu, i, title, true));
 
         if (strcmp (wxStripMenuCodes(title), "Help") == 0)
             XtVaSetValues ((Widget) menuBarW, XmNmenuHelpWidget, (Widget) menu->GetButtonWidget(), NULL);
@@ -474,7 +465,12 @@ void wxMenu::DestroyWidgetAndDetach()
 *
 */
 
-WXWidget wxMenu::CreateMenu (wxMenuBar * menuBar, WXWidget parent, wxMenu * topMenu, const wxString& title, bool pullDown)
+WXWidget wxMenu::CreateMenu (wxMenuBar * menuBar,
+                             WXWidget parent,
+                             wxMenu * topMenu,
+                             size_t WXUNUSED(index),
+                             const wxString& title,
+                             bool pullDown)
 {
     Widget menu = (Widget) 0;
     Widget buttonWidget = (Widget) 0;
@@ -517,13 +513,14 @@ WXWidget wxMenu::CreateMenu (wxMenuBar * menuBar, WXWidget parent, wxMenu * topM
 
     m_topLevelMenu = topMenu;
 
+    size_t i = 0;
     for ( wxMenuItemList::compatibility_iterator node = GetMenuItems().GetFirst();
           node;
-          node = node->GetNext() )
+          node = node->GetNext(), ++i )
     {
         wxMenuItem *item = node->GetData();
 
-        item->CreateItem(menu, menuBar, topMenu);
+        item->CreateItem(menu, menuBar, topMenu, i);
     }
 
     SetBackgroundColour(m_backgroundColour);
@@ -679,6 +676,8 @@ void wxMenu::ChangeFont(bool keepOriginalSize)
         if (item->GetSubMenu())
             item->GetSubMenu()->ChangeFont(keepOriginalSize);
     }
+#else
+    wxUnusedVar(keepOriginalSize);
 #endif
 }
 
@@ -730,4 +729,3 @@ bool wxMenuBar::SetFont(const wxFont& font)
 
     return true;
 }
-
