@@ -4,7 +4,7 @@
 // Author:      Julian Smart
 // Modified by:
 // Created:     04/01/98
-// RCS-ID:      $Id: msgdlg.cpp,v 1.22 2005/09/14 14:24:31 VZ Exp $
+// RCS-ID:      $Id: msgdlg.cpp,v 1.28 2006/05/24 07:16:14 ABX Exp $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -13,10 +13,6 @@
 // declarations
 // ============================================================================
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-    #pragma implementation "msgdlg.h"
-#endif
-
 // ----------------------------------------------------------------------------
 // headers
 // ----------------------------------------------------------------------------
@@ -24,12 +20,10 @@
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
-#include "wx/defs.h"
-
 #ifdef __VMS
 #define XtDisplay XTDISPLAY
 #pragma message disable nosimpint
-#include <wx/vms_x_fix.h>
+#include "wx/vms_x_fix.h"
 #endif
 #include <X11/Xlib.h>
 
@@ -39,11 +33,15 @@
 #pragma message enable nosimpint
 #endif
 
-#include "wx/app.h"
-#include "wx/intl.h"
 #include "wx/msgdlg.h"
+
+#ifndef WX_PRECOMP
+    #include "wx/intl.h"
+    #include "wx/app.h"
+    #include "wx/settings.h"
+#endif
+
 #include "wx/motif/private.h"
-#include "wx/settings.h"
 
 // ----------------------------------------------------------------------------
 // macros
@@ -271,4 +269,3 @@ int wxMessageDialog::ShowModal()
 
     return m_result;
 }
-
