@@ -1,10 +1,10 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        motif/settings.cpp
+// Name:        src/motif/settings.cpp
 // Purpose:     wxSettings
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: settings.cpp,v 1.24 2005/07/31 09:42:13 MBN Exp $
+// RCS-ID:      $Id: settings.cpp,v 1.28 2006/06/19 20:18:36 ABX Exp $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -13,16 +13,15 @@
 // per-user file, which can be edited using a Windows-control-panel clone.
 // Also they should be documented better. Some are very MS Windows-ish.
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-#pragma implementation "settings.h"
-#endif
-
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
 #include "wx/settings.h"
-#include "wx/gdicmn.h"
-#include "wx/app.h"
+
+#ifndef WX_PRECOMP
+    #include "wx/app.h"
+    #include "wx/gdicmn.h"
+#endif
 
 #ifdef __VMS__
 #pragma message disable nosimpint
@@ -45,7 +44,7 @@ wxColour wxSystemSettingsNative::GetColour(wxSystemColour index)
   if (NULL == but_setting_wid && wxTheApp && wxTheApp->GetTopLevelWidget())
   {
     but_setting_wid = XtVaCreateWidget("settings_button", xmPushButtonWidgetClass,
-	                                 (Widget)wxTheApp->GetTopLevelWidget(), NULL);
+                                       (Widget)wxTheApp->GetTopLevelWidget(), NULL);
   }
 
   switch (index)
@@ -74,7 +73,9 @@ wxColour wxSystemSettingsNative::GetColour(wxSystemColour index)
             XtVaGetValues(but_setting_wid,
                         XtVaTypedArg, XmNbackground, XtRColor, &bg, sizeof(bg),
                         NULL);
-            return wxColor(bg.red >> 8, bg.green >> 8, bg.blue >> 8);
+            return wxColor((unsigned char)(bg.red >> 8),
+                           (unsigned char)(bg.green >> 8),
+                           (unsigned char)(bg.blue >> 8));
         }
         else
         {
@@ -117,7 +118,9 @@ wxColour wxSystemSettingsNative::GetColour(wxSystemColour index)
             XtVaGetValues(but_setting_wid,
                         XtVaTypedArg, XmNforeground, XtRColor, &fg, sizeof(fg),
                         NULL);
-            return wxColor(fg.red >> 8, fg.green >> 8, fg.blue >> 8);
+            return wxColor((unsigned char)(fg.red >> 8),
+                           (unsigned char)(fg.green >> 8),
+                           (unsigned char)(fg.blue >> 8));
         }
         else
         {
@@ -137,7 +140,9 @@ wxColour wxSystemSettingsNative::GetColour(wxSystemColour index)
             XtVaGetValues(but_setting_wid,
                         XtVaTypedArg, XmNbackground, XtRColor, &bg, sizeof(bg),
                         NULL);
-            return wxColor(bg.red >> 8, bg.green >> 8, bg.blue >> 8);
+            return wxColor((unsigned char)(bg.red >> 8),
+                           (unsigned char)(bg.green >> 8),
+                           (unsigned char)(bg.blue >> 8));
         }
         else
         {
@@ -167,11 +172,13 @@ wxFont wxSystemSettingsNative::GetFont(wxSystemFont index)
         || wxFont::GetDefaultEncoding() == wxFONTENCODING_EUC_JP)
         pointSize = 15;
 
+    wxFont font;
+
     switch (index)
     {
         case wxSYS_SYSTEM_FIXED_FONT:
         {
-            return wxFont(pointSize, wxMODERN, wxNORMAL, wxNORMAL, false);
+            font = wxFont(pointSize, wxMODERN, wxNORMAL, wxNORMAL, false);
             break;
         }
         case wxSYS_DEVICE_DEFAULT_FONT:
@@ -179,12 +186,12 @@ wxFont wxSystemSettingsNative::GetFont(wxSystemFont index)
         case wxSYS_DEFAULT_GUI_FONT:
         default:
         {
-            return wxFont(pointSize, wxSWISS, wxNORMAL, wxNORMAL, false);
+            font = wxFont(pointSize, wxSWISS, wxNORMAL, wxNORMAL, false);
             break;
         }
     }
 
-    return wxFont();
+    return font;
 }
 
 // Get a system metric, e.g. scrollbar size
@@ -197,7 +204,7 @@ int wxSystemSettingsNative::GetMetric(wxSystemMetric index, wxWindow* WXUNUSED(w
         case wxSYS_HSCROLL_Y:
         case wxSYS_VSCROLL_X:
             return 15;
-            
+
         case wxSYS_SCREEN_X:
             return_value = DisplayWidth( wxGlobalDisplay(), 0 );
             break;
