@@ -1,18 +1,14 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        statbox.cpp
+// Name:        src/motif/statbox.cpp
 // Purpose:     wxStaticBox
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: statbox.cpp,v 1.28 2005/08/28 08:07:34 MBN Exp $
+// RCS-ID:      $Id: statbox.cpp,v 1.32 2006/07/25 18:47:35 VZ Exp $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-#pragma implementation "statbox.h"
-#endif
-
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
@@ -20,10 +16,11 @@
 #define XtDisplay XTDISPLAY
 #endif
 
-#include "wx/defs.h"
-
 #include "wx/statbox.h"
-#include "wx/utils.h"
+
+#ifndef WX_PRECOMP
+    #include "wx/utils.h"
+#endif
 
 #ifdef __VMS__
 #pragma message disable nosimpint
@@ -105,10 +102,9 @@ bool wxStaticBox::Create(wxWindow *parent, wxWindowID id,
             // XmNshadowType, XmSHADOW_IN,
             NULL);
 
-    bool hasLabel = (!label.IsNull() && !label.IsEmpty()) ;
-    if (hasLabel)
+    if (!label.empty())
     {
-        wxString label1(wxStripMenuCodes(label));
+        wxString label1(GetLabelText(label));
         wxXmString text(label1);
         Display* dpy = XtDisplay( parentWidget );
 
@@ -119,11 +115,11 @@ bool wxStaticBox::Create(wxWindow *parent, wxWindowID id,
 #if wxCHECK_MOTIF_VERSION( 2, 0 )
                 XmNframeChildType, XmFRAME_TITLE_CHILD,
 #else
-                XmNchildType, XmFRAME_TITLE_CHILD,          
+                XmNchildType, XmFRAME_TITLE_CHILD,
 #endif
                 NULL);
     }
-    
+
     AttachWidget (parent, m_mainWidget, NULL, pos.x, pos.y, size.x, size.y);
     ChangeBackgroundColour();
 
