@@ -1,10 +1,10 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        utils.cpp
+// Name:        src/motif/utils.cpp
 // Purpose:     Various utilities
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: utils.cpp,v 1.60 2005/09/13 16:49:07 VZ Exp $
+// RCS-ID:      $Id: utils.cpp,v 1.70 2006/10/30 22:58:02 VZ Exp $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -24,12 +24,15 @@
 #define XtDisplay XTDISPLAY
 #endif
 
-#include "wx/setup.h"
 #include "wx/utils.h"
+
+#ifndef WX_PRECOMP
+    #include "wx/app.h"
+    #include "wx/dcmemory.h"
+    #include "wx/bitmap.h"
+#endif
+
 #include "wx/apptrait.h"
-#include "wx/app.h"
-#include "wx/dcmemory.h"
-#include "wx/bitmap.h"
 #include "wx/evtloop.h"
 
 #include <string.h>
@@ -140,30 +143,18 @@ void wxBell()
 }
 #endif
 
-wxToolkitInfo& wxGUIAppTraits::GetToolkitInfo()
+wxPortId wxGUIAppTraits::GetToolkitVersion(int *verMaj, int *verMin) const
 {
-    static wxToolkitInfo info;
+    // XmVERSION and XmREVISION are defined in Xm/Xm.h
+    if ( verMaj )
+        *verMaj = XmVERSION;
+    if ( verMin )
+        *verMin = XmREVISION;
 
-    info.shortName = _T("motif");
-    info.name = _T("wxMotif");
-#ifdef __WXUNIVERSAL__
-    info.shortName << _T("univ");
-    info.name << _T("/wxUniversal");
-#endif
-    // FIXME TODO
-    // This code is WRONG!! Does NOT return the
-    // Motif version of the libs but the X protocol
-    // version!
-    Display *display = wxGlobalDisplay();
-    if (display)
-    {
-        info.versionMajor = ProtocolVersion (display);
-        info.versionMinor = ProtocolRevision (display);
-    }
-    info.os = wxMOTIF_X;
-    return info;
+    return wxPORT_MOTIF;
 }
 
+
 // ----------------------------------------------------------------------------
 // Reading and writing resources (eg WIN.INI, .Xdefaults)
 // ----------------------------------------------------------------------------
@@ -180,7 +171,7 @@ static char * GetIniFile (char *dest, const char *filename)
     {
         strcpy(dest, filename);
     }
-    else if ((home = wxGetUserHome("")) != NULL)
+    else if ((home = wxGetUserHome()) != NULL)
     {
         strcpy(dest, home);
         if (dest[strlen(dest) - 1] != '/')
@@ -314,7 +305,7 @@ bool wxGetResource(const wxString& section, const wxString& entry, char **value,
 
     XrmDatabase database;
 
-    if (file != "")
+    if (!file.empty())
     {
         char buffer[500];
 
@@ -454,7 +445,7 @@ void wxXMergeDatabases (wxApp * theApp, Display * display)
         environment = GetIniFile (filename, NULL);
         len = strlen (environment);
         wxString hostname = wxGetHostName();
-        if ( !!hostname )
+        if ( !hostname.empty() )
             strncat(environment, hostname, 1024 - len);
     }
     homeDB = XrmGetFileDatabase (environment);
@@ -529,7 +520,7 @@ void wxGetMousePosition( int* x, int* y )
     *x = xev.x_root;
     *y = xev.y_root;
 #endif
-};
+}
 
 // Return true if we have a colour display
 bool wxColourDisplay()
@@ -667,9 +658,9 @@ void wxHSVToXColor(wxHSV *hsv,XColor *rgb)
     case 4: r = t, g = p, b = v; break;
     case 5: r = v, g = p, b = q; break;
     }
-    rgb->red = r << 8;
-    rgb->green = g << 8;
-    rgb->blue = b << 8;
+    rgb->red = (unsigned short)(r << 8);
+    rgb->green = (unsigned short)(g << 8);
+    rgb->blue = (unsigned short)(b << 8);
 }
 
 void wxXColorToHSV(wxHSV *hsv,XColor *rgb)
@@ -811,6 +802,7 @@ char wxFindMnemonic (const char *s)
 char* wxFindAccelerator( const char *s )
 {
 #if 1
+    wxUnusedVar(s);
     // VZ: this function returns incorrect keysym which completely breaks kbd
     //     handling
     return NULL;
@@ -878,6 +870,7 @@ char* wxFindAccelerator( const char *s )
 XmString wxFindAcceleratorText (const char *s)
 {
 #if 1
+    wxUnusedVar(s);
     // VZ: this function returns incorrect keysym which completely breaks kbd
     //     handling
     return NULL;
@@ -908,7 +901,7 @@ void wxDoChangeForegroundColour(WXWidget widget, wxColour& foregroundColour)
         NULL);
 }
 
-void wxDoChangeBackgroundColour(WXWidget widget, wxColour& backgroundColour, bool changeArmColour)
+void wxDoChangeBackgroundColour(WXWidget widget, const wxColour& backgroundColour, bool changeArmColour)
 {
     wxComputeColours (XtDisplay((Widget) widget), & backgroundColour,
         (wxColour*) NULL);
@@ -926,7 +919,7 @@ void wxDoChangeBackgroundColour(WXWidget widget, wxColour& backgroundColour, boo
         NULL);
 }
 
-extern void wxDoChangeFont(WXWidget widget, wxFont& font)
+extern void wxDoChangeFont(WXWidget widget, const wxFont& font)
 {
     // Lesstif 0.87 hangs here, but 0.93 does not; MBN: sometimes it does
 #if !wxCHECK_LESSTIF() // || wxCHECK_LESSTIF_VERSION( 0, 93 )
@@ -934,6 +927,9 @@ extern void wxDoChangeFont(WXWidget widget, wxFont& font)
     XtVaSetValues( w,
                    wxFont::GetFontTag(), font.GetFontTypeC( XtDisplay(w) ),
                    NULL );
+#else
+    wxUnusedVar(widget);
+    wxUnusedVar(font);
 #endif
 
 }
@@ -967,7 +963,7 @@ XmString wxStringToXmString( const char* str )
 
 // Creates a bitmap with transparent areas drawn in
 // the given colour.
-wxBitmap wxCreateMaskedBitmap(const wxBitmap& bitmap, wxColour& colour)
+wxBitmap wxCreateMaskedBitmap(const wxBitmap& bitmap, const wxColour& colour)
 {
     wxBitmap newBitmap(bitmap.GetWidth(),
                        bitmap.GetHeight(),
@@ -975,7 +971,7 @@ wxBitmap wxCreateMaskedBitmap(const wxBitmap& bitmap, wxColour& colour)
     wxMemoryDC destDC;
     wxMemoryDC srcDC;
 
-    srcDC.SelectObject(bitmap);
+    srcDC.SelectObjectAsSource(bitmap);
     destDC.SelectObject(newBitmap);
 
     wxBrush brush(colour, wxSOLID);
