@@ -1,10 +1,10 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        windows.cpp
+// Name:        src/motif/window.cpp
 // Purpose:     wxWindow
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: window.cpp,v 1.137 2005/09/18 14:11:14 VZ Exp $
+// RCS-ID:      $Id: window.cpp,v 1.163 2006/10/15 15:51:35 MBN Exp $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -17,10 +17,6 @@
 // headers
 // ----------------------------------------------------------------------------
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-    #pragma implementation "window.h"
-#endif
-
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
@@ -30,22 +26,24 @@
 #define XtScreen XTSCREEN
 #endif
 
-#include "wx/setup.h"
-#include "wx/menu.h"
-#include "wx/dc.h"
-#include "wx/dcclient.h"
-#include "wx/utils.h"
-#include "wx/app.h"
-#include "wx/layout.h"
-#include "wx/button.h"
-#include "wx/settings.h"
-#include "wx/frame.h"
-#include "wx/scrolwin.h"
-#include "wx/module.h"
-#include "wx/menuitem.h"
-#include "wx/log.h"
+#ifndef WX_PRECOMP
+    #include "wx/hash.h"
+    #include "wx/log.h"
+    #include "wx/app.h"
+    #include "wx/utils.h"
+    #include "wx/frame.h"
+    #include "wx/dc.h"
+    #include "wx/dcclient.h"
+    #include "wx/button.h"
+    #include "wx/menu.h"
+    #include "wx/settings.h"
+    #include "wx/scrolwin.h"
+    #include "wx/layout.h"
+    #include "wx/menuitem.h"
+    #include "wx/module.h"
+#endif
+
 #include "wx/evtloop.h"
-#include "wx/hash.h"
 
 #if  wxUSE_DRAG_AND_DROP
     #include "wx/dnd.h"
@@ -67,7 +65,7 @@
 // 2) call DoMoveWindow from DoSetSize, allowing controls to override it
 
 #ifdef __VMS__
-#pragma message disable nosimpint
+    #pragma message disable nosimpint
 #endif
 #include <Xm/Xm.h>
 
@@ -78,7 +76,7 @@
 #include <Xm/Label.h>
 #include <Xm/RowColumn.h>           // for XmMenuPosition
 #ifdef __VMS__
-#pragma message enable nosimpint
+    #pragma message enable nosimpint
 #endif
 
 #include "wx/motif/private.h"
@@ -204,7 +202,7 @@ void wxWindow::Init()
     m_winCaptured = false;
 
     m_isShown = true;
-    
+
     m_hScrollBar =
     m_vScrollBar =
     m_borderWidget =
@@ -356,7 +354,7 @@ wxWindow::~wxWindow()
 {
     if (g_captureWindow == this)
         g_captureWindow = NULL;
-    
+
     m_isBeingDeleted = true;
 
     // Motif-specific actions first
@@ -636,17 +634,17 @@ void wxWindow::Lower()
     XLowerWindow(XtDisplay(wTop), window);
 }
 
-void wxWindow::SetTitle(const wxString& title)
+void wxWindow::SetLabel(const wxString& label)
 {
-    XtVaSetValues((Widget)GetMainWidget(), XmNtitle, title.c_str(), NULL);
+    XtVaSetValues((Widget)GetMainWidget(), XmNtitle, label.c_str(), NULL);
 }
 
-wxString wxWindow::GetTitle() const
+wxString wxWindow::GetLabel() const
 {
-    char *title;
-    XtVaGetValues((Widget)GetMainWidget(), XmNtitle, &title, NULL);
+    char *label;
+    XtVaGetValues((Widget)GetMainWidget(), XmNtitle, &label, NULL);
 
-    return wxString(title);
+    return wxString(label);
 }
 
 void wxWindow::DoCaptureMouse()
@@ -698,7 +696,7 @@ bool wxWindow::SetCursor(const wxCursor& cursor)
 
     //    wxASSERT_MSG( m_cursor.Ok(),
     //                  wxT("cursor must be valid after call to the base version"));
-    wxCursor* cursor2 = NULL;
+    const wxCursor* cursor2 = NULL;
     if (m_cursor.Ok())
         cursor2 = & m_cursor;
     else
@@ -751,12 +749,12 @@ int wxWindow::GetScrollPos(int orient) const
 int wxWindow::GetScrollRange(int orient) const
 {
     Widget scrollBar = (Widget)GetScrollbar((wxOrientation)orient);
-    // CE scintilla windows don't always have these scrollbars 
+    // CE scintilla windows don't always have these scrollbars
     // and it tends to pile up a whole bunch of asserts
     //wxCHECK_MSG( scrollBar, 0, "no such scrollbar" );
 
     int range = 0;
-    if (scrollBar) 
+    if (scrollBar)
         XtVaGetValues(scrollBar, XmNmaximum, &range, NULL);
     return range;
 }
@@ -856,7 +854,7 @@ void wxWindow::SetScrollbar(int orient, int pos, int thumbVisible,
 
     // Adjusting scrollbars can resize the canvas accidentally
     if (newW != oldW || newH != oldH)
-        SetSize(-1, -1, oldW, oldH);
+        SetSize(wxDefaultCoord, wxDefaultCoord, oldW, oldH);
 }
 
 // Does a physical scroll
@@ -1069,7 +1067,7 @@ void wxWindow::DoSetToolTip(wxToolTip * WXUNUSED(tooltip))
 
 bool wxWindow::DoPopupMenu(wxMenu *menu, int x, int y)
 {
-    if ( x == -1 && y == -1 )
+    if ( x == wxDefaultCoord && y == wxDefaultCoord )
     {
         wxPoint mouse = ScreenToClient(wxGetMousePosition());
         x = mouse.x; y = mouse.y;
@@ -1093,7 +1091,7 @@ bool wxWindow::DoPopupMenu(wxMenu *menu, int x, int y)
     }
 
     menu->SetId(1); /* Mark as popped-up */
-    menu->CreateMenu(NULL, widget, menu);
+    menu->CreateMenu(NULL, widget, menu, 0);
     menu->SetInvokingWindow(this);
 
     menu->UpdateUI();
@@ -1179,7 +1177,7 @@ void wxWindow::DoGetSize(int *x, int *y) const
                    XmNwidth, &xx,
                    XmNheight, &yy,
                    NULL );
-    if(x) *x = xx; 
+    if(x) *x = xx;
     if(y) *y = yy;
 }
 
@@ -1187,7 +1185,7 @@ void wxWindow::DoGetPosition(int *x, int *y) const
 {
     Widget widget = (Widget)
         ( m_drawingArea ?
-          ( m_borderWidget ? m_borderWidget : m_scrolledWindow ) : 
+          ( m_borderWidget ? m_borderWidget : m_scrolledWindow ) :
           GetTopWidget() );
 
     Position xx, yy;
@@ -1198,8 +1196,8 @@ void wxWindow::DoGetPosition(int *x, int *y) const
     if (GetParent())
     {
         wxPoint pt(GetParent()->GetClientAreaOrigin());
-        xx -= pt.x;
-        yy -= pt.y;
+        xx = (Position)(xx - pt.x);
+        yy = (Position)(yy - pt.y);
     }
 
     if(x) *x = xx;
@@ -1252,6 +1250,7 @@ void wxWindow::DoSetSizeIntr(int x, int y, int width, int height,
 {
     // A bit of optimization to help sort out the flickers.
     int oldX = -1, oldY = -1, oldW = -1, oldH = -1;
+
     if( !fromCtor )
     {
         GetSize(& oldW, & oldH);
@@ -1260,13 +1259,13 @@ void wxWindow::DoSetSizeIntr(int x, int y, int width, int height,
 
     if ( !(sizeFlags & wxSIZE_ALLOW_MINUS_ONE) )
     {
-        if ( x == -1 )
-            x = oldX;
-        if ( y == -1 )
-            y = oldY;
+        if ( width == -1 )
+            width = oldW;
+        if ( height == -1 )
+            height = oldH;
     }
 
-    wxSize size(-1, -1);
+    wxSize size(wxDefaultSize);
     if ( width <= 0 )
     {
         if ( ( sizeFlags & wxSIZE_AUTO_WIDTH ) && !fromCtor )
@@ -1300,10 +1299,10 @@ void wxWindow::DoSetSizeIntr(int x, int y, int width, int height,
         {
             int flags = 0;
 
-            if (x > -1 || (sizeFlags & wxSIZE_ALLOW_MINUS_ONE))
+            if (x != oldX)
                 flags |= wxMOVE_X;
 
-            if (y > -1 || (sizeFlags & wxSIZE_ALLOW_MINUS_ONE))
+            if (y != oldY)
                 flags |= wxMOVE_Y;
 
             if (width > 0)
@@ -1430,8 +1429,6 @@ void wxWindow::DoMoveWindowIntr(int xx, int yy, int w, int h,
     }
     else
     {
-        if( xx < 0 ) xx = 0;
-        if( yy < 0 ) yy = 0;
         if( w < 1 ) w = 1;
         if( h < 1 ) h = 1;
 
@@ -1459,7 +1456,7 @@ int wxWindow::GetCharHeight() const
     wxCHECK_MSG( m_font.Ok(), 0, "valid window font needed" );
 
     int height;
-    
+
     wxGetTextExtent (GetXDisplay(), m_font, 1.0,
                      "x", NULL, &height, NULL, NULL);
 
@@ -1471,7 +1468,7 @@ int wxWindow::GetCharWidth() const
     wxCHECK_MSG( m_font.Ok(), 0, "valid window font needed" );
 
     int width;
-    
+
     wxGetTextExtent (GetXDisplay(), m_font, 1.0,
                      "x", &width, NULL, NULL, NULL);
 
@@ -1898,9 +1895,8 @@ void wxWidgetResizeProc(Widget w, XConfigureEvent *WXUNUSED(event),
 
     if (win->PreResize())
     {
-        int width, height;
-        win->GetSize(&width, &height);
-        wxSizeEvent sizeEvent(wxSize(width, height), win->GetId());
+        wxSize newSize(win->GetSize());
+        wxSizeEvent sizeEvent(newSize, win->GetId());
         sizeEvent.SetEventObject(win);
         win->GetEventHandler()->ProcessEvent(sizeEvent);
     }
@@ -2319,10 +2315,10 @@ bool wxTranslateMouseEvent(wxMouseEvent& wxevent, wxWindow *win,
                 || (event_right_is_down (xevent)
                 && (eventType != wxEVT_RIGHT_UP)));
 
-            wxevent.m_shiftDown = xevent->xbutton.state & ShiftMask;
-            wxevent.m_controlDown = xevent->xbutton.state & ControlMask;
-            wxevent.m_altDown = xevent->xbutton.state & Mod3Mask;
-            wxevent.m_metaDown = xevent->xbutton.state & Mod1Mask;
+            wxevent.m_shiftDown = (xevent->xbutton.state & ShiftMask) == ShiftMask;
+            wxevent.m_controlDown = (xevent->xbutton.state & ControlMask) == ControlMask;
+            wxevent.m_altDown = (xevent->xbutton.state & Mod3Mask) == Mod3Mask;
+            wxevent.m_metaDown = (xevent->xbutton.state & Mod1Mask) == Mod1Mask;
 
             wxevent.SetId(win->GetId());
             wxevent.SetEventObject(win);
@@ -2368,9 +2364,8 @@ bool wxTranslateKeyEvent(wxKeyEvent& wxevent, wxWindow *win,
 
             if (id > -1)
                 return true;
-            else
-                return false;
-            break;
+
+            return false;
         }
     default:
         break;
@@ -2384,7 +2379,7 @@ bool wxTranslateKeyEvent(wxKeyEvent& wxevent, wxWindow *win,
 
 #define YAllocColor XAllocColor
 XColor g_itemColors[5];
-int wxComputeColours (Display *display, wxColour * back, wxColour * fore)
+int wxComputeColours (Display *display, const wxColour * back, const wxColour * fore)
 {
     int result;
     static XmColorProc colorProc;
@@ -2393,9 +2388,9 @@ int wxComputeColours (Display *display, wxColour * back, wxColour * fore)
 
     if (back)
     {
-        g_itemColors[0].red = (((long) back->Red ()) << 8);
-        g_itemColors[0].green = (((long) back->Green ()) << 8);
-        g_itemColors[0].blue = (((long) back->Blue ()) << 8);
+        g_itemColors[0].red = (unsigned short)(((long) back->Red ()) << 8);
+        g_itemColors[0].green = (unsigned short)(((long) back->Green ()) << 8);
+        g_itemColors[0].blue = (unsigned short)(((long) back->Blue ()) << 8);
         g_itemColors[0].flags = DoRed | DoGreen | DoBlue;
         if (colorProc == (XmColorProc) NULL)
         {
@@ -2413,9 +2408,9 @@ int wxComputeColours (Display *display, wxColour * back, wxColour * fore)
     }
     if (fore)
     {
-        g_itemColors[wxFORE_INDEX].red = (((long) fore->Red ()) << 8);
-        g_itemColors[wxFORE_INDEX].green = (((long) fore->Green ()) << 8);
-        g_itemColors[wxFORE_INDEX].blue = (((long) fore->Blue ()) << 8);
+        g_itemColors[wxFORE_INDEX].red = (unsigned short)(((long) fore->Red ()) << 8);
+        g_itemColors[wxFORE_INDEX].green = (unsigned short)(((long) fore->Green ()) << 8);
+        g_itemColors[wxFORE_INDEX].blue = (unsigned short)(((long) fore->Blue ()) << 8);
         g_itemColors[wxFORE_INDEX].flags = DoRed | DoGreen | DoBlue;
         if (result == wxNO_COLORS)
             result = wxFORE_COLORS;
@@ -2498,7 +2493,7 @@ void wxWindow::ChangeFont(bool keepOriginalSize)
         GetSize(& width1, & height1);
         if (keepOriginalSize && (width != width1 || height != height1))
         {
-            SetSize(-1, -1, width, height);
+            SetSize(wxDefaultCoord, wxDefaultCoord, width, height);
         }
     }
 }
@@ -2525,24 +2520,55 @@ wxWindow *wxWindowBase::GetCapture()
 // position.
 wxWindow* wxFindWindowAtPointer(wxPoint& pt)
 {
-    return wxFindWindowAtPoint(wxGetMousePosition());
+    pt = wxGetMousePosition();
+    return wxFindWindowAtPoint(pt);
 }
 
-// Get the current mouse position.
-wxPoint wxGetMousePosition()
+void wxGetMouseState(int& rootX, int& rootY, unsigned& maskReturn)
 {
     Display *display = wxGlobalDisplay();
     Window rootWindow = RootWindowOfScreen (DefaultScreenOfDisplay(display));
     Window rootReturn, childReturn;
-    int rootX, rootY, winX, winY;
-    unsigned int maskReturn;
+    int winX, winY;
 
     XQueryPointer (display,
                    rootWindow,
                    &rootReturn,
                    &childReturn,
                    &rootX, &rootY, &winX, &winY, &maskReturn);
-    return wxPoint(rootX, rootY);
+}
+
+// Get the current mouse position.
+wxPoint wxGetMousePosition()
+{
+    int x, y;
+    unsigned mask;
+
+    wxGetMouseState(x, y, mask);
+    return wxPoint(x, y);
+}
+
+wxMouseState wxGetMouseState()
+{
+    wxMouseState ms;
+    int x, y;
+    unsigned mask;
+
+    wxGetMouseState(x, y, mask);
+
+    ms.SetX(x);
+    ms.SetY(y);
+
+    ms.SetLeftDown(mask & Button1Mask);
+    ms.SetMiddleDown(mask & Button2Mask);
+    ms.SetRightDown(mask & Button3Mask);
+
+    ms.SetControlDown(mask & ControlMask);
+    ms.SetShiftDown(mask & ShiftMask);
+    ms.SetAltDown(mask & Mod3Mask);
+    ms.SetMetaDown(mask & Mod1Mask);
+
+    return ms;
 }
 
 
@@ -2551,4 +2577,3 @@ wxPoint wxGetMousePosition()
 // ----------------------------------------------------------------------------
 
 int wxNoOptimize::ms_count = 0;
-
