@@ -1,31 +1,29 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        control.cpp
+// Name:        src/os2/control.cpp
 // Purpose:     wxControl class
 // Author:      David Webster
 // Modified by:
 // Created:     09/17/99
-// RCS-ID:      $Id: control.cpp,v 1.36 2005/05/14 17:34:10 SN Exp $
+// RCS-ID:      $Id: control.cpp,v 1.43 2006/07/16 21:26:04 SN Exp $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
-#ifdef __GNUG__
-#pragma implementation "control.h"
-#endif
-
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
-#ifndef WX_PRECOMP
-#include "wx/event.h"
-#include "wx/app.h"
-#include "wx/dcclient.h"
-#include "wx/scrolwin.h"
-#include "wx/log.h"
-#endif
-#include "wx/os2/private.h"
 #include "wx/control.h"
 
+#ifndef WX_PRECOMP
+    #include "wx/event.h"
+    #include "wx/app.h"
+    #include "wx/dcclient.h"
+    #include "wx/scrolwin.h"
+    #include "wx/log.h"
+#endif
+
+#include "wx/os2/private.h"
+
 IMPLEMENT_ABSTRACT_CLASS(wxControl, wxWindow)
 
 BEGIN_EVENT_TABLE(wxControl, wxWindow)
@@ -37,15 +35,13 @@ wxControl::wxControl()
 {
 } // end of wxControl::wxControl
 
-bool wxControl::Create(
-  wxWindow*                         pParent
-, wxWindowID                        vId
-, const wxPoint&                    rPos
-, const wxSize&                     rSize
-, long                              lStyle
-, const wxValidator&                rValidator
-, const wxString&                   rsName
-)
+bool wxControl::Create( wxWindow*           pParent,
+                        wxWindowID          vId,
+                        const wxPoint&      rPos,
+                        const wxSize&       rSize,
+                        long                lStyle,
+                        const wxValidator&  rValidator,
+                        const wxString&     rsName )
 {
     bool                            bRval = wxWindow::Create( pParent
                                                              ,vId
@@ -65,21 +61,17 @@ bool wxControl::Create(
 
 wxControl::~wxControl()
 {
-    m_isBeingDeleted = TRUE;
+    m_isBeingDeleted = true;
 }
 
-bool wxControl::OS2CreateControl(
-  const wxChar*                     zClassname
-, const wxString&                   rsLabel
-, const wxPoint&                    rPos
-, const wxSize&                     rSize
-, long                              lStyle
-)
+bool wxControl::OS2CreateControl( const wxChar* zClassname,
+                                  const wxString& rsLabel,
+                                  const wxPoint& rPos,
+                                  const wxSize& rSize,
+                                  long lStyle )
 {
-    WXDWORD                         dwExstyle;
-    WXDWORD                         dwStyle = OS2GetStyle( lStyle
-                                                          ,&dwExstyle
-                                                         );
+    WXDWORD dwExstyle;
+    WXDWORD dwStyle = OS2GetStyle( lStyle, &dwExstyle );
 
     return OS2CreateControl( zClassname
                             ,dwStyle
@@ -90,14 +82,12 @@ bool wxControl::OS2CreateControl(
                            );
 } // end of wxControl::OS2CreateControl
 
-bool wxControl::OS2CreateControl(
-  const wxChar*                     zClassname
-, WXDWORD                           dwStyle
-, const wxPoint&                    rPos
-, const wxSize&                     rSize
-, const wxString&                   rsLabel
-, WXDWORD                           dwExstyle
-)
+bool wxControl::OS2CreateControl( const wxChar*   zClassname,
+                                  WXDWORD         dwStyle,
+                                  const wxPoint&  rPos,
+                                  const wxSize&   rSize,
+                                  const wxString& rsLabel,
+                                  WXDWORD         dwExstyle )
 {
     //
     // Doesn't do anything at all under OS/2
@@ -105,7 +95,7 @@ bool wxControl::OS2CreateControl(
     if (dwExstyle == (WXDWORD)-1)
     {
         dwExstyle = 0;
-	(void) OS2GetStyle(GetWindowStyle(), &dwExstyle);
+        (void) OS2GetStyle(GetWindowStyle(), &dwExstyle);
     }
     //
     // All controls should have these styles (wxWidgets creates all controls
@@ -114,11 +104,11 @@ bool wxControl::OS2CreateControl(
     if (m_isShown )
         dwStyle |= WS_VISIBLE;
 
-    wxWindow*                       pParent = GetParent();
-    PSZ                             zClass = "";
+    wxWindow* pParent = GetParent();
+    PSZ zClass = "";
 
     if (!pParent)
-        return FALSE;
+        return false;
 
     if ((wxStrcmp(zClassname, _T("COMBOBOX"))) == 0)
         zClass = WC_COMBOBOX;
@@ -130,13 +120,23 @@ bool wxControl::OS2CreateControl(
         zClass = WC_NOTEBOOK;
     else if ((wxStrcmp(zClassname, _T("CONTAINER"))) == 0)
         zClass = WC_CONTAINER;
-    dwStyle |= WS_VISIBLE;
+    if ((zClass == WC_STATIC) || (zClass == WC_BUTTON))
+        dwStyle |= DT_MNEMONIC;
 
-    wxString                        sLabel = ::wxPMTextToLabel(rsLabel);
+    m_dwStyle = dwStyle;
+    m_label = rsLabel;
+    wxString label;
+    if (dwStyle & DT_MNEMONIC)
+        label = ::wxPMTextToLabel(m_label);
+    else
+        label = m_label;
+
+    // clipping siblings does not yet work
+    dwStyle &= ~WS_CLIPSIBLINGS;
 
     m_hWnd = (WXHWND)::WinCreateWindow( (HWND)GetHwndOf(pParent) // Parent window handle
                                        ,(PSZ)zClass              // Window class
-                                       ,(PSZ)sLabel.c_str()      // Initial Text
+                                       ,(PSZ)label.c_str()       // Initial Text
                                        ,(ULONG)dwStyle           // Style flags
                                        ,(LONG)0                  // X pos of origin
                                        ,(LONG)0                  // Y pos of origin
@@ -155,7 +155,7 @@ bool wxControl::OS2CreateControl(
         wxLogError(wxT("Failed to create a control of class '%s'"), zClassname);
 #endif // DEBUG
 
-        return FALSE;
+        return false;
     }
     //
     // Subclass again for purposes of dialog editing mode
@@ -173,12 +173,8 @@ bool wxControl::OS2CreateControl(
 
     SetXComp(0);
     SetYComp(0);
-    SetSize( rPos.x
-            ,rPos.y
-            ,rSize.x
-            ,rSize.y
-           );
-    return TRUE;
+    SetSize( rPos.x, rPos.y, rSize.x, rSize.y );
+    return true;
 } // end of wxControl::OS2CreateControl
 
 wxSize wxControl::DoGetBestSize() const
@@ -191,18 +187,16 @@ bool wxControl::ProcessCommand(wxCommandEvent& event)
     return GetEventHandler()->ProcessEvent(event);
 }
 
-WXHBRUSH wxControl::OnCtlColor(
-  WXHDC                             hWxDC
-, WXHWND                            hWnd
-, WXUINT                            uCtlColor
-, WXUINT                            uMessage
-, WXWPARAM                          wParam
-, WXLPARAM                          lParam
-)
+WXHBRUSH wxControl::OnCtlColor(WXHDC    hWxDC,
+                               WXHWND   WXUNUSED(hWnd),
+                               WXUINT   WXUNUSED(uCtlColor),
+                               WXUINT   WXUNUSED(uMessage),
+                               WXWPARAM WXUNUSED(wParam),
+                               WXLPARAM WXUNUSED(lParam))
 {
-    HPS                             hPS = (HPS)hWxDC; // pass in a PS handle in OS/2
-    wxColour                        vColFore = GetForegroundColour();
-    wxColour                        vColBack = GetBackgroundColour();
+    HPS      hPS = (HPS)hWxDC; // pass in a PS handle in OS/2
+    wxColour vColFore = GetForegroundColour();
+    wxColour vColBack = GetBackgroundColour();
 
     if (GetParent()->GetTransparentBackground())
         ::GpiSetBackMix(hPS, BM_LEAVEALONE);
@@ -212,15 +206,13 @@ WXHBRUSH wxControl::OnCtlColor(
     ::GpiSetBackColor(hPS, vColBack.GetPixel());
     ::GpiSetColor(hPS, vColFore.GetPixel());
 
-    wxBrush*                        pBrush = wxTheBrushList->FindOrCreateBrush( vColBack
-                                                                               ,wxSOLID
-                                                                              );
+    wxBrush* pBrush = wxTheBrushList->FindOrCreateBrush( vColBack
+                                                         ,wxSOLID
+                                                       );
     return (WXHBRUSH)pBrush->GetResourceHandle();
 } // end of wxControl::OnCtlColor
 
-void wxControl::OnEraseBackground(
-  wxEraseEvent&                     rEvent
-)
+void wxControl::OnEraseBackground( wxEraseEvent& rEvent )
 {
     RECTL                           vRect;
     HPS                             hPS = rEvent.GetDC()->GetHPS();
@@ -231,14 +223,9 @@ void wxControl::OnEraseBackground(
     ::WinFillRect(hPS, &vRect, GetBackgroundColour().GetPixel());
 } // end of wxControl::OnEraseBackground
 
-WXDWORD wxControl::OS2GetStyle(
-  long                              lStyle
-, WXDWORD*                          pdwExstyle
-) const
+WXDWORD wxControl::OS2GetStyle( long lStyle, WXDWORD* pdwExstyle ) const
 {
-    long                            dwStyle = wxWindow::OS2GetStyle( lStyle
-                                                                    ,pdwExstyle
-                                                                   );
+    long dwStyle = wxWindow::OS2GetStyle( lStyle, pdwExstyle );
 
     if (AcceptsFocus())
     {
@@ -247,13 +234,18 @@ WXDWORD wxControl::OS2GetStyle(
     return dwStyle;
 } // end of wxControl::OS2GetStyle
 
-void wxControl::SetLabel(
-  const wxString&                   rsLabel
-)
+void wxControl::SetLabel( const wxString& rsLabel )
 {
-    wxString                        sLabel = ::wxPMTextToLabel(rsLabel);
-
-    ::WinSetWindowText(GetHwnd(), (PSZ)sLabel.c_str());
+    if(rsLabel != m_label)
+    {
+        m_label = rsLabel;
+        wxString label;
+        if (m_dwStyle & DT_MNEMONIC)
+            label = ::wxPMTextToLabel(m_label);
+        else
+            label = m_label;
+        ::WinSetWindowText(GetHwnd(), (PSZ)label.c_str());
+    }
 } // end of wxControl::SetLabel
 
 // ---------------------------------------------------------------------------
@@ -292,5 +284,3 @@ void wxFindMaxSize(
     if (nBottom < pRect->yBottom)
         pRect->yBottom = nBottom;
 } // end of wxFindMaxSize
-
-
