@@ -1,10 +1,10 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        dcclient.cpp
+// Name:        src/os2/dcclient.cpp
 // Purpose:     wxClientDC class
 // Author:      David Webster
 // Modified by:
 // Created:     09/21/99
-// RCS-ID:      $Id: dcclient.cpp,v 1.38 2006/01/02 16:32:12 SN Exp $
+// RCS-ID:      $Id: dcclient.cpp,v 1.44 2006/06/07 13:25:59 ABX Exp $
 // Copyright:   (c) David Webster
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -20,15 +20,17 @@
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
-#include "wx/string.h"
-#include "wx/log.h"
-#include "wx/window.h"
-#include "wx/app.h"
+#include "wx/dcclient.h"
+
+#ifndef WX_PRECOMP
+    #include "wx/string.h"
+    #include "wx/log.h"
+    #include "wx/app.h"
+    #include "wx/window.h"
+#endif
 
 #include "wx/os2/private.h"
 
-#include "wx/dcclient.h"
-
 // ----------------------------------------------------------------------------
 // array/list types
 // ----------------------------------------------------------------------------
@@ -137,7 +139,7 @@ wxWindowDC::wxWindowDC(
     {
         vError = ::WinGetLastError(vHabmain);
         sError = wxPMErrorToStr(vError);
-        wxLogError(_T("Unable to set current color table. Error: %s\n"), sError.c_str());
+        wxLogError(_T("Unable to set current color table (3). Error: %s\n"), sError.c_str());
     }
     ::GpiCreateLogColorTable( m_hPS
                              ,0L
@@ -166,17 +168,10 @@ void wxWindowDC::InitDC()
     //
     SetBackground(wxBrush(m_pCanvas->GetBackgroundColour(), wxSOLID));
 
-    wxColour vColor( wxT("BLACK") );
-    m_pen.SetColour(vColor);
-
-    vColor.Set( wxT("WHITE") );
-    m_brush.SetColour(vColor);
+    m_pen.SetColour(*wxBLACK);
+    m_brush.SetColour(*wxWHITE);
     InitializePalette();
-    wxFont*                         pFont = new wxFont( 10
-                                                       ,wxMODERN
-                                                       ,wxNORMAL
-                                                       ,wxBOLD
-                                                      );
+    wxFont* pFont = new wxFont( 10, wxMODERN, wxNORMAL, wxBOLD );
     SetFont(*pFont);
     delete pFont;
     //
@@ -237,7 +232,7 @@ wxClientDC::wxClientDC(
     {
         vError = ::WinGetLastError(vHabmain);
         sError = wxPMErrorToStr(vError);
-        wxLogError(_T("Unable to set current color table. Error: %s\n"), sError.c_str());
+        wxLogError(_T("Unable to set current color table (4). Error: %s\n"), sError.c_str());
     }
     ::GpiCreateLogColorTable( m_hPS
                              ,0L
@@ -362,7 +357,7 @@ wxPaintDC::wxPaintDC(
                                 );
         }
 
-        m_bIsPaintTime   = TRUE;
+        m_bIsPaintTime   = true;
         ms_cache.Add(new wxPaintDCInfo(m_pCanvas, this));
     }
     InitDC();
@@ -383,7 +378,7 @@ wxPaintDC::~wxPaintDC()
         {
             ::WinEndPaint(m_hPS);
             m_hPS          = m_hOldPS;
-            m_bIsPaintTime = FALSE;
+            m_bIsPaintTime = false;
             ms_cache.RemoveAt(nIndex);
         }
         //else: cached DC entry is still in use
@@ -431,4 +426,3 @@ WXHDC wxPaintDC::FindDCInCache(
     }
     return 0;
 } // end of wxPaintDC::FindInCache
-
