@@ -4,7 +4,7 @@
 // Author:      Vadim Zeitlin
 // Modified by: Stefan Neis
 // Created:     08.12.99
-// RCS-ID:      $Id: dir.cpp,v 1.12 2005/04/27 01:19:39 DW Exp $
+// RCS-ID:      $Id: dir.cpp,v 1.13 2005/09/23 12:55:29 MR Exp $
 // Copyright:   (c) 1999 Vadim Zeitlin <zeitlin@dptmaths.ens-cachan.fr>
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -17,10 +17,6 @@
 // headers
 // ----------------------------------------------------------------------------
 
-#ifdef __GNUG__
-    #pragma implementation "dir.h"
-#endif
-
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
