@@ -1,31 +1,27 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        dirdlg.cpp
+// Name:        src/os2/dirdlg.cpp
 // Purpose:     wxDirDialog
 // Author:      David Webster
 // Modified by:
 // Created:     10/14/99
-// RCS-ID:      $Id: dirdlg.cpp,v 1.8 2004/05/23 20:53:12 JS Exp $
+// RCS-ID:      $Id: dirdlg.cpp,v 1.12 2006/05/28 23:32:10 VZ Exp $
 // Copyright:   (c) David Webster
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
-#ifdef __GNUG__
-    #pragma implementation "dirdlg.h"
-#endif
-
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
-#ifndef WX_PRECOMP
-#include <stdio.h>
-#include "wx/defs.h"
-#include "wx/utils.h"
-#include "wx/dialog.h"
 #include "wx/dirdlg.h"
+
+#ifndef WX_PRECOMP
+    #include <stdio.h>
+    #include "wx/utils.h"
+    #include "wx/dialog.h"
+    #include "wx/cmndata.h"
 #endif
 
 #include "wx/os2/private.h"
-#include "wx/cmndata.h"
 
 #include <stdlib.h>
 #include <string.h>
@@ -40,7 +36,7 @@ wxDirDialog::wxDirDialog(wxWindow *parent, const wxString& message,
         long style, const wxPoint& pos)
 {
     m_message = message;
-    m_dialogStyle = style;
+    m_windowStyle = style;
     m_parent = parent;
     m_path = defaultPath;
 }
@@ -50,4 +46,3 @@ int wxDirDialog::ShowModal()
     // TODO
     return wxID_CANCEL;
 }
-
