@@ -1,11 +1,11 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        fontdlg.cpp
+// Name:        src/os2/fontdlg.cpp
 // Purpose:     wxFontDialog class. NOTE: you can use the generic class
 //              if you wish, instead of implementing this.
 // Author:      David Webster
 // Modified by:
 // Created:     10/06/99
-// RCS-ID:      $Id: fontdlg.cpp,v 1.15 2005/04/27 01:19:40 DW Exp $
+// RCS-ID:      $Id: fontdlg.cpp,v 1.17 2006/05/25 21:08:09 ABX Exp $
 // Copyright:   (c) David Webster
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -13,22 +13,22 @@
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
+#include "wx/fontdlg.h"
+
 #ifndef WX_PRECOMP
-#include <stdio.h>
-#include "wx/defs.h"
-#include "wx/utils.h"
-#include "wx/dialog.h"
-#include "wx/math.h"
+    #include <stdio.h>
+    #include "wx/utils.h"
+    #include "wx/dialog.h"
+    #include "wx/math.h"
+    #include "wx/cmndata.h"
 #endif
 
-#include "wx/fontdlg.h"
 #include "wx/fontutil.h"
 
 #define INCL_PM
 #include <os2.h>
 
 #include "wx/os2/private.h"
-#include "wx/cmndata.h"
 
 #include <stdlib.h>
 #include <string.h>
@@ -37,10 +37,10 @@ IMPLEMENT_DYNAMIC_CLASS(wxFontDialog, wxDialog)
 
 int wxFontDialog::ShowModal()
 {
-    FONTDLG                         vFontDlg;
-    char                            zCurrentFont[FACESIZE];
-    HWND                            hWndFontDlg;
-    FACENAMEDESC                    vFn;
+    FONTDLG      vFontDlg;
+    char         zCurrentFont[FACESIZE];
+    HWND         hWndFontDlg;
+    FACENAMEDESC vFn;
 
     memset(&vFontDlg, '\0', sizeof(FONTDLG));
     zCurrentFont[0] = '\0';
@@ -98,4 +98,3 @@ int wxFontDialog::ShowModal()
     }
     return wxID_CANCEL;
 } // end of wxFontDialg::ShowModal
-
