@@ -4,14 +4,10 @@
 // Author:      Modified by David Webster for OS/2
 // Modified by:
 // Created:     01.03.00
-// RCS-ID:      $Id: fontutil.cpp,v 1.26 2005/04/27 01:19:40 DW Exp $
+// RCS-ID:      $Id: fontutil.cpp,v 1.28 2005/09/23 12:55:30 MR Exp $
 // Copyright:   (c) 1999 Vadim Zeitlin <zeitlin@dptmaths.ens-cachan.fr>
 // Licence:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
-#define DEBUG_PRINTF(NAME)   { static int raz=0; \
-  printf( #NAME " %i\n",raz); fflush(stdout);       \
-   raz++;                                        \
- }
 
 // ============================================================================
 // declarations
@@ -21,13 +17,16 @@
 // headers
 // ----------------------------------------------------------------------------
 
-#ifdef __GNUG__
-    #pragma implementation "fontutil.h"
-#endif
-
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
+#define DEBUG_PRINTF(NAME)                            \
+    {                                                 \
+        static int raz=0;                             \
+        printf( #NAME " %i\n",raz); fflush(stdout);   \
+        raz++;                                        \
+    }
+
 #ifndef WX_PRECOMP
     #include "wx/app.h"
     #include "wx/string.h"
@@ -54,9 +53,7 @@
 // convert to/from the string representation: format is
 //      encodingid;facename[;charset]
 
-bool wxNativeEncodingInfo::FromString(
-  const wxString&                   rsStr
-)
+bool wxNativeEncodingInfo::FromString( const wxString& rsStr )
 {
     wxStringTokenizer               vTokenizer(rsStr, _T(";"));
     wxString                        sEncid = vTokenizer.GetNextToken();
@@ -83,7 +80,7 @@ bool wxNativeEncodingInfo::FromString(
             return FALSE;
         }
     }
-    return TRUE;
+    return true;
 } // end of wxNativeEncodingInfo::FromString
 
 wxString wxNativeEncodingInfo::ToString() const
@@ -103,10 +100,8 @@ wxString wxNativeEncodingInfo::ToString() const
 // helper functions
 // ----------------------------------------------------------------------------
 
-bool wxGetNativeFontEncoding(
-  wxFontEncoding                    vEncoding
-, wxNativeEncodingInfo*             pInfo
-)
+bool wxGetNativeFontEncoding( wxFontEncoding vEncoding,
+                              wxNativeEncodingInfo* pInfo )
 {
     wxCHECK_MSG(pInfo, FALSE, _T("bad pointer in wxGetNativeFontEncoding") );
     if (vEncoding == wxFONTENCODING_DEFAULT)
@@ -168,7 +163,7 @@ bool wxGetNativeFontEncoding(
             pInfo->charset = 850;
             break;
     }
-    return TRUE;
+    return true;
 } // end of wxGetNativeFontEncoding
 
 wxFontEncoding wxGetFontEncFromCharSet(
@@ -223,18 +218,16 @@ wxFontEncoding wxGetFontEncFromCharSet(
     return eFontEncoding;
 } // end of wxGetNativeFontEncoding
 
-bool wxTestFontEncoding(
-  const wxNativeEncodingInfo&       rInfo
-)
+bool wxTestFontEncoding( const wxNativeEncodingInfo& rInfo )
 {
-    FATTRS                          vLogFont;
-    HPS                             hPS;
+    FATTRS vLogFont;
+    HPS    hPS;
 
     hPS = ::WinGetPS(HWND_DESKTOP);
 
     memset(&vLogFont, '\0', sizeof(FATTRS));           // all default values
     vLogFont.usRecordLength = sizeof(FATTRS);
-    vLogFont.usCodePage = rInfo.charset;
+    vLogFont.usCodePage = (USHORT)rInfo.charset;
     vLogFont.lMaxBaselineExt = 0L;                    // Outline fonts should use 0
     vLogFont.lAveCharWidth = 0L;                      // Outline fonts should use 0
     vLogFont.fsFontUse = FATTR_FONTUSE_OUTLINE |      // only outline fonts allowed
@@ -252,7 +245,7 @@ bool wxTestFontEncoding(
         return FALSE;
     }
     ::WinReleasePS(hPS);
-    return TRUE;
+    return true;
 } // end of wxTestFontEncoding
 
 // ----------------------------------------------------------------------------
@@ -297,21 +290,19 @@ void wxConvertVectorFontSize(
 
 } // end of wxConvertVectorPointSize
 
-void wxFillLogFont(
-  LOGFONT*                          pFattrs  // OS2 GPI FATTRS
-, PFACENAMEDESC                     pFaceName
-, HPS*                              phPS
-, bool*                             pbInternalPS
-, long*                             pflId
-, wxString&                         sFaceName
-, wxFont*                           pFont
-)
+void wxFillLogFont( LOGFONT*      pFattrs,  // OS2 GPI FATTRS
+                    PFACENAMEDESC pFaceName,
+                    HPS*          phPS,
+                    bool*         pbInternalPS,
+                    long*         pflId,
+                    wxString&     sFaceName,
+                    wxFont*       pFont )
 {
-    LONG                            lNumFonts = 0L;       // For system font count
-    ERRORID                         vError;               // For logging API errors
-    LONG                            lTemp = 0L;
-    bool                            bInternalPS = FALSE;  // if we have to create one
-    PFONTMETRICS                    pFM = NULL;
+    LONG         lNumFonts = 0L;       // For system font count
+    ERRORID      vError;               // For logging API errors
+    LONG         lTemp = 0L;
+    bool         bInternalPS = false;  // if we have to create one
+    PFONTMETRICS pFM = NULL;
 
     //
     // Initial house cleaning to free data buffers and ensure we have a
@@ -320,7 +311,7 @@ void wxFillLogFont(
     if (!*phPS)
     {
         *phPS = ::WinGetPS(HWND_DESKTOP);
-        bInternalPS = TRUE;
+        bInternalPS = true;
     }
 
     //
@@ -712,4 +703,3 @@ int wxGpiStrcmp(
     }
     return rc;
 }
-
