@@ -1,10 +1,10 @@
 ///////////////////////////////////////////////////////////////////////////////
-// Name:        menuitem.cpp
+// Name:        src/os2/menuitem.cpp
 // Purpose:     wxMenuItem implementation
 // Author:      David Webster
 // Modified by:
 // Created:     10/10/98
-// RCS-ID:      $Id: menuitem.cpp,v 1.31 2005/04/27 01:19:41 DW Exp $
+// RCS-ID:      $Id: menuitem.cpp,v 1.39 2006/09/05 21:00:51 VZ Exp $
 // Copyright:   (c) David Webster
 // Licence:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
@@ -13,27 +13,23 @@
 // headers & declarations
 // ============================================================================
 
-#ifdef __GNUG__
-    #pragma implementation "menuitem.h"
-#endif
-
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
+#include "wx/menuitem.h"
+#include "wx/stockitem.h"
+
 #ifndef WX_PRECOMP
     #include "wx/font.h"
     #include "wx/bitmap.h"
     #include "wx/settings.h"
-    #include "wx/font.h"
     #include "wx/window.h"
     #include "wx/accel.h"
     #include "wx/menu.h"
     #include "wx/string.h"
+    #include "wx/log.h"
 #endif
 
-#include "wx/menuitem.h"
-#include "wx/log.h"
-
 #if wxUSE_ACCEL
     #include "wx/accel.h"
 #endif // wxUSE_ACCEL
@@ -175,13 +171,13 @@ int wxMenuItem::GetRealId() const
 // --------------
 bool wxMenuItem::IsChecked() const
 {
-    USHORT                          uFlag = SHORT1FROMMR(::WinSendMsg( GetHMenuOf(m_parentMenu)
-                                                                      ,MM_QUERYITEMATTR
-                                                                      ,MPFROM2SHORT(GetId(), TRUE)
-                                                                      ,MPFROMSHORT(MIA_CHECKED)
-                                                                     ));
+    USHORT uFlag = SHORT1FROMMR(::WinSendMsg( GetHMenuOf(m_parentMenu)
+                                             ,MM_QUERYITEMATTR
+                                             ,MPFROM2SHORT(GetId(), TRUE)
+                                             ,MPFROMSHORT(MIA_CHECKED)
+                                            ));
 
-    return (uFlag & MIA_CHECKED);
+    return (uFlag & MIA_CHECKED) == MIA_CHECKED ;
 } // end of wxMenuItem::IsChecked
 
 wxString wxMenuItemBase::GetLabelFromText(
@@ -211,7 +207,7 @@ wxString wxMenuItemBase::GetLabelFromText(
 //
 void wxMenuItem::SetAsRadioGroupStart()
 {
-    m_bIsRadioGroupStart = TRUE;
+    m_bIsRadioGroupStart = true;
 } // end of wxMenuItem::SetAsRadioGroupStart
 
 void wxMenuItem::SetRadioGroupStart(
@@ -260,7 +256,7 @@ void wxMenuItem::Enable(
                                 );
     if (!bOk)
     {
-        wxLogLastError("EnableMenuItem");
+        wxLogLastError(wxT("EnableMenuItem"));
     }
     wxMenuItemBase::Enable(bEnable);
 } // end of wxMenuItem::Enable
@@ -362,14 +358,12 @@ void wxMenuItem::Check(
     }
     if (!bOk)
     {
-        wxLogLastError("CheckMenuItem");
+        wxLogLastError(wxT("CheckMenuItem"));
     }
     wxMenuItemBase::Check(bCheck);
 } // end of wxMenuItem::Check
 
-void wxMenuItem::SetText(
-  const wxString&                   rText
-)
+void wxMenuItem::SetText( const wxString& rText )
 {
     //
     // Don't do anything if label didn't change
@@ -379,10 +373,18 @@ void wxMenuItem::SetText(
     if (m_text == sText)
         return;
 
+    // wxMenuItemBase will do stock ID checks
     wxMenuItemBase::SetText(sText);
-    OWNER_DRAWN_ONLY(wxOwnerDrawn::SetName(sText));
+
+    // m_text could now be different from 'text' if we are a stock menu item,
+    // so use only m_text below
+
+    OWNER_DRAWN_ONLY(wxOwnerDrawn::SetName(m_text));
 #if  wxUSE_OWNER_DRAWN
-    SetAccelString(rText.AfterFirst(_T('\t')));
+    if (rText.IsEmpty())
+        SetAccelString(m_text.AfterFirst(_T('\t')));
+    else
+        SetAccelString(rText.AfterFirst(_T('\t')));
 #endif // wxUSE_OWNER_DRAWN
 
     HWND                            hMenu = GetHmenuOf(m_parentMenu);
@@ -393,9 +395,9 @@ void wxMenuItem::SetText(
     m_parentMenu->UpdateAccel(this);
 #endif // wxUSE_ACCEL
 
-    USHORT                          uId = GetRealId();
-    MENUITEM                        vItem;
-    USHORT                          uFlagsOld;
+    USHORT   uId = (USHORT)GetRealId();
+    MENUITEM vItem;
+    USHORT   uFlagsOld;
 
     if (!::WinSendMsg( hMenu
                       ,MM_QUERYITEM
@@ -403,7 +405,7 @@ void wxMenuItem::SetText(
                       ,(MPARAM)&vItem
                      ))
     {
-        wxLogLastError("GetMenuState");
+        wxLogLastError(wxT("GetMenuState"));
     }
     else
     {
@@ -425,7 +427,7 @@ void wxMenuItem::SetText(
 #endif  //owner drawn
         {
             uFlagsOld |= MIS_TEXT;
-            pData = (BYTE*)sText.c_str();
+            pData = (BYTE*)m_text.c_str();
         }
 
         //
@@ -483,4 +485,3 @@ wxMenuItem* wxMenuItemBase::New(
                           ,pSubMenu
                          );
 } // end of wxMenuItemBase::New
-
