@@ -1,37 +1,32 @@
 ///////////////////////////////////////////////////////////////////////////////
-// Name:        msw/ownerdrw.cpp
+// Name:        src/os2/ownerdrw.cpp
 // Purpose:     implementation of wxOwnerDrawn class
 // Author:      David Webster
 // Modified by:
 // Created:     10/12/99
-// RCS-ID:      $Id: ownerdrw.cpp,v 1.23 2005/05/31 09:28:39 JS Exp $
+// RCS-ID:      $Id: ownerdrw.cpp,v 1.30 2006/10/08 21:28:44 SN Exp $
 // Copyright:   (c) David Webster
 // Licence:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
 
-#ifdef __GNUG__
-#pragma implementation
-#endif
-
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
-#ifndef WX_PRECOMP
-  #include "wx/window.h"
-  #include "wx/os2/private.h"
-  #include "wx/font.h"
-  #include "wx/bitmap.h"
-  #include "wx/dcmemory.h"
-  #include "wx/menu.h"
-  #include "wx/utils.h"
-#endif
-
 #if wxUSE_OWNER_DRAWN
 
-#include "wx/settings.h"
-#include "wx/ownerdrw.h"
-#include "wx/menuitem.h"
+#ifndef WX_PRECOMP
+    #include "wx/window.h"
+    #include "wx/os2/private.h"
+    #include "wx/font.h"
+    #include "wx/bitmap.h"
+    #include "wx/dcmemory.h"
+    #include "wx/menu.h"
+    #include "wx/utils.h"
+    #include "wx/settings.h"
+    #include "wx/menuitem.h"
+#endif
 
+#include "wx/ownerdrw.h"
 
 // ============================================================================
 // implementation of wxOwnerDrawn class
@@ -41,21 +36,21 @@
 // ctor
 // ----
 //
-wxOwnerDrawn::wxOwnerDrawn(
-  const wxString&                   rsStr
-, bool                              bCheckable
-, bool                              bMenuItem
-)
+wxOwnerDrawn::wxOwnerDrawn( const wxString& rsStr,
+                            bool            bCheckable,
+                            bool            WXUNUSED(bMenuItem) )
 : m_strName(rsStr)
 {
     m_bCheckable   = bCheckable;
-    m_bOwnerDrawn  = FALSE;
+    m_bOwnerDrawn  = false;
     m_nHeight      = 0;
     m_nMarginWidth = ms_nLastMarginWidth;
     if (wxNORMAL_FONT)
         m_font = *wxNORMAL_FONT;
 } // end of wxOwnerDrawn::wxOwnerDrawn
 
+wxOwnerDrawn::~wxOwnerDrawn() { }
+
 size_t wxOwnerDrawn::ms_nDefaultMarginWidth = 15;
 
 size_t wxOwnerDrawn::ms_nLastMarginWidth = ms_nDefaultMarginWidth;
@@ -65,15 +60,12 @@ size_t wxOwnerDrawn::ms_nLastMarginWidth = ms_nDefaultMarginWidth;
 // -------
 //
 
-bool wxOwnerDrawn::OnMeasureItem(
-  size_t*                           pWidth
-, size_t*                           pHeight
-)
+bool wxOwnerDrawn::OnMeasureItem( size_t* pWidth,
+                                  size_t* pHeight )
 {
-    wxMemoryDC                      vDC;
+    wxMemoryDC vDC;
 
-
-    wxString                        sStr = wxStripMenuCodes(m_strName);
+    wxString  sStr = wxStripMenuCodes(m_strName);
 
     //
     // If we have a valid accel string, then pad out
@@ -81,7 +73,7 @@ bool wxOwnerDrawn::OnMeasureItem(
     // placed on top of each other.
     if (!m_strAccel.empty() )
     {
-        sStr.Pad(sStr.Length()%8);
+        sStr.Pad(sStr.length()%8);
         sStr += m_strAccel;
     }
     vDC.SetFont(GetFont());
@@ -89,7 +81,7 @@ bool wxOwnerDrawn::OnMeasureItem(
                       ,(long *)pWidth
                       ,(long *)pHeight
                      );
-    if (!m_strAccel.IsEmpty())
+    if (!m_strAccel.empty())
     {
         //
         // Measure the accelerator string, and add its width to
@@ -166,22 +158,20 @@ bool wxOwnerDrawn::OnMeasureItem(
     if (*pHeight < m_nMinHeight)
         *pHeight = m_nMinHeight;
     m_nHeight = *pHeight;                // remember height for use in OnDrawItem
-    return TRUE;
+    return true;
 } // end of wxOwnerDrawn::OnMeasureItem
 
 // draw the item
-bool wxOwnerDrawn::OnDrawItem(
-  wxDC&                             rDC
-, const wxRect&                     rRect
-, wxODAction                        eAction
-, wxODStatus                        eStatus
-)
+bool wxOwnerDrawn::OnDrawItem( wxDC& rDC,
+                               const wxRect& rRect,
+                               wxODAction eAction,
+                               wxODStatus eStatus )
 {
     //
     // We do nothing on focus change
     //
     if (eAction == wxODFocusChanged )
-        return TRUE;
+        return true;
 
     //
     // Select the font and draw the text
@@ -214,12 +204,22 @@ bool wxOwnerDrawn::OnDrawItem(
     //
     if (eStatus & wxODSelected)
     {
-        wxColour                        vCol2(wxT("WHITE"));
-        vColBack.Set( (unsigned char)0
-                     ,(unsigned char)0
-                     ,(unsigned char)160
-                    ); // no dark blue in color table
-        vColText = vCol2;
+        vRef = (ULONG)::WinQuerySysColor( HWND_DESKTOP
+                                         ,SYSCLR_MENUHILITEBGND
+                                         ,0L
+                                        );
+        vColBack.Set( GetRValue(vRef)
+                     ,GetGValue(vRef)
+                     ,GetBValue(vRef)
+                    );
+        vRef = (ULONG)::WinQuerySysColor( HWND_DESKTOP
+                                         ,SYSCLR_MENUHILITE
+                                         ,0L
+                                        );
+        vColText.Set( GetRValue(vRef)
+                     ,GetGValue(vRef)
+                     ,GetBValue(vRef)
+                    );
     }
     else if (eStatus & wxODDisabled)
     {
@@ -300,15 +300,15 @@ bool wxOwnerDrawn::OnDrawItem(
     //
     // Display main text and accel text separately to align better
     //
-    wxString                        sTgt = wxT("\t");
-    wxString                        sFullString = m_strName; // need to save the original text
-    wxString                        sAccel;
-    int                             nIndex;
-    size_t                          nWidth;
-    size_t                          nCharWidth;
-    size_t                          nHeight;
-    bool                            bFoundMnemonic = FALSE;
-    bool                            bFoundAccel = FALSE;
+    wxString sTgt = wxT("\t");
+    wxString sFullString = m_strName; // need to save the original text
+    wxString sAccel;
+    int      nIndex;
+    size_t   nWidth;
+    size_t   nCharWidth;
+    size_t   nHeight;
+    bool     bFoundMnemonic = false;
+    bool     bFoundAccel = false;
 
     //
     // Deal with the tab, extracting the Accel text
@@ -316,7 +316,7 @@ bool wxOwnerDrawn::OnDrawItem(
     nIndex = sFullString.Find(sTgt.c_str());
     if (nIndex != -1)
     {
-        bFoundAccel = TRUE;
+        bFoundAccel = true;
         sAccel = sFullString.Mid(nIndex + 1);
         sFullString.Remove(nIndex);
     }
@@ -328,9 +328,9 @@ bool wxOwnerDrawn::OnDrawItem(
     nIndex = sFullString.Find(sTgt.c_str());
     if (nIndex != -1)
     {
-        wxString                    sTmp = sFullString;
+        wxString sTmp = sFullString;
 
-        bFoundMnemonic = TRUE;
+        bFoundMnemonic = true;
         sTmp.Remove(nIndex);
         rDC.GetTextExtent( sTmp
                           ,(long *)&nWidth
@@ -341,7 +341,7 @@ bool wxOwnerDrawn::OnDrawItem(
                           ,(long *)&nCharWidth
                           ,(long *)&nHeight
                          );
-        sFullString.Replace(sTgt.c_str(), wxEmptyString, TRUE);
+        sFullString.Replace(sTgt.c_str(), wxEmptyString, true);
     }
 
     //
@@ -424,7 +424,7 @@ bool wxOwnerDrawn::OnDrawItem(
         //
         // For uncheckable item we use only the 'checked' bitmap
         //
-        wxBitmap                    vBmp(GetBitmap(IsCheckable() ? ((eStatus & wxODChecked) != 0) : TRUE));
+        wxBitmap vBmp(GetBitmap(IsCheckable() ? ((eStatus & wxODChecked) != 0) : TRUE));
 
         if (vBmp.Ok())
         {
@@ -459,7 +459,7 @@ bool wxOwnerDrawn::OnDrawItem(
                      ,0
                      ,0
                      ,wxCOPY
-                     ,TRUE
+                     ,true
                     );
 
             if (eStatus & wxODSelected)
@@ -487,7 +487,7 @@ bool wxOwnerDrawn::OnDrawItem(
             vBmp.SetSelectedInto(NULL);
         }
     }
-    return TRUE;
+    return true;
 } // end of wxOwnerDrawn::OnDrawItem
 
 #endif //wxUSE_OWNER_DRAWN
