@@ -4,16 +4,11 @@
 // Author:      David Webster
 // Modified by:
 // Created:     10/15/99
-// RCS-ID:      $Id: spinbutt.cpp,v 1.20.2.1 2006/01/07 18:01:20 SN Exp $
+// RCS-ID:      $Id: spinbutt.cpp,v 1.24 2006/07/19 20:52:06 SN Exp $
 // Copyright:   (c) David Webster
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
-#ifdef __GNUG__
-    #pragma implementation "spinbutt.h"
-    #pragma implementation "spinbutbase.h"
-#endif
-
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
@@ -124,12 +119,7 @@ bool wxSpinButton::Create(
     SetXComp(vSwp.x);
     SetYComp(vSwp.y-5); // compensate for the associated TextControl border
 
-    wxFont*                          pTextFont = new wxFont( 10
-                                                            ,wxMODERN
-                                                            ,wxNORMAL
-                                                            ,wxNORMAL
-                                                           );
-    SetFont(*pTextFont);
+    SetFont(*wxSMALL_FONT);
     //
     // For OS/2 we want to hide the text portion so we can substitute an
     // independent text ctrl in its place.
@@ -150,7 +140,6 @@ bool wxSpinButton::Create(
     ::WinSetWindowULong(GetHwnd(), QWL_USER, (LONG)this);
     fnWndProcSpinCtrl = (WXFARPROC)::WinSubclassWindow(m_hWnd, (PFNWP)wxSpinCtrlWndProc);
 #endif
-    delete pTextFont;
     return TRUE;
 } // end of wxSpinButton::Create
 
@@ -166,11 +155,11 @@ wxSize wxSpinButton::DoGetBestSize() const
 {
     //
     // OS/2 PM does not really have system metrics so we'll just set it to
-    // 26x20 which is the size of the buttons and the borders.
-    // Also we have no horizontal spin buttons.
+    // a square based on its height.
     //
-    wxSize best(26,20);
-    return best;
+    RECTL   vRect;
+    ::WinQueryWindowRect(GetHwnd(),&vRect);
+    return wxSize(vRect.yTop,vRect.yTop);
 } // end of wxSpinButton::DoGetBestSize
 
 // ----------------------------------------------------------------------------
@@ -198,7 +187,7 @@ bool wxSpinButton::OS2OnScroll( int    WXUNUSED(nOrientation),
                                 WXWORD wPos,
                                 WXHWND hControl )
 {
-    wxCHECK_MSG(hControl, false, wxT("scrolling what?") )
+    wxCHECK_MSG(hControl, false, wxT("scrolling what?") );
 
     wxSpinEvent vEvent( wxEVT_SCROLL_THUMBTRACK, m_windowId );
     int nVal = (int)wPos;    // cast is important for negative values!
