@@ -1,30 +1,27 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        statbmp.cpp
+// Name:        src/os2/statbmp.cpp
 // Purpose:     wxStaticBitmap
 // Author:      David Webster
 // Modified by:
 // Created:     11/27/99
-// RCS-ID:      $Id: statbmp.cpp,v 1.20.2.1 2006/01/07 18:01:20 SN Exp $
+// RCS-ID:      $Id: statbmp.cpp,v 1.24 2006/05/06 21:51:34 ABX Exp $
 // Copyright:   (c) David Webster
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
-#ifdef __GNUG__
-#pragma implementation "statbmp.h"
-#endif
-
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
-#include "wx/dcclient.h"
-#include "wx/window.h"
-#include "wx/os2/private.h"
+#include "wx/statbmp.h"
 
 #ifndef WX_PRECOMP
     #include "wx/icon.h"
-    #include "wx/statbmp.h"
+    #include "wx/window.h"
+    #include "wx/dcclient.h"
 #endif
 
+#include "wx/os2/private.h"
+
 #include <stdio.h>
 
 // ---------------------------------------------------------------------------
@@ -123,17 +120,16 @@ bool wxStaticBitmap::Create( wxWindow*         pParent,
         sError = wxPMErrorToStr(vError);
         return false;
     }
-    wxCHECK_MSG( m_hWnd, FALSE, wxT("Failed to create static bitmap") );
+    wxCHECK_MSG( m_hWnd, false, wxT("Failed to create static bitmap") );
     m_pImage = ConvertImage(rBitmap);
-
+    ::WinSendMsg(   m_hWnd,
+                    SM_SETHANDLE,
+                    MPFROMHWND(rBitmap.GetHandle()),
+                    (MPARAM)0);
 
     // Subclass again for purposes of dialog editing mode
     SubclassWin(m_hWnd);
     SetSize(nX, nY, m_pImage->GetWidth(), m_pImage->GetHeight());
-   ::WinSendMsg(   m_hWnd,
-                   SM_SETHANDLE,
-                   MPFROMHWND(rBitmap.GetHandle()),
-                   (MPARAM)0);
 
     return true;
 } // end of wxStaticBitmap::Create
@@ -159,12 +155,10 @@ wxSize wxStaticBitmap::DoGetBestSize() const
     return wxWindow::DoGetBestSize();
 }
 
-void wxStaticBitmap::OnPaint (
-  wxPaintEvent&                     WXUNUSED(rEvent)
-)
+void wxStaticBitmap::OnPaint ( wxPaintEvent& WXUNUSED(rEvent) )
 {
-    wxPaintDC                       vDc(this);
-    wxBitmap*                       pBitmap;
+    wxPaintDC vDc(this);
+    wxBitmap* pBitmap;
 
     if (m_pImage->IsKindOf(CLASSINFO(wxIcon)))
     {
@@ -182,14 +176,12 @@ void wxStaticBitmap::OnPaint (
     }
 } // end of wxStaticBitmap::OnPaint
 
-void wxStaticBitmap::SetImage(
-  const wxGDIImage&                 rBitmap
-)
+void wxStaticBitmap::SetImage( const wxGDIImage& rBitmap )
 {
-    int                             nX = 0;
-    int                             nY = 0;
-    int                             nWidth = 0;
-    int                             nHeight = 0;
+    int nX = 0;
+    int nY = 0;
+    int nWidth = 0;
+    int nHeight = 0;
 
     Free();
     ::WinSendMsg( GetHwnd()
