@@ -1,10 +1,10 @@
 ///////////////////////////////////////////////////////////////////////////////
-// Name:        os2/toplevel.cpp
+// Name:        src/os2/toplevel.cpp
 // Purpose:     implements wxTopLevelWindow for OS/2
 // Author:      Vadim Zeitlin
 // Modified by:
 // Created:     30.12.01
-// RCS-ID:      $Id: toplevel.cpp,v 1.38.2.2 2006/01/11 22:35:06 SN Exp $
+// RCS-ID:      $Id: toplevel.cpp,v 1.46 2006/08/31 19:31:16 ABX Exp $
 // Copyright:   (c) 2001 SciTech Software, Inc. (www.scitechsoft.com)
 // License:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
@@ -17,10 +17,6 @@
 // headers
 // ----------------------------------------------------------------------------
 
-#ifdef __GNUG__
-    #pragma implementation "toplevel.h"
-#endif
-
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
@@ -28,9 +24,10 @@
     #pragma hdrstop
 #endif
 
+#include "wx/toplevel.h"
+
 #ifndef WX_PRECOMP
     #include "wx/app.h"
-    #include "wx/toplevel.h"
     #include "wx/dialog.h"
     #include "wx/string.h"
     #include "wx/log.h"
@@ -39,9 +36,9 @@
     #include "wx/control.h"
     #include "wx/containr.h"        // wxSetFocusToChild()
     #include "wx/settings.h"
+    #include "wx/module.h"        // wxSetFocusToChild()
 #endif //WX_PRECOMP
 
-#include "wx/module.h"        // wxSetFocusToChild()
 #include "wx/os2/private.h"
 
 // ----------------------------------------------------------------------------
@@ -54,11 +51,10 @@
 // ----------------------------------------------------------------------------
 
 // the name of the default wxWidgets class
-extern void          wxAssociateWinWithHandle( HWND         hWnd
-                                              ,wxWindowOS2* pWin
-                                             );
-bool                 wxTopLevelWindowOS2::m_sbInitialized = false;
-wxWindow*            wxTopLevelWindowOS2::m_spHiddenParent = NULL;
+extern void wxAssociateWinWithHandle( HWND hWnd, wxWindowOS2* pWin );
+
+bool wxTopLevelWindowOS2::m_sbInitialized = false;
+wxWindow* wxTopLevelWindowOS2::m_spHiddenParent = NULL;
 
 // ============================================================================
 // wxTopLevelWindowOS2 implementation
@@ -120,12 +116,12 @@ private:
     //
     // The HWND of the hidden parent
     //
-    static HWND                     m_shWnd;
+    static HWND m_shWnd;
 
     //
     // The class used to create it
     //
-    static const wxChar*            m_szClassName;
+    static const wxChar* m_szClassName;
     DECLARE_DYNAMIC_CLASS(wxTLWHiddenParentModule)
 }; // end of CLASS wxTLWHiddenParentModule
 
@@ -239,7 +235,7 @@ WXDWORD wxTopLevelWindowOS2::OS2GetStyle(
         lMsflags |= FCF_MINBUTTON;
     if (lStyle & wxMAXIMIZE_BOX)
         lMsflags |= FCF_MAXBUTTON;
-    if (lStyle & wxTHICK_FRAME)
+    if (lStyle & wxRESIZE_BORDER)
         lMsflags |= FCF_DLGBORDER;
     if (lStyle & wxSYSTEM_MENU)
         lMsflags |= FCF_SYSMENU;
@@ -255,7 +251,7 @@ WXDWORD wxTopLevelWindowOS2::OS2GetStyle(
     if (lStyle & wxTINY_CAPTION_HORIZ)
         lMsflags |= FCF_TASKLIST;
 
-    if ((lStyle & wxTHICK_FRAME) == 0)
+    if ((lStyle & wxRESIZE_BORDER) == 0)
         lMsflags |= FCF_BORDER;
     if (lStyle & wxFRAME_TOOL_WINDOW)
         *pdwExflags = kFrameToolWindow;
@@ -443,26 +439,24 @@ bool wxTopLevelWindowOS2::CreateDialog( ULONG           ulDlgTemplate,
     return true;
 } // end of wxTopLevelWindowOS2::CreateDialog
 
-bool wxTopLevelWindowOS2::CreateFrame(
-  const wxString&                   rsTitle
-, const wxPoint&                    rPos
-, const wxSize&                     rSize
-)
+bool wxTopLevelWindowOS2::CreateFrame( const wxString& rsTitle,
+                                       const wxPoint& rPos,
+                                       const wxSize& rSize )
 {
-    WXDWORD                         lExflags;
-    WXDWORD                         lFlags = OS2GetCreateWindowFlags(&lExflags);
-    long                            lStyle = GetWindowStyleFlag();
-    int                             nX = rPos.x;
-    int                             nY = rPos.y;
-    int                             nWidth = rSize.x;
-    int                             nHeight = rSize.y;
-    ULONG                           ulStyleFlags = 0L;
-    ERRORID                         vError;
-    wxString                        sError;
-    wxWindow*                       pParent = GetParent();
-    HWND                            hParent;
-    HWND                            hFrame;
-    HWND                            hClient;
+    WXDWORD    lExflags;
+    WXDWORD    lFlags = OS2GetCreateWindowFlags(&lExflags);
+    long       lStyle = GetWindowStyleFlag();
+    int        nX = rPos.x;
+    int        nY = rPos.y;
+    int        nWidth = rSize.x;
+    int        nHeight = rSize.y;
+    ULONG      ulStyleFlags = 0L;
+    ERRORID    vError;
+    wxString   sError;
+    wxWindow*  pParent = GetParent();
+    HWND       hParent;
+    HWND       hFrame;
+    HWND       hClient;
 
     if (pParent)
         hParent = GetHwndOf(pParent);
@@ -547,7 +541,9 @@ bool wxTopLevelWindowOS2::CreateFrame(
                                   ,nWidth
                                   ,nHeight
                                  ))
+    {
         nX = nWidth = (int)CW_USEDEFAULT;
+    }
 
     //
     // We can't use CW_USEDEFAULT here as we're not calling CreateWindow()
@@ -557,7 +553,7 @@ bool wxTopLevelWindowOS2::CreateFrame(
     //
     if (nWidth == (int)CW_USEDEFAULT)
     {
-        //
+       //
         // The exact number doesn't matter, the dialog will be resized
         // again soon anyhow but it should be big enough to allow
         // calculation relying on "totalSize - clientSize > 0" work, i.e.
@@ -751,12 +747,10 @@ void wxTopLevelWindowOS2::DoShowWindow(
     m_bIconized = nShowCmd == SWP_MINIMIZE;
 } // end of wxTopLevelWindowOS2::DoShowWindow
 
-bool wxTopLevelWindowOS2::Show(
-  bool                              bShow
-)
+bool wxTopLevelWindowOS2::Show( bool bShow )
 {
-    int                             nShowCmd;
-    SWP                             vSwp;
+    int nShowCmd;
+    SWP vSwp;
 
     if (bShow != IsShown() )
     {
@@ -786,14 +780,14 @@ bool wxTopLevelWindowOS2::Show(
 
     if (bShow)
     {
-        wxActivateEvent             vEvent(wxEVT_ACTIVATE, true, m_windowId);
+        wxActivateEvent vEvent(wxEVT_ACTIVATE, true, m_windowId);
 
         ::WinQueryWindowPos(m_hFrame, &vSwp);
         m_bIconized = ( vSwp.fl & SWP_MINIMIZE ) == SWP_MINIMIZE ;
         ::WinQueryWindowPos(m_hWnd, &m_vSwpClient);
         ::WinSendMsg(m_hFrame, WM_UPDATEFRAME, (MPARAM)~0, 0);
         ::WinQueryWindowPos(m_hWnd, &vSwp);
-        ::WinEnableWindow(m_hFrame, true);
+        ::WinEnableWindow(m_hFrame, TRUE);
 
         vEvent.SetEventObject(this);
         GetEventHandler()->ProcessEvent(vEvent);
@@ -805,7 +799,7 @@ bool wxTopLevelWindowOS2::Show(
         //
         if (GetParent())
         {
-            HWND                    hWndParent = GetHwndOf(GetParent());
+            HWND hWndParent = GetHwndOf(GetParent());
 
             ::WinQueryWindowPos(hWndParent, &vSwp);
             m_bIconized = (vSwp.fl & SWP_MINIMIZE)==SWP_MINIMIZE;
@@ -846,9 +840,17 @@ bool wxTopLevelWindowOS2::IsMaximized() const
     return (m_vSwp.fl & SWP_MAXIMIZE) == SWP_MAXIMIZE;
 } // end of wxTopLevelWindowOS2::IsMaximized
 
-void wxTopLevelWindowOS2::Iconize(
-  bool                              bIconize
-)
+void wxTopLevelWindowOS2::SetTitle( const wxString& title)
+{
+    SetLabel(title);
+}
+
+wxString wxTopLevelWindowOS2::GetTitle() const
+{
+    return GetLabel();
+}
+
+void wxTopLevelWindowOS2::Iconize( bool bIconize )
 {
     DoShowWindow(bIconize ? SWP_MINIMIZE : SWP_RESTORE);
 } // end of wxTopLevelWindowOS2::Iconize
@@ -1026,14 +1028,12 @@ void wxTopLevelWindowOS2::SetIcons(
     }
 } // end of wxTopLevelWindowOS2::SetIcon
 
-bool wxTopLevelWindowOS2::EnableCloseButton(
-  bool                              bEnable
-)
+bool wxTopLevelWindowOS2::EnableCloseButton( bool bEnable )
 {
     //
     // Get system (a.k.a. window) menu
     //
-    HMENU                           hMenu = ::WinWindowFromID(m_hFrame, FID_SYSMENU);
+    HMENU hMenu = ::WinWindowFromID(m_hFrame, FID_SYSMENU);
 
     if (!hMenu)
     {
@@ -1120,20 +1120,19 @@ HWND wxTLWHiddenParentModule::GetHWND()
                 m_szClassName = zHIDDEN_PARENT_CLASS;
             }
         }
-        m_shWnd = ::WinCreateWindow( HWND_DESKTOP
-                                    ,(PSZ)m_szClassName
-                                    ,""
-                                    ,0L
-                                    ,(LONG)0L
-                                    ,(LONG)0L
-                                    ,(LONG)0L
-                                    ,(LONG)0L
-                                    ,NULLHANDLE
-                                    ,HWND_TOP
-                                    ,0L
-                                    ,NULL
-                                    ,NULL
-                                   );
+        m_shWnd = ::WinCreateWindow( HWND_DESKTOP,
+                                     (PSZ)m_szClassName,
+                                     "",
+                                     0L,
+                                     (LONG)0L,
+                                     (LONG)0L,
+                                     (LONG)0L,
+                                     (LONG)0L,
+                                     NULLHANDLE,
+                                     HWND_TOP,
+                                     0L,
+                                     NULL,
+                                     NULL );
         if (!m_shWnd)
         {
             wxLogLastError(_T("CreateWindow(hidden TLW parent)"));
