@@ -4,7 +4,7 @@
 // Author:      William Osborne - minimal working wxPalmOS port
 // Modified by:
 // Created:     10/13/04
-// RCS-ID:      $Id: volume.cpp,v 1.4 2005/07/01 19:36:58 ABX Exp $
+// RCS-ID:      $Id: volume.cpp,v 1.8 2006/06/20 10:24:07 ABX Exp $
 // Copyright:   (c) William Osborne
 // Licence:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
@@ -17,10 +17,6 @@
 // headers
 // ----------------------------------------------------------------------------
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-    #pragma implementation "fsvolume.h"
-#endif
-
 #include "wx/wxprec.h"
 
 #ifdef __BORLANDC__
@@ -29,16 +25,17 @@
 
 #if wxUSE_FSVOLUME
 
+#include "wx/volume.h"
+
 #ifndef WX_PRECOMP
     #if wxUSE_GUI
         #include "wx/icon.h"
     #endif
     #include "wx/intl.h"
+    #include "wx/arrstr.h"
+    #include "wx/hashmap.h"
 #endif // WX_PRECOMP
 
-#include "wx/arrstr.h"
-#include "wx/volume.h"
-
 #include <VFSMgr.h>
 #include <PalmTypesCompatibility.h>
 
@@ -236,4 +233,3 @@ wxIcon wxFSVolume::GetIcon(wxFSIconType type) const
 #endif // wxUSE_GUI
 
 #endif // wxUSE_FSVOLUME
-
