@@ -1,33 +1,35 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        app.cpp
+// Name:        src/x11/app.cpp
 // Purpose:     wxApp
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: app.cpp,v 1.100.2.1 2006/03/24 12:27:45 JS Exp $
+// RCS-ID:      $Id: app.cpp,v 1.119 2006/10/31 08:45:33 JS Exp $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-    #pragma implementation "app.h"
+// for compilers that support precompilation, includes "wx.h".
+#include "wx/wxprec.h"
+
+#include "wx/app.h"
+
+#ifndef WX_PRECOMP
+    #include "wx/hash.h"
+    #include "wx/intl.h"
+    #include "wx/log.h"
+    #include "wx/utils.h"
+    #include "wx/frame.h"
+    #include "wx/icon.h"
+    #include "wx/dialog.h"
+    #include "wx/timer.h"
+    #include "wx/memory.h"
+    #include "wx/gdicmn.h"
+    #include "wx/module.h"
 #endif
 
-#include "wx/frame.h"
-#include "wx/app.h"
-#include "wx/utils.h"
-#include "wx/gdicmn.h"
-#include "wx/icon.h"
-#include "wx/dialog.h"
-#include "wx/log.h"
-#include "wx/module.h"
-#include "wx/memory.h"
-#include "wx/log.h"
-#include "wx/intl.h"
 #include "wx/evtloop.h"
-#include "wx/timer.h"
 #include "wx/filename.h"
-#include "wx/hash.h"
 
 #include "wx/univ/theme.h"
 #include "wx/univ/renderer.h"
@@ -44,12 +46,10 @@
 //   global data
 //------------------------------------------------------------------------
 
-extern wxList wxPendingDelete;
-
 wxWindowHash *wxWidgetHashTable = NULL;
 wxWindowHash *wxClientWidgetHashTable = NULL;
 
-static bool g_showIconic = FALSE;
+static bool g_showIconic = false;
 static wxSize g_initialSize = wxDefaultSize;
 
 // This is required for wxFocusEvent::SetWindow(). It will only
@@ -83,7 +83,6 @@ static int wxXErrorHandler(Display *dpy, XErrorEvent *xevent)
 //------------------------------------------------------------------------
 
 long wxApp::sm_lastMessageTime = 0;
-WXDisplay *wxApp::ms_display = NULL;
 
 IMPLEMENT_DYNAMIC_CLASS(wxApp, wxEvtHandler)
 
@@ -99,7 +98,7 @@ bool wxApp::Initialize(int& argC, wxChar **argV)
 #endif // __WXDEBUG__
 
     wxString displayName;
-    bool syncDisplay = FALSE;
+    bool syncDisplay = false;
 
     int argCOrig = argC;
     for ( int i = 0; i < argCOrig; i++ )
@@ -139,14 +138,14 @@ bool wxApp::Initialize(int& argC, wxChar **argV)
         }
         else if (wxStrcmp( argV[i], _T("-sync") ) == 0)
         {
-            syncDisplay = TRUE;
+            syncDisplay = true;
 
             argV[i] = NULL;
             argC--;
         }
         else if (wxStrcmp( argV[i], _T("-iconic") ) == 0)
         {
-            g_showIconic = TRUE;
+            g_showIconic = true;
 
             argV[i] = NULL;
             argC--;
@@ -165,34 +164,24 @@ bool wxApp::Initialize(int& argC, wxChar **argV)
         }
     }
 
-    // X11 display stuff
-    Display *xdisplay;
-    if ( displayName.empty() )
-        xdisplay = XOpenDisplay( NULL );
-    else
-        xdisplay = XOpenDisplay( displayName.ToAscii() );
-    if (!xdisplay)
+    // open and set up the X11 display
+    if ( !wxSetDisplay(displayName) )
     {
-        wxLogError( _("wxWidgets could not open display. Exiting.") );
+        wxLogError(_("wxWidgets could not open display. Exiting."));
         return false;
     }
 
+    Display *dpy = wxGlobalDisplay();
     if (syncDisplay)
-        XSynchronize(xdisplay, True);
+        XSynchronize(dpy, True);
 
-    ms_display = (WXDisplay*) xdisplay;
+    XSelectInput(dpy, XDefaultRootWindow(dpy), PropertyChangeMask);
 
-    XSelectInput( xdisplay, XDefaultRootWindow(xdisplay), PropertyChangeMask);
+    wxSetDetectableAutoRepeat( true );
 
-    // Misc.
-    wxSetDetectableAutoRepeat( TRUE );
 
     if ( !wxAppBase::Initialize(argC, argV) )
-    {
-        XCloseDisplay(xdisplay);
-
         return false;
-    }
 
 #if wxUSE_UNICODE
     // Glib's type system required by Pango
@@ -221,14 +210,10 @@ void wxApp::CleanUp()
 
 wxApp::wxApp()
 {
-    // TODO: parse the command line
-    argc = 0;
-    argv = NULL;
-
-    m_mainColormap = (WXColormap) NULL;
-    m_topLevelWidget = (WXWindow) NULL;
+    m_mainColormap = NULL;
+    m_topLevelWidget = NULL;
     m_maxRequestSize = 0;
-    m_showIconic = FALSE;
+    m_showIconic = false;
     m_initialSize = wxDefaultSize;
 
 #if !wxUSE_NANOX
@@ -244,6 +229,7 @@ wxApp::~wxApp()
 }
 
 #if !wxUSE_NANOX
+
 //-----------------------------------------------------------------------
 // X11 predicate function for exposure compression
 //-----------------------------------------------------------------------
@@ -254,7 +240,8 @@ struct wxExposeInfo
     Bool found_non_matching;
 };
 
-static Bool expose_predicate (Display *display, XEvent *xevent, XPointer arg)
+extern "C"
+Bool wxX11ExposePredicate (Display *display, XEvent *xevent, XPointer arg)
 {
     wxExposeInfo *info = (wxExposeInfo*) arg;
 
@@ -263,23 +250,23 @@ static Bool expose_predicate (Display *display, XEvent *xevent, XPointer arg)
 
     if (xevent->xany.type != Expose)
     {
-        info->found_non_matching = TRUE;
+        info->found_non_matching = true;
         return FALSE;
     }
 
     if (xevent->xexpose.window != info->window)
     {
-        info->found_non_matching = TRUE;
+        info->found_non_matching = true;
         return FALSE;
     }
 
     return TRUE;
 }
-#endif
-    // wxUSE_NANOX
+
+#endif // wxUSE_NANOX
 
 //-----------------------------------------------------------------------
-// Processes an X event, returning TRUE if the event was processed.
+// Processes an X event, returning true if the event was processed.
 //-----------------------------------------------------------------------
 
 bool wxApp::ProcessXEvent(WXEvent* _event)
@@ -305,7 +292,7 @@ bool wxApp::ProcessXEvent(WXEvent* _event)
         win = wxGetClientWindowFromTable(window);
         if (!win)
 #endif
-            return FALSE;
+            return false;
     }
 
 #ifdef __WXDEBUG__
@@ -322,8 +309,8 @@ bool wxApp::ProcessXEvent(WXEvent* _event)
                 XEvent tmp_event;
                 wxExposeInfo info;
                 info.window = event->xexpose.window;
-                info.found_non_matching = FALSE;
-                while (XCheckIfEvent( wxGlobalDisplay(), &tmp_event, expose_predicate, (XPointer) &info ))
+                info.found_non_matching = false;
+                while (XCheckIfEvent( wxGlobalDisplay(), &tmp_event, wxX11ExposePredicate, (XPointer) &info ))
                 {
                     // Don't worry about optimizing redrawing the border etc.
                 }
@@ -341,8 +328,8 @@ bool wxApp::ProcessXEvent(WXEvent* _event)
                 XEvent tmp_event;
                 wxExposeInfo info;
                 info.window = event->xexpose.window;
-                info.found_non_matching = FALSE;
-                while (XCheckIfEvent( wxGlobalDisplay(), &tmp_event, expose_predicate, (XPointer) &info ))
+                info.found_non_matching = false;
+                while (XCheckIfEvent( wxGlobalDisplay(), &tmp_event, wxX11ExposePredicate, (XPointer) &info ))
                 {
                     win->GetUpdateRegion().Union( tmp_event.xexpose.x, tmp_event.xexpose.y,
                                                   tmp_event.xexpose.width, tmp_event.xexpose.height );
@@ -369,7 +356,7 @@ bool wxApp::ProcessXEvent(WXEvent* _event)
                 //win->Update();
             }
 
-            return TRUE;
+            return true;
         }
 
 #if !wxUSE_NANOX
@@ -390,14 +377,14 @@ bool wxApp::ProcessXEvent(WXEvent* _event)
                 // win->Update();
             }
 
-            return TRUE;
+            return true;
         }
 #endif
 
         case KeyPress:
         {
             if (!win->IsEnabled())
-                return FALSE;
+                return false;
 
             wxKeyEvent keyEvent(wxEVT_KEY_DOWN);
             wxTranslateKeyEvent(keyEvent, win, window, event);
@@ -406,14 +393,14 @@ bool wxApp::ProcessXEvent(WXEvent* _event)
 
             // We didn't process wxEVT_KEY_DOWN, so send wxEVT_CHAR
             if (win->GetEventHandler()->ProcessEvent( keyEvent ))
-                return TRUE;
+                return true;
 
             keyEvent.SetEventType(wxEVT_CHAR);
             // Do the translation again, retaining the ASCII
             // code.
-            wxTranslateKeyEvent(keyEvent, win, window, event, TRUE);
-            if (win->GetEventHandler()->ProcessEvent( keyEvent ))
-                return TRUE;
+            if (wxTranslateKeyEvent(keyEvent, win, window, event, true) &&
+                win->GetEventHandler()->ProcessEvent( keyEvent ))
+                return true;
 
             if ( (keyEvent.m_keyCode == WXK_TAB) &&
                  win->GetParent() && (win->GetParent()->HasFlag( wxTAB_TRAVERSAL)) )
@@ -428,12 +415,12 @@ bool wxApp::ProcessXEvent(WXEvent* _event)
                 return win->GetParent()->GetEventHandler()->ProcessEvent( new_event );
             }
 
-            return FALSE;
+            return false;
         }
         case KeyRelease:
         {
             if (!win->IsEnabled())
-                return FALSE;
+                return false;
 
             wxKeyEvent keyEvent(wxEVT_KEY_UP);
             wxTranslateKeyEvent(keyEvent, win, window, event);
@@ -465,7 +452,7 @@ bool wxApp::ProcessXEvent(WXEvent* _event)
                     return win->GetEventHandler()->ProcessEvent( sizeEvent );
                 }
             }
-            return FALSE;
+            return false;
         }
 #if !wxUSE_NANOX
         case PropertyNotify:
@@ -476,7 +463,7 @@ bool wxApp::ProcessXEvent(WXEvent* _event)
         case ClientMessage:
         {
             if (!win->IsEnabled())
-                return FALSE;
+                return false;
 
             Atom wm_delete_window = XInternAtom(wxGlobalDisplay(), "WM_DELETE_WINDOW", True);
             Atom wm_protocols = XInternAtom(wxGlobalDisplay(), "WM_PROTOCOLS", True);
@@ -485,11 +472,11 @@ bool wxApp::ProcessXEvent(WXEvent* _event)
             {
                 if ((Atom) (event->xclient.data.l[0]) == wm_delete_window)
                 {
-                    win->Close(FALSE);
-                    return TRUE;
+                    win->Close(false);
+                    return true;
                 }
             }
-            return FALSE;
+            return false;
         }
 #if 0
         case DestroyNotify:
@@ -531,10 +518,10 @@ bool wxApp::ProcessXEvent(WXEvent* _event)
         {
             if (win)
             {
-                win->Close(FALSE);
-                return TRUE;
+                win->Close(false);
+                return true;
             }
-            return FALSE;
+            return false;
             break;
         }
 #endif
@@ -545,7 +532,7 @@ bool wxApp::ProcessXEvent(WXEvent* _event)
         case MotionNotify:
         {
             if (!win->IsEnabled())
-                return FALSE;
+                return false;
 
             // Here we check if the top level window is
             // disabled, which is one aspect of modality.
@@ -553,7 +540,7 @@ bool wxApp::ProcessXEvent(WXEvent* _event)
             while (tlw && !tlw->IsTopLevel())
                 tlw = tlw->GetParent();
             if (tlw && !tlw->IsEnabled())
-                return FALSE;
+                return false;
 
             if (event->type == ButtonPress)
             {
@@ -582,7 +569,7 @@ bool wxApp::ProcessXEvent(WXEvent* _event)
             {
                 // Throw out NotifyGrab and NotifyUngrab
                 if (event->xcrossing.mode != NotifyNormal)
-                    return FALSE;
+                    return false;
             }
 #endif
             wxMouseEvent wxevent;
@@ -604,7 +591,7 @@ bool wxApp::ProcessXEvent(WXEvent* _event)
                     // caused by a child having its focus set.
                     g_GettingFocus = NULL;
                     wxLogTrace( _T("focus"), _T("FocusIn from %s of type %s being deliberately ignored"), win->GetName().c_str(), win->GetClassInfo()->GetClassName() );
-                    return TRUE;
+                    return true;
                 }
                 else
                 {
@@ -616,7 +603,7 @@ bool wxApp::ProcessXEvent(WXEvent* _event)
                     return win->GetEventHandler()->ProcessEvent(focusEvent);
                 }
             }
-            return FALSE;
+            return false;
 
         case FocusOut:
 #if !wxUSE_NANOX
@@ -632,7 +619,7 @@ bool wxApp::ProcessXEvent(WXEvent* _event)
                 g_nextFocus = NULL;
                 return win->GetEventHandler()->ProcessEvent(focusEvent);
             }
-            return FALSE;
+            return false;
 
 #ifdef __WXDEBUG__
         default:
@@ -642,7 +629,7 @@ bool wxApp::ProcessXEvent(WXEvent* _event)
 #endif // __WXDEBUG__
     }
 
-    return FALSE;
+    return false;
 }
 
 // This should be redefined in a derived class for
@@ -652,7 +639,7 @@ bool wxApp::HandlePropertyChange(WXEvent *event)
     // by default do nothing special
     // TODO: what to do for X11
     // XtDispatchEvent((XEvent*) event);
-    return FALSE;
+    return false;
 }
 
 void wxApp::WakeUpIdle()
@@ -666,24 +653,27 @@ void wxApp::WakeUpIdle()
 // Create display, and other initialization
 bool wxApp::OnInitGui()
 {
+#if wxUSE_LOG
     // Eventually this line will be removed, but for
     // now we don't want to try popping up a dialog
     // for error messages.
     delete wxLog::SetActiveTarget(new wxLogStderr);
+#endif
 
     if (!wxAppBase::OnInitGui())
-        return FALSE;
+        return false;
 
-    GetMainColormap( wxApp::GetDisplay() );
+    Display *dpy = wxGlobalDisplay();
+    GetMainColormap(dpy);
 
-    m_maxRequestSize = XMaxRequestSize( (Display*) wxApp::GetDisplay() );
+    m_maxRequestSize = XMaxRequestSize(dpy);
 
 #if !wxUSE_NANOX
     m_visualInfo = new wxXVisualInfo;
-    wxFillXVisualInfo( m_visualInfo, (Display*) wxApp::GetDisplay() );
+    wxFillXVisualInfo(m_visualInfo, dpy);
 #endif
 
-    return TRUE;
+    return true;
 }
 
 #if wxUSE_UNICODE
@@ -696,33 +686,34 @@ bool wxApp::OnInitGui()
 
 PangoContext* wxApp::GetPangoContext()
 {
-    static PangoContext *ret = NULL;
-    if (ret)
-        return ret;
-
-    Display *xdisplay = (Display*) wxApp::GetDisplay();
+    static PangoContext *s_pangoContext = NULL;
+    if ( !s_pangoContext )
+    {
+        Display *dpy = wxGlobalDisplay();
 
 #ifdef HAVE_PANGO_XFT
-    int xscreen = DefaultScreen(xdisplay);
-    static int use_xft = -1;
-    if (use_xft == -1)
-    {
-        wxString val = wxGetenv( L"GDK_USE_XFT" );
-        use_xft = (val == L"1");
+        int xscreen = DefaultScreen(dpy);
+        static int use_xft = -1;
+        if (use_xft == -1)
+        {
+            wxString val = wxGetenv( L"GDK_USE_XFT" );
+            use_xft = val == L"1";
+        }
+
+        if (use_xft)
+            s_pangoContext = pango_xft_get_context(dpy, xscreen);
+        else
+#endif // HAVE_PANGO_XFT
+            s_pangoContext = pango_x_get_context(dpy);
+
+        if (!PANGO_IS_CONTEXT(s_pangoContext))
+            wxLogError( wxT("No pango context.") );
     }
 
-    if (use_xft)
-        ret = pango_xft_get_context( xdisplay, xscreen );
-    else
-#endif
-        ret = pango_x_get_context( xdisplay );
-
-    if (!PANGO_IS_CONTEXT(ret))
-        wxLogError( wxT("No pango context.") );
-
-    return ret;
+    return s_pangoContext;
 }
-#endif
+
+#endif // wxUSE_UNICODE
 
 WXColormap wxApp::GetMainColormap(WXDisplay* display)
 {
@@ -789,7 +780,7 @@ bool wxApp::Yield(bool onlyIfNeeded)
     int i;
     for (i = 0; i < 2; i++)
     {
-        static bool s_inYield = FALSE;
+        static bool s_inYield = false;
 
         if ( s_inYield )
         {
@@ -798,10 +789,10 @@ bool wxApp::Yield(bool onlyIfNeeded)
                 wxFAIL_MSG( wxT("wxYield called recursively" ) );
             }
 
-            return FALSE;
+            return false;
         }
 
-        s_inYield = TRUE;
+        s_inYield = true;
 
         // Make sure we have an event loop object,
         // or Pending/Dispatch will fail
@@ -831,10 +822,10 @@ bool wxApp::Yield(bool onlyIfNeeded)
             delete newEventLoop;
         }
 
-        s_inYield = FALSE;
+        s_inYield = false;
     }
 
-    return TRUE;
+    return true;
 }
 
 #ifdef __WXDEBUG__
@@ -853,4 +844,3 @@ void wxApp::OnAssert(const wxChar *file, int line, const wxChar* cond, const wxC
 }
 
 #endif // __WXDEBUG__
-
