@@ -3,7 +3,7 @@
 // Purpose:     wxDateTime unit test
 // Author:      Vadim Zeitlin
 // Created:     2004-06-23 (extracted from samples/console/console.cpp)
-// RCS-ID:      $Id: datetimetest.cpp,v 1.7 2005/08/28 13:06:36 VZ Exp $
+// RCS-ID:      $Id: datetimetest.cpp,v 1.16 2007/01/18 14:06:37 VZ Exp $
 // Copyright:   (c) 2004 Vadim Zeitlin <vadim@wxwindows.org>
 ///////////////////////////////////////////////////////////////////////////////
 
@@ -20,7 +20,18 @@
 #ifndef WX_PRECOMP
 #endif // WX_PRECOMP
 
+#if wxUSE_DATETIME
+
 #include "wx/datetime.h"
+#include "wx/ioswrap.h"
+
+// need this to be able to use CPPUNIT_ASSERT_EQUAL with wxDateTime objects
+static wxSTD ostream& operator<<(wxSTD ostream& ostr, const wxDateTime& dt)
+{
+    ostr << dt.FormatISODate() << _T(" ") << dt.FormatISOTime();
+
+    return ostr;
+}
 
 // to test Today() meaningfully we must be able to change the system date which
 // is not usually the case, but if we're under Win32 we can try it -- define
@@ -174,10 +185,13 @@ private:
         CPPUNIT_TEST( TestTimeWDays );
         CPPUNIT_TEST( TestTimeDST );
         CPPUNIT_TEST( TestTimeFormat );
+        CPPUNIT_TEST( TestTimeSpanFormat );
         CPPUNIT_TEST( TestTimeTicks );
-        CPPUNIT_TEST( TestTimeParse );
+        CPPUNIT_TEST( TestParceRFC822 );
+        CPPUNIT_TEST( TestDateParse );
         CPPUNIT_TEST( TestTimeArithmetics );
         CPPUNIT_TEST( TestDSTBug );
+        CPPUNIT_TEST( TestDateOnly );
     CPPUNIT_TEST_SUITE_END();
 
     void TestLeapYears();
@@ -187,10 +201,13 @@ private:
     void TestTimeWDays();
     void TestTimeDST();
     void TestTimeFormat();
+    void TestTimeSpanFormat();
     void TestTimeTicks();
-    void TestTimeParse();
+    void TestParceRFC822();
+    void TestDateParse();
     void TestTimeArithmetics();
     void TestDSTBug();
+    void TestDateOnly();
 
     DECLARE_NO_COPY_CLASS(DateTimeTestCase)
 };
@@ -575,6 +592,7 @@ void DateTimeTestCase::TestTimeFormat()
     {
         CompareNone,        // don't try comparing
         CompareBoth,        // dates and times should be identical
+        CompareYear,        // don't compare centuries (fails for 2 digit years)
         CompareDate,        // dates only
         CompareTime         // time only
     };
@@ -585,9 +603,9 @@ void DateTimeTestCase::TestTimeFormat()
         const wxChar *format;
     } formatTestFormats[] =
     {
-       { CompareBoth, _T("---> %c") },
+       { CompareYear, _T("---> %c") }, // %c could use 2 digit years
        { CompareDate, _T("Date is %A, %d of %B, in year %Y") },
-       { CompareBoth, _T("Date is %x, time is %X") },
+       { CompareYear, _T("Date is %x, time is %X") }, // %x could use 2 digits
        { CompareTime, _T("Time is %H:%M:%S or %I:%M:%S %p") },
        { CompareNone, _T("The day of year: %j, the week of year: %W") },
        { CompareDate, _T("ISO date without separators: %Y%m%d") },
@@ -595,30 +613,33 @@ void DateTimeTestCase::TestTimeFormat()
 
     static const Date formatTestDates[] =
     {
-        { 29, wxDateTime::May, 1976, 18, 30, 00, 0.0, wxDateTime::Inv_WeekDay, 0, 0 },
-        { 31, wxDateTime::Dec, 1999, 23, 30, 00, 0.0, wxDateTime::Inv_WeekDay, 0, 0 },
+        { 29, wxDateTime::May, 1976, 18, 30, 00, 0.0, wxDateTime::Inv_WeekDay },
+        { 31, wxDateTime::Dec, 1999, 23, 30, 00, 0.0, wxDateTime::Inv_WeekDay },
+        {  6, wxDateTime::Feb, 1937, 23, 30, 00, 0.0, wxDateTime::Inv_WeekDay },
+        {  6, wxDateTime::Feb, 1856, 23, 30, 00, 0.0, wxDateTime::Inv_WeekDay },
+        {  6, wxDateTime::Feb, 1857, 23, 30, 00, 0.0, wxDateTime::Inv_WeekDay },
+        { 29, wxDateTime::May, 2076, 18, 30, 00, 0.0, wxDateTime::Inv_WeekDay },
+        { 29, wxDateTime::Feb, 2400, 02, 15, 25, 0.0, wxDateTime::Inv_WeekDay },
 #if 0
-        // this test can't work for other centuries because it uses two digit
-        // years in formats, so don't even try it
-        { 29, wxDateTime::May, 2076, 18, 30, 00, 0.0, wxDateTime::Inv_WeekDay, 0, 0 },
-        { 29, wxDateTime::Feb, 2400, 02, 15, 25, 0.0, wxDateTime::Inv_WeekDay, 0, 0 },
-        { 01, wxDateTime::Jan,  -52, 03, 16, 47, 0.0, wxDateTime::Inv_WeekDay, 0, 0 },
+        // Need to add support for BCE dates.
+        { 01, wxDateTime::Jan,  -52, 03, 16, 47, 0.0, wxDateTime::Inv_WeekDay },
 #endif
     };
 
-    for ( size_t d = 0; d < WXSIZEOF(formatTestDates) + 1; d++ )
+    for ( size_t d = 0; d < WXSIZEOF(formatTestDates); d++ )
     {
-        wxDateTime dt = d == 0 ? wxDateTime::Now() : formatTestDates[d - 1].DT();
+        wxDateTime dt = formatTestDates[d].DT();
         for ( size_t n = 0; n < WXSIZEOF(formatTestFormats); n++ )
         {
-            wxString s = dt.Format(formatTestFormats[n].format);
+            const wxChar *fmt = formatTestFormats[n].format;
+            wxString s = dt.Format(fmt);
 
             // what can we recover?
-            int kind = formatTestFormats[n].compareKind;
+            CompareKind kind = formatTestFormats[n].compareKind;
 
             // convert back
             wxDateTime dt2;
-            const wxChar *result = dt2.ParseFormat(s, formatTestFormats[n].format);
+            const wxChar *result = dt2.ParseFormat(s, fmt);
             if ( !result )
             {
                 // converion failed - should it have?
@@ -631,8 +652,18 @@ void DateTimeTestCase::TestTimeFormat()
 
                 switch ( kind )
                 {
+                    case CompareYear:
+                        if ( dt2.GetCentury() != dt.GetCentury() )
+                        {
+                            CPPUNIT_ASSERT_EQUAL(dt.GetYear() % 100,
+                                                 dt2.GetYear() % 100);
+
+                            dt2.SetYear(dt.GetYear());
+                        }
+                        // fall through and compare everything
+
                     case CompareBoth:
-                        CPPUNIT_ASSERT( dt2 == dt );
+                        CPPUNIT_ASSERT_EQUAL( dt, dt2 );
                         break;
 
                     case CompareDate:
@@ -642,12 +673,47 @@ void DateTimeTestCase::TestTimeFormat()
                     case CompareTime:
                         CPPUNIT_ASSERT( dt.IsSameTime(dt2) );
                         break;
+
+                    case CompareNone:
+                        wxFAIL_MSG( _T("unexpected") );
+                        break;
                 }
             }
         }
     }
 }
 
+void DateTimeTestCase::TestTimeSpanFormat()
+{
+    static const struct TimeSpanFormatTestData
+    {
+        long h, min, sec, msec;
+        const wxChar *fmt;
+        const wxChar *result;
+    } testSpans[] =
+    {
+        {   12, 34, 56, 789, _T("%H:%M:%S.%l"),   _T("12:34:56.789")          },
+        {    1,  2,  3,   0, _T("%H:%M:%S"),      _T("01:02:03")              },
+        {    1,  2,  3,   0, _T("%S"),            _T("3723")                  },
+        {   -1, -2, -3,   0, _T("%S"),            _T("-3723")                 },
+        {   -1, -2, -3,   0, _T("%H:%M:%S"),      _T("-01:02:03")             },
+        {   26,  0,  0,   0, _T("%H"),            _T("26")                    },
+        {   26,  0,  0,   0, _T("%D, %H"),        _T("1, 02")                 },
+        {  -26,  0,  0,   0, _T("%H"),            _T("-26")                   },
+        {  -26,  0,  0,   0, _T("%D, %H"),        _T("-1, 02")                },
+        {  219,  0,  0,   0, _T("%H"),            _T("219")                   },
+        {  219,  0,  0,   0, _T("%D, %H"),        _T("9, 03")                 },
+        {  219,  0,  0,   0, _T("%E, %D, %H"),    _T("1, 2, 03")              },
+    };
+
+    for ( size_t n = 0; n < WXSIZEOF(testSpans); n++ )
+    {
+        const TimeSpanFormatTestData& td = testSpans[n];
+        wxTimeSpan ts(td.h, td.min, td.sec, td.msec);
+        CPPUNIT_ASSERT_EQUAL( wxString(td.result), ts.Format(td.fmt) );
+    }
+}
+
 void DateTimeTestCase::TestTimeTicks()
 {
     for ( size_t n = 0; n < WXSIZEOF(testDates); n++ )
@@ -670,12 +736,12 @@ void DateTimeTestCase::TestTimeTicks()
     }
 }
 
-// test text -> wxDateTime conversion
-void DateTimeTestCase::TestTimeParse()
+// test parsing dates in RFC822 format
+void DateTimeTestCase::TestParceRFC822()
 {
     static const struct ParseTestData
     {
-        const wxChar *format;
+        const wxChar *rfc822;
         Date date;              // NB: this should be in UTC
         bool good;
     } parseTestDates[] =
@@ -699,15 +765,56 @@ void DateTimeTestCase::TestTimeParse()
 
     for ( size_t n = 0; n < WXSIZEOF(parseTestDates); n++ )
     {
-        const wxChar *format = parseTestDates[n].format;
-
         wxDateTime dt;
-        if ( dt.ParseRfc822Date(format) )
+        if ( dt.ParseRfc822Date(parseTestDates[n].rfc822) )
         {
             CPPUNIT_ASSERT( parseTestDates[n].good );
 
             wxDateTime dtReal = parseTestDates[n].date.DT().FromUTC();
-            CPPUNIT_ASSERT( dt == dtReal );
+            CPPUNIT_ASSERT_EQUAL( dtReal, dt );
+        }
+        else // failed to parse
+        {
+            CPPUNIT_ASSERT( !parseTestDates[n].good );
+        }
+    }
+}
+
+// test parsing dates in free format
+void DateTimeTestCase::TestDateParse()
+{
+    static const struct ParseTestData
+    {
+        const wxChar *str;
+        Date date;              // NB: this should be in UTC
+        bool good;
+    } parseTestDates[] =
+    {
+        { _T("21 Mar 2006"), { 21, wxDateTime::Mar, 2006 }, true },
+        { _T("29 Feb 1976"), { 29, wxDateTime::Feb, 1976 }, true },
+        { _T("Feb 29 1976"), { 29, wxDateTime::Feb, 1976 }, true },
+        { _T("31/03/06"),    { 31, wxDateTime::Mar,    6 }, true },
+        { _T("31/03/2006"),  { 31, wxDateTime::Mar, 2006 }, true },
+
+        // some invalid ones too
+        { _T("29 Feb 2006") },
+        { _T("31/04/06") },
+        { _T("bloordyblop") }
+    };
+
+    // special cases
+    wxDateTime dt;
+    CPPUNIT_ASSERT( dt.ParseDate(_T("today")) );
+    CPPUNIT_ASSERT_EQUAL( wxDateTime::Today(), dt );
+
+    for ( size_t n = 0; n < WXSIZEOF(parseTestDates); n++ )
+    {
+        wxDateTime dt;
+        if ( dt.ParseDate(parseTestDates[n].str) )
+        {
+            CPPUNIT_ASSERT( parseTestDates[n].good );
+
+            CPPUNIT_ASSERT_EQUAL( parseTestDates[n].date.DT(), dt );
         }
         else // failed to parse
         {
@@ -815,3 +922,20 @@ void DateTimeTestCase::TestDSTBug()
 #endif // CHANGE_SYSTEM_DATE
 }
 
+void DateTimeTestCase::TestDateOnly()
+{
+    wxDateTime dt(19, wxDateTime::Jan, 2007, 15, 01, 00);
+
+    static const wxDateTime::wxDateTime_t DATE_ZERO = 0;
+    CPPUNIT_ASSERT_EQUAL( DATE_ZERO, dt.GetDateOnly().GetHour() );
+    CPPUNIT_ASSERT_EQUAL( DATE_ZERO, dt.GetDateOnly().GetMinute() );
+    CPPUNIT_ASSERT_EQUAL( DATE_ZERO, dt.GetDateOnly().GetSecond() );
+    CPPUNIT_ASSERT_EQUAL( DATE_ZERO, dt.GetDateOnly().GetMillisecond() );
+
+    dt.ResetTime();
+    CPPUNIT_ASSERT_EQUAL( wxDateTime(19, wxDateTime::Jan, 2007), dt );
+
+    CPPUNIT_ASSERT_EQUAL( wxDateTime::Today(), wxDateTime::Now().GetDateOnly() );
+}
+
+#endif // wxUSE_DATETIME
